@@ -13,6 +13,9 @@ from sphinx_astropy.conf import *
 from gammapy.utils.docs import gammapy_sphinx_ext_activate
 from gammapy.utils.docs import gammapy_sphinx_notebooks
 
+# Sphinx-gallery config
+from sphinx_gallery.sorting import FileNameSortKey
+
 # Get configuration information from setup.cfg
 from configparser import ConfigParser
 
@@ -60,6 +63,7 @@ extensions.extend(
         "sphinx_click.ext",
         "IPython.sphinxext.ipython_console_highlighting",
         "sphinx.ext.mathjax",
+        "sphinx_gallery.gen_gallery",
     ]
 )
 nbsphinx_execute = "never"
@@ -194,3 +198,20 @@ automodsumm_inherited_members = True
 suppress_warnings = ["ref.citation"]
 
 # nitpicky = True
+
+sphinx_gallery_conf = {
+    "examples_dirs": ["../examples/models"],  # path to your example scripts
+    "gallery_dirs": [
+        "modeling/gallery"
+    ],  # path to where to save gallery generated output
+    "within_subsection_order": FileNameSortKey,
+    "download_all_examples": False,
+    "capture_repr": (),
+    "min_reported_time": 10000,
+    "show_memory": False,
+    "line_numbers": False,
+    "reference_url": {
+        # The module you locally document uses None
+        "gammapy": None,
+    },
+}
