@@ -18,34 +18,35 @@ the following sub-packages (e.g. `gammapy.spectrum`):
 
 ::
 
- `astro`          --- Astrophysical source and population models
- `background`     --- Background estimation and modeling
- `catalog`        --- Source catalog tools
- `cube`           --- Cube analysis
- `data`           --- Data and observation handling
- `detect`         --- Source detection tools
- `image`          --- Image processing and analysis tools
- `irf`            --- Instrument response functions (IRFs)
- `maps`           --- Sky map data structures
- `spectrum`       --- Spectrum estimation and modeling
- `stats`          --- Statistics tools
- `time`           --- Time handling and analysis
- `utils`          --- Utility functions and classes
+ astro        --- Astrophysical source and population models
+ catalog      --- Source catalog tools
+ cube         --- Cube analysis
+ data         --- Data and observation handling
+ detect       --- Source detection tools
+ irf          --- Instrument response functions (IRFs)
+ maps         --- Sky map data structures
+ modeling     --- Models and fitting
+ spectrum     --- Spectrum estimation and modeling
+ stats        --- Statistics tools
+ time         --- Time handling and analysis
+ utils        --- Utility functions and classes
 """
 
-# Affiliated packages may add whatever they like to this file, but
-# should keep this content at the top.
-# ----------------------------------------------------------------------------
-from ._astropy_init import *
+__all__ = ["__version__", "test", "song"]
 
-# ----------------------------------------------------------------------------
+import pkg_resources
 
-# For egg_info test builds to pass, put package imports here.
-if not _ASTROPY_SETUP_:  # pylint: disable=undefined-variable
-    # put top-level package imports here
+try:
+    __version__ = pkg_resources.get_distribution(__name__).version
+except pkg_resources.DistributionNotFound:
+    # package is not installed
     pass
 
 
+def test():
+    raise NotImplementedError
+
+
 def song(karaoke=False):
     """
     Listen to the Gammapy song.
@@ -76,5 +77,5 @@ def song(karaoke=False):
             "Supernova remnants, pulsar winds, AGN, Gamma, Gamma, Gammapy\n"
         )
 
-        centered = "\n".join("{:^80}".format(s) for s in lyrics.split("\n"))
+        centered = "\n".join(f"{s:^80}" for s in lyrics.split("\n"))
         sys.stdout.write(centered)
