@@ -1,8 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
 import astropy.units as u
-from ....utils.testing import assert_quantity_allclose, requires_data
-from .. import PrimaryFlux, DMAnnihilation
+from gammapy.astro.darkmatter import DarkMatterAnnihilationSpectralModel, PrimaryFlux
+from gammapy.utils.testing import assert_quantity_allclose, requires_data
 
 
 @requires_data()
@@ -18,14 +18,15 @@ def test_primary_flux():
 
 @requires_data()
 def test_DMAnnihilation():
-
     channel = "b"
     massDM = 5 * u.TeV
     jfactor = 3.41e19 * u.Unit("GeV2 cm-5")
     emin = 0.01 * u.TeV
     emax = 10 * u.TeV
 
-    model = DMAnnihilation(mass=massDM, channel=channel, jfactor=jfactor)
+    model = DarkMatterAnnihilationSpectralModel(
+        mass=massDM, channel=channel, jfactor=jfactor
+    )
     integral_flux = model.integral(emin=emin, emax=emax).to("cm-2 s-1")
     differential_flux = model.evaluate(energy=1 * u.TeV, scale=1).to("cm-2 s-1 TeV-1")
 
