@@ -1,29 +1,28 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Simulate source catalogs."""
 import numpy as np
-from astropy.table import Table, Column
-from astropy.units import Quantity
 from astropy.coordinates import SkyCoord
-from ...utils import coordinates as astrometry
-from ...utils.coordinates import D_SUN_TO_GALACTIC_CENTER
-from ...utils.random import (
+from astropy.table import Column, Table
+from astropy.units import Quantity
+from gammapy.astro.source import PWN, SNR, Pulsar, SNRTrueloveMcKee
+from gammapy.utils import coordinates as astrometry
+from gammapy.utils.random import (
+    draw,
+    get_random_state,
+    pdf,
     sample_sphere,
     sample_sphere_distance,
-    get_random_state,
-    draw,
-    pdf,
 )
-from ..source import SNR, SNRTrueloveMcKee, PWN, Pulsar
-from ..population.spatial import (
+from .spatial import (
+    RMAX,
+    RMIN,
+    ZMAX,
+    ZMIN,
     Exponential,
     FaucherSpiral,
-    RMIN,
-    RMAX,
-    ZMIN,
-    ZMAX,
     radial_distributions,
 )
-from ..population.velocity import VMIN, VMAX, velocity_distributions
+from .velocity import VMAX, VMIN, velocity_distributions
 
 __all__ = [
     "make_catalog_random_positions_cube",
@@ -80,7 +79,7 @@ def make_catalog_random_positions_cube(
         y = random_state.uniform(-distance_max, distance_max, size)
         z = random_state.uniform(-distance_max, distance_max, size)
     else:
-        raise ValueError("Invalid dimension: {}".format(dimension))
+        raise ValueError(f"Invalid dimension: {dimension}")
 
     table = Table()
     table["x"] = Column(x, unit="pc", description="Cartesian coordinate")
@@ -144,7 +143,7 @@ def make_base_catalog_galactic(
     Choose a radial distribution, a velocity distribution, the number
     of pulsars n_pulsars, the maximal age max_age[years] and the fraction
     of the individual morphtypes. There's an option spiralarms. If set on
-    True a spiralarm modelling after Faucher&Kaspi is included.
+    True a spiralarm modeling after Faucher&Kaspi is included.
 
     max_age and n_sources effectively correspond to s SN rate:
     SN_rate = n_sources / max_age
@@ -394,7 +393,7 @@ def add_observed_parameters(table, obs_pos=None):
     table : `~astropy.table.Table`
         Modified input table with columns added
     """
-    obs_pos = obs_pos or [D_SUN_TO_GALACTIC_CENTER, 0, 0]
+    obs_pos = obs_pos or [astrometry.D_SUN_TO_GALACTIC_CENTER, 0, 0]
 
     # Get data
     x, y, z = table["x"].quantity, table["y"].quantity, table["z"].quantity
