@@ -1,10 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Galactic radial source distribution probability density functions."""
 import numpy as np
-from astropy.units import Quantity
 from astropy.modeling import Fittable1DModel, Parameter
-from ...utils.coordinates import cartesian, polar, D_SUN_TO_GALACTIC_CENTER
-from ...utils.random import get_random_state
+from astropy.units import Quantity
+from gammapy.utils.coordinates import D_SUN_TO_GALACTIC_CENTER, cartesian, polar
+from gammapy.utils.random import get_random_state
 
 __all__ = [
     "CaseBattacharya1998",
@@ -223,7 +223,7 @@ class FaucherKaspi2006(Fittable1DModel):
     def evaluate(r, amplitude, r_0, sigma):
         """Evaluate model."""
         term1 = 1.0 / np.sqrt(2 * np.pi * sigma)
-        term2 = np.exp(-(r - r_0) ** 2 / (2 * sigma ** 2))
+        term2 = np.exp(-((r - r_0) ** 2) / (2 * sigma ** 2))
         return amplitude * term1 * term2
 
 
