@@ -1,8 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Supernova remnant (SNR) source models."""
 import numpy as np
+import astropy.constants
 from astropy.units import Quantity
-import astropy.constants as const
 from astropy.utils import lazyproperty
 
 __all__ = ["SNR", "SNRTrueloveMcKee"]
@@ -13,7 +13,7 @@ class SNR:
 
     The model is based on the Sedov-Taylor solution for strong explosions.
 
-    Reference: http://adsabs.harvard.edu/abs/1950RSPSA.201..159T
+    Reference: https://ui.adsabs.harvard.edu/abs/1950RSPSA.201..159T
 
     Parameters
     ----------
@@ -34,7 +34,7 @@ class SNR:
         e_sn="1e51 erg",
         theta=Quantity(0.1),
         n_ISM=Quantity(1, "cm-3"),
-        m_ejecta=const.M_sun,
+        m_ejecta=astropy.constants.M_sun,
         t_stop=Quantity(1e6, "K"),
         age=None,
         morphology="Shell2D",
@@ -42,7 +42,7 @@ class SNR:
     ):
         self.e_sn = Quantity(e_sn, "erg")
         self.theta = theta
-        self.rho_ISM = n_ISM * const.m_p
+        self.rho_ISM = n_ISM * astropy.constants.m_p
         self.n_ISM = n_ISM
         self.m_ejecta = m_ejecta
         self.t_stop = t_stop
@@ -52,20 +52,20 @@ class SNR:
             self.age = Quantity(age, "yr")
 
     def radius(self, t):
-        """Outer shell radius at age t.
+        r"""Outer shell radius at age t.
 
         The radius during the free expansion phase is given by:
 
         .. math::
-            r_{SNR}(t) \\approx 0.01
-            \\left(\\frac{E_{SN}}{10^{51}erg}\\right)^{1/2}
-            \\left(\\frac{M_{ej}}{M_{\\odot}}\\right)^{-1/2} t
-            \\text{ pc}
+            r_{SNR}(t) \approx 0.01
+            \left(\frac{E_{SN}}{10^{51}erg}\right)^{1/2}
+            \left(\frac{M_{ej}}{M_{\odot}}\right)^{-1/2} t
+            \text{ pc}
 
         The radius during the Sedov-Taylor phase evolves like:
 
         .. math::
-            r_{SNR}(t) \\approx \\left(\\frac{E_{SN}}{\\rho_{ISM}}\\right)^{1/5}t^{2/5}
+            r_{SNR}(t) \approx \left(\frac{E_{SN}}{\rho_{ISM}}\right)^{1/5}t^{2/5}
 
         Parameters
         ----------
@@ -90,7 +90,7 @@ class SNR:
         """
         # proportional constant for the free expansion phase
         term_1 = (self.e_sn / Quantity(1e51, "erg")) ** (1.0 / 2)
-        term_2 = (self.m_ejecta / const.M_sun) ** (-1.0 / 2)
+        term_2 = (self.m_ejecta / astropy.constants.M_sun) ** (-1.0 / 2)
         return Quantity(0.01, "pc/yr") * term_1 * term_2 * t
 
     def _radius_sedov_taylor(self, t):
@@ -115,7 +115,7 @@ class SNR:
         return self.radius(t) * (1 - fraction)
 
     def luminosity_tev(self, t, energy_min="1 TeV"):
-        """Gamma-ray luminosity above ``energy_min`` at age ``t``.
+        r"""Gamma-ray luminosity above ``energy_min`` at age ``t``.
 
         The luminosity is assumed constant in a given age interval and zero
         before and after. The assumed spectral index is 2.1.
@@ -123,12 +123,12 @@ class SNR:
         The gamma-ray luminosity above 1 TeV is given by:
 
         .. math::
-            L_{\\gamma}(\\geq 1TeV) \\approx 10^{34} \\theta
-            \\left(\\frac{E_{SN}}{10^{51} erg}\\right)
-            \\left(\\frac{\\rho_{ISM}}{1.66\\cdot 10^{-24} g/cm^{3}} \\right)
-            \\text{ s}^{-1}
+            L_{\gamma}(\geq 1TeV) \approx 10^{34} \theta
+            \left(\frac{E_{SN}}{10^{51} erg}\right)
+            \left(\frac{\rho_{ISM}}{1.66\cdot 10^{-24} g/cm^{3}} \right)
+            \text{ s}^{-1}
 
-        Reference: http://adsabs.harvard.edu/abs/1994A%26A...287..959D (Formula (7)).
+        Reference: https://ui.adsabs.harvard.edu/abs/1994A%26A...287..959D (Formula (7)).
 
         Parameters
         ----------
@@ -143,7 +143,7 @@ class SNR:
         # Flux in 1 k distance according to Drury formula 9
         term_0 = energy_min / Quantity(1, "TeV")
         term_1 = self.e_sn / Quantity(1e51, "erg")
-        term_2 = self.rho_ISM / (Quantity(1, "cm-3") * const.m_p)
+        term_2 = self.rho_ISM / (Quantity(1, "cm-3") * astropy.constants.m_p)
         L = self.theta * term_0 ** (1 - self.spectral_index) * term_1 * term_2
 
         # Corresponding luminosity
@@ -154,7 +154,7 @@ class SNR:
 
     @lazyproperty
     def sedov_taylor_begin(self):
-        """Characteristic time scale when the Sedov-Taylor phase of the SNR's evolution begins.
+        r"""Characteristic time scale when the Sedov-Taylor phase of the SNR's evolution begins.
 
         The beginning of the Sedov-Taylor phase of the SNR is defined by the condition,
         that the swept up mass of the surrounding medium equals the mass of the
@@ -163,20 +163,22 @@ class SNR:
         The time scale is given by:
 
         .. math::
-            t_{begin} \\approx 200
-            \\left(\\frac{E_{SN}}{10^{51}erg}\\right)^{-1/2}
-            \\left(\\frac{M_{ej}}{M_{\\odot}}\\right)^{5/6}
-            \\left(\\frac{\\rho_{ISM}}{10^{-24}g/cm^3}\\right)^{-1/3}
-            \\text{yr}
+            t_{begin} \approx 200
+            \left(\frac{E_{SN}}{10^{51}erg}\right)^{-1/2}
+            \left(\frac{M_{ej}}{M_{\odot}}\right)^{5/6}
+            \left(\frac{\rho_{ISM}}{10^{-24}g/cm^3}\right)^{-1/3}
+            \text{yr}
         """
         term1 = (self.e_sn / Quantity(1e51, "erg")) ** (-1.0 / 2)
-        term2 = (self.m_ejecta / const.M_sun) ** (5.0 / 6)
-        term3 = (self.rho_ISM / (Quantity(1, "cm-3") * const.m_p)) ** (-1.0 / 3)
+        term2 = (self.m_ejecta / astropy.constants.M_sun) ** (5.0 / 6)
+        term3 = (self.rho_ISM / (Quantity(1, "cm-3") * astropy.constants.m_p)) ** (
+            -1.0 / 3
+        )
         return Quantity(200, "yr") * term1 * term2 * term3
 
     @lazyproperty
     def sedov_taylor_end(self):
-        """Characteristic time scale when the Sedov-Taylor phase of the SNR's evolution ends.
+        r"""Characteristic time scale when the Sedov-Taylor phase of the SNR's evolution ends.
 
         The end of the Sedov-Taylor phase of the SNR is defined by the condition, that the
         temperature at the shock drops below T = 10^6 K.
@@ -184,13 +186,17 @@ class SNR:
         The time scale is given by:
 
         .. math::
-            t_{end} \\approx 43000
-            \\left(\\frac{m}{1.66\\cdot 10^{-24}g}\\right)^{5/6}
-            \\left(\\frac{E_{SN}}{10^{51}erg}\\right)^{1/3}
-            \\left(\\frac{\\rho_{ISM}}{1.66\\cdot 10^{-24}g/cm^3}\\right)^{-1/3}
-            \\text{yr}
+            t_{end} \approx 43000
+            \left(\frac{m}{1.66\cdot 10^{-24}g}\right)^{5/6}
+            \left(\frac{E_{SN}}{10^{51}erg}\right)^{1/3}
+            \left(\frac{\rho_{ISM}}{1.66\cdot 10^{-24}g/cm^3}\right)^{-1/3}
+            \text{yr}
         """
-        term1 = 3 * const.m_p.cgs / (100 * const.k_B.cgs * self.t_stop)
+        term1 = (
+            3
+            * astropy.constants.m_p.cgs
+            / (100 * astropy.constants.k_B.cgs * self.t_stop)
+        )
         term2 = (self.e_sn / self.rho_ISM) ** (2.0 / 5)
         return ((term1 * term2) ** (5.0 / 6)).to("yr")
 
@@ -198,7 +204,7 @@ class SNR:
 class SNRTrueloveMcKee(SNR):
     """SNR model according to Truelove & McKee (1999).
 
-    Reference: http://adsabs.harvard.edu/abs/1999ApJS..120..299T
+    Reference: https://ui.adsabs.harvard.edu/abs/1999ApJS..120..299T
     """
 
     def __init__(self, *args, **kwargs):
@@ -213,24 +219,24 @@ class SNRTrueloveMcKee(SNR):
         )
 
     def radius(self, t):
-        """Outer shell radius at age t.
+        r"""Outer shell radius at age t.
 
         The radius during the free expansion phase is given by:
 
         .. math::
-            R_{SNR}(t) = 1.12R_{ch}\\left(\\frac{t}{t_{ch}}\\right)^{2/3}
+            R_{SNR}(t) = 1.12R_{ch}\left(\frac{t}{t_{ch}}\right)^{2/3}
 
         The radius during the Sedov-Taylor phase evolves like:
 
         .. math::
-            R_{SNR}(t) = \\left[R_{SNR, ST}^{5/2} + \\left(2.026\\frac{E_{SN}}
-            {\\rho_{ISM}}\\right)^{1/2}(t - t_{ST})\\right]^{2/5}
+            R_{SNR}(t) = \left[R_{SNR, ST}^{5/2} + \left(2.026\frac{E_{SN}}
+            {\rho_{ISM}}\right)^{1/2}(t - t_{ST})\right]^{2/5}
 
         Using the characteristic dimensions:
 
         .. math::
-            R_{ch} = M_{ej}^{1/3}\\rho_{ISM}^{-1/3} \\ \\
-            \\text{and} \\ \\ t_{ch} = E_{SN}^{-1/2}M_{ej}^{5/6}\\rho_{ISM}^{-1/3}
+            R_{ch} = M_{ej}^{1/3}\rho_{ISM}^{-1/3} \ \
+            \text{and} \ \ t_{ch} = E_{SN}^{-1/2}M_{ej}^{5/6}\rho_{ISM}^{-1/3}
 
         Parameters
         ----------
@@ -271,26 +277,26 @@ class SNRTrueloveMcKee(SNR):
 
     @lazyproperty
     def sedov_taylor_begin(self):
-        """Characteristic time scale when the Sedov-Taylor phase starts.
+        r"""Characteristic time scale when the Sedov-Taylor phase starts.
 
-        Given by :math:`t_{ST} \\approx 0.52 t_{ch}`.
+        Given by :math:`t_{ST} \approx 0.52 t_{ch}`.
         """
         return 0.52 * self.t_c
 
     def radius_reverse_shock(self, t):
-        """Reverse shock radius at age t.
+        r"""Reverse shock radius at age t.
 
         Initially the reverse shock co-evolves with the radius of the SNR:
 
         .. math::
-            R_{RS}(t) = \\frac{1}{1.19}r_{SNR}(t)
+            R_{RS}(t) = \frac{1}{1.19}r_{SNR}(t)
 
-        After a time :math:`t_{core} \\simeq 0.25t_{ch}` the reverse shock reaches
+        After a time :math:`t_{core} \simeq 0.25t_{ch}` the reverse shock reaches
         the core and then propagates as:
 
         .. math::
-            R_{RS}(t) = \\left[1.49 - 0.16 \\frac{t - t_{core}}{t_{ch}} - 0.46
-            \\ln \\left(\\frac{t}{t_{core}}\\right)\\right]\\frac{R_{ch}}{t_{ch}}t
+            R_{RS}(t) = \left[1.49 - 0.16 \frac{t - t_{core}}{t_{ch}} - 0.46
+            \ln \left(\frac{t}{t_{core}}\right)\right]\frac{R_{ch}}{t_{ch}}t
 
         Parameters
         ----------
