@@ -1,16 +1,21 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Source catalog and object base classes."""
-from collections import OrderedDict
-import copy
-import numpy as np
+import abc
+import numbers
 from astropy.coordinates import SkyCoord
 from astropy.utils import lazyproperty
-from ..utils.array import _is_int
-from ..utils.table import table_row_to_dict, table_from_row_data
+from gammapy.utils.table import table_from_row_data, table_row_to_dict
 
 __all__ = ["SourceCatalog", "SourceCatalogObject"]
 
 
+# https://pydanny.blogspot.com/2011/11/loving-bunch-class.html
+class Bunch(dict):
+    def __init__(self, **kw):
+        dict.__init__(self, kw)
+        self.__dict__.update(kw)
+
+
 class SourceCatalogObject:
     """Source catalog object.
 
@@ -18,21 +23,21 @@ class SourceCatalogObject:
     base class for the other source catalog classes.
 
     The catalog data on this source is stored in the `source.data`
-    attribute as on OrderedDict.
+    attribute as a dict.
 
     The source catalog object is decoupled from the source catalog,
-    it doesn't hold a reference back to it.
-    The catalog table row index is stored in `_table_row_index` though,
-    because it can be useful for debugging or display.
+    it doesn't hold a reference back to it, except for a key
+    ``_row_index`` of type ``int`` that links to the catalog table
+    row the source information comes from.
     """
 
     _source_name_key = "Source_Name"
-    _source_index_key = "catalog_row_index"
+    _row_index_key = "_row_index"
 
     def __init__(self, data, data_extended=None):
-        self.data = data
+        self.data = Bunch(**data)
         if data_extended:
-            self.data_extended = data_extended
+            self.data_extended = Bunch(**data_extended)
 
     @property
     def name(self):
@@ -41,33 +46,9 @@ class SourceCatalogObject:
         return name.strip()
 
     @property
-    def index(self):
+    def row_index(self):
         """Row index of source in catalog (int)"""
-        return self.data[self._source_index_key]
-
-    @property
-    def _data_python_dict(self):
-        """Convert ``data`` to a Python dict with Python types.
-
-        The dict is readily JSON or YAML serializable.
-        Quantity unit information is stripped.
-
-        This is mainly used at the moment to pass the data to
-        the gamma-sky.net webpage.
-        """
-        out = OrderedDict()
-        for key, value in self.data.items():
-            if isinstance(value, int):
-                out_val = value
-            else:
-                # This works because almost all values in ``data``
-                # are Numpy objects, and ``tolist`` works for Numpy
-                # arrays and scalars.
-                out_val = np.asarray(value).tolist()
-
-            out[key] = out_val
-
-        return out
+        return self.data[self._row_index_key]
 
     @property
     def position(self):
@@ -76,7 +57,7 @@ class SourceCatalogObject:
         return _skycoord_from_table(table)[0]
 
 
-class SourceCatalog:
+class SourceCatalog(abc.ABC):
     """Generic source catalog.
 
     This class can be used directly, but it's mostly used as a
@@ -96,11 +77,20 @@ class SourceCatalog:
         row by alias names as well.
     """
 
-    source_object_class = SourceCatalogObject
+    @classmethod
+    @abc.abstractmethod
+    def name(cls):
+        """Catalog name (str)."""
+        pass
 
-    # TODO: at the moment these are duplicated in SourceCatalogObject.
-    # Should we share them somehow?
-    _source_index_key = "catalog_row_index"
+    @classmethod
+    @abc.abstractmethod
+    def description(cls):
+        """Catalog description (str)."""
+        pass
+
+    source_object_class = SourceCatalogObject
+    """Source class (`SourceCatalogObject`)."""
 
     def __init__(self, table, source_name_key="Source_Name", source_name_alias=()):
         self.table = table
@@ -108,9 +98,12 @@ class SourceCatalog:
         self._source_name_alias = source_name_alias
 
     def __str__(self):
-        s = self.description
-        s += " with {} objects.".format(len(self.table))
-        return s
+        return (
+            f"{self.__class__.__name__}:\n"
+            f"    name: {self.name}\n"
+            f"    description: {self.description}\n"
+            f"    sources: {len(self.table)}\n"
+        )
 
     @lazyproperty
     def _name_to_index_cache(self):
@@ -149,6 +142,7 @@ class SourceCatalog:
         if name not in possible_names:
             self.__dict__.pop("_name_to_index_cache")
             index = self._name_to_index_cache[name]
+
         return index
 
     def source_name(self, index):
@@ -174,21 +168,14 @@ class SourceCatalog:
         Returns
         -------
         source : `SourceCatalogObject`
-            An object representing one source.
-
-        Notes
-        -----
-        At the moment this can raise KeyError, IndexError and ValueError
-        for invalid keys. Should we always raise KeyError to simplify this?
+            An object representing one source
         """
         if isinstance(key, str):
             index = self.row_index(key)
-        elif _is_int(key):
+        elif isinstance(key, numbers.Integral):
             index = key
         else:
-            msg = "Key must be source name string or row index integer. "
-            msg += "Type not understood: {}".format(type(key))
-            raise ValueError(msg)
+            raise TypeError(f"Invalid key: {key!r}, {type(key)}\n")
 
         return self._make_source_object(index)
 
@@ -206,13 +193,18 @@ class SourceCatalog:
             Source object
         """
         data = table_row_to_dict(self.table[index])
-        data[self._source_index_key] = index
+        data[SourceCatalogObject._row_index_key] = index
 
-        try:
+        if "Extended_Source_Name" in data:
             name_extended = data["Extended_Source_Name"].strip()
+        elif "Source_Name" in data:
+            name_extended = data["Source_Name"].strip()
+        else:
+            name_extended = None
+        try:
             idx = self._lookup_extended_source_idx[name_extended]
             data_extended = table_row_to_dict(self.extended_sources_table[idx])
-        except KeyError:
+        except (KeyError, AttributeError):
             data_extended = None
 
         source = self.source_object_class(data, data_extended)
@@ -224,33 +216,14 @@ class SourceCatalog:
         idx = range(len(names))
         return dict(zip(names, idx))
 
-    @property
-    def _data_python_list(self):
-        """Convert catalog to a Python list with Python types.
-
-        The list is readily JSON or YAML serializable.
-        Quantity unit information is stripped.
-
-        This is mainly used at the moment to pass the data to
-        the gamma-sky.net webpage.
-        """
-        return [source._data_python_dict for source in self]
-
     @property
     def positions(self):
         """Source positions (`~astropy.coordinates.SkyCoord`)."""
         return _skycoord_from_table(self.table)
 
-    def copy(self):
-        """Copy catalog"""
-        return copy.deepcopy(self)
-
 
 def _skycoord_from_table(table):
-    try:
-        keys = table.colnames
-    except AttributeError:
-        keys = list(table.keys())
+    keys = table.colnames
 
     if {"RAJ2000", "DEJ2000"}.issubset(keys):
         lon, lat, frame = "RAJ2000", "DEJ2000", "icrs"
@@ -258,10 +231,6 @@ def _skycoord_from_table(table):
         lon, lat, frame = "RA", "DEC", "icrs"
     elif {"ra", "dec"}.issubset(keys):
         lon, lat, frame = "ra", "dec", "icrs"
-    elif {"GLON", "GLAT"}.issubset(keys):
-        lon, lat, frame = "GLON", "GLAT", "galactic"
-    elif {"glon", "glat"}.issubset(keys):
-        lon, lat, frame = "glon", "glat", "galactic"
     else:
         raise KeyError("No column GLON / GLAT or RA / DEC or RAJ2000 / DEJ2000 found.")
 
