@@ -1,30 +1,35 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
-from collections import OrderedDict
 import numpy as np
 from numpy.testing import assert_allclose
-from astropy.table import Table, Column
+from astropy.table import Column, Table
 from astropy.units import Quantity
-from ...utils.testing import assert_quantity_allclose
-from ..core import SourceCatalog
+from gammapy.catalog import SourceCatalog
+from gammapy.utils.testing import assert_quantity_allclose
+
+
+class SomeSourceCatalog(SourceCatalog):
+    """Minimal test source catalog class for unit tests."""
+
+    name = "test123"
+    description = "Test source catalog"
 
 
 def make_test_catalog():
     table = Table()
     table["Source_Name"] = ["a", "bb", "ccc"]
-    table["RA"] = Column([42.2, 43.3, 44.4])
+    table["RA"] = Column([42.2, 43.3, 44.4], unit="deg")
     table["DEC"] = Column([1, 2, 3], unit="deg")
-
-    catalog = SourceCatalog(table)
-
-    return catalog
+    return SomeSourceCatalog(table)
 
 
 class TestSourceCatalog:
     def setup(self):
         self.cat = make_test_catalog()
 
+    def test_str(self):
+        assert "description" in str(self.cat)
+
     def test_table(self):
         assert_allclose(self.cat.table["RA"][1], 43.3)
 
@@ -42,10 +47,7 @@ class TestSourceCatalog:
         with pytest.raises(IndexError):
             self.cat.source_name(index=99)
 
-        # This seems to raise IndexError or ValueError with
-        # different Astropy versions, so we just check for
-        # any exception here
-        with pytest.raises(Exception):
+        with pytest.raises(IndexError):
             self.cat.source_name("invalid")
 
     def test_getitem(self):
@@ -55,7 +57,7 @@ class TestSourceCatalog:
         source = self.cat[0]
         assert source.data["Source_Name"] == "a"
 
-        source = self.cat[np.int(0)]
+        source = self.cat[np.int32(0)]
         assert source.data["Source_Name"] == "a"
 
         with pytest.raises(KeyError):
@@ -64,8 +66,8 @@ class TestSourceCatalog:
         with pytest.raises(IndexError):
             self.cat[99]
 
-        with pytest.raises(ValueError):
-            self.cat[int]
+        with pytest.raises(TypeError):
+            self.cat[1.2]
 
     def test_positions(self):
         positions = self.cat.positions
@@ -80,14 +82,20 @@ class TestSourceCatalogObject:
     def test_name(self):
         assert self.source.name == "bb"
 
-    def test_index(self):
-        assert self.source.index == 1
+    def test_row_index(self):
+        assert self.source.row_index == 1
 
     def test_data(self):
         d = self.source.data
-        assert isinstance(d, OrderedDict)
-        assert isinstance(d["RA"], float)
-        assert_allclose(d["RA"], 43.3)
+        assert isinstance(d, dict)
+
+        assert isinstance(d["RA"], Quantity)
+        assert_quantity_allclose(d["RA"], Quantity(43.3, "deg"))
 
         assert isinstance(d["DEC"], Quantity)
         assert_quantity_allclose(d["DEC"], Quantity(2, "deg"))
+
+    def test_position(self):
+        position = self.source.position
+        assert_allclose(position.ra.deg, 43.3)
+        assert_allclose(position.dec.deg, 2)
