@@ -1,11 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Sky cubes (3-dimensional: energy, lon, lat)."""
-from .counts import *
-from .exposure import *
 from .background import *
+from .edisp_map import *
+from .exposure import *
+from .fit import *
+from .fov import *
+from .make import *
 from .psf_kernel import *
 from .psf_map import *
-from .edisp_map import *
-from .make import *
-from .fit import *
+from .ring import *
 from .simulate import *
