@@ -1,10 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from copy import deepcopy
 import numpy as np
+from scipy.interpolate import interp1d
 import astropy.io.fits as fits
-import astropy.units as u
-from gammapy.irf import EnergyDispersion
-from gammapy.maps import Map, MapCoord, WcsGeom
+from gammapy.irf import EDispKernel
+from gammapy.maps import Map, MapAxis, MapCoord, WcsGeom
 from gammapy.utils.random import InverseCDFSampler, get_random_state
 
 __all__ = ["make_edisp_map", "EDispMap"]
@@ -105,7 +105,7 @@ class EDispMap:
         # Get an Energy Dispersion (1D) at any position in the image
         pos = SkyCoord(2.0, 2.5, unit="deg")
         e_reco = np.logspace(-1.0, 1.0, 10) * u.TeV
-        edisp = edisp_map.get_energy_dispersion(pos=pos, e_reco=e_reco)
+        edisp = edisp_map.get_edisp_kernel(pos=pos, e_reco=e_reco)
 
         # Write map to disk
         edisp_map.write("edisp_map.fits")
@@ -196,7 +196,7 @@ class EDispMap:
         hdulist = self.to_hdulist(**kwargs)
         hdulist.writeto(filename, overwrite=overwrite)
 
-    def get_energy_dispersion(self, position, e_reco, migra_step=5e-3):
+    def get_edisp_kernel(self, position, e_reco):
         """Get energy dispersion at a given position.
 
         Parameters
@@ -205,76 +205,58 @@ class EDispMap:
             the target position. Should be a single coordinates
         e_reco : `~astropy.units.Quantity`
             Reconstructed energy axis binning
-        migra_step : float
-            Integration step in migration
 
         Returns
         -------
         edisp : `~gammapy.irf.EnergyDispersion`
             the energy dispersion (i.e. rmf object)
         """
-        # TODO: reduce code duplication with EnergyDispersion2D.get_response
         if position.size != 1:
             raise ValueError(
                 "EnergyDispersion can be extracted at one single position only."
             )
 
-        # axes ordering fixed. Could be changed.
-        pix_ener = np.arange(self.edisp_map.geom.axes[1].nbin)
+        energy_axis = self.edisp_map.geom.get_axis_by_name("energy")
+        migra_axis = self.edisp_map.geom.get_axis_by_name("migra")
 
-        # Define a vector of migration with mig_step step
-        mrec_min = self.edisp_map.geom.axes[0].edges[0]
-        mrec_max = self.edisp_map.geom.axes[0].edges[-1]
-        mig_array = np.arange(mrec_min, mrec_max, migra_step)
-        pix_migra = (mig_array - mrec_min) / mrec_max * self.edisp_map.geom.axes[0].nbin
+        coords = {
+            "skycoord": position,
+            "migra": migra_axis.center.reshape((-1, 1, 1, 1)),
+            "energy": energy_axis.center.reshape((1, -1, 1, 1)),
+        }
 
-        # Convert position to pixels
-        pix_lon, pix_lat = self.edisp_map.geom.to_image().coord_to_pix(position)
-
-        # Build the pixels tuple
-        pix = np.meshgrid(pix_lon, pix_lat, pix_migra, pix_ener)
         # Interpolate in the EDisp map. Squeeze to remove dimensions of length 1
-        edisp_values = self.edisp_map.interp_by_pix(pix) * u.Unit(self.edisp_map.unit)
-        edisp_values = np.squeeze(edisp_values, axis=(0, 1))
+        values = self.edisp_map.interp_by_coord(coords) * self.edisp_map.unit
+        edisp_values = values.squeeze()
 
-        e_trues = self.edisp_map.geom.axes[1].center
         data = []
 
-        for i, e_true in enumerate(e_trues):
-            # We now perform integration over migra
-            # The code is adapted from `~gammapy.EnergyDispersion2D.get_response`
-
+        for idx, e_true in enumerate(energy_axis.center):
             # migration value of e_reco bounds
-            migra_e_reco = e_reco / e_true
+            migra = e_reco / e_true
 
-            # Compute normalized cumulative sum to prepare integration
-            tmp = np.nan_to_num(
-                np.cumsum(edisp_values[:, i]) / np.sum(edisp_values[:, i])
+            cumsum = np.insert(edisp_values[:, idx], 0, 0).cumsum()
+            with np.errstate(invalid="ignore"):
+                cumsum = np.nan_to_num(cumsum / cumsum[-1])
+
+            f = interp1d(
+                migra_axis.edges.value,
+                cumsum,
+                kind="linear",
+                bounds_error=False,
+                fill_value=(0, 1),
             )
 
-            # Determine positions (bin indices) of e_reco bounds in migration array
-            pos_mig = np.digitize(migra_e_reco, mig_array) - 1
-            # We ensure that no negative values are found
-            pos_mig = np.maximum(pos_mig, 0)
-
             # We compute the difference between 2 successive bounds in e_reco
             # to get integral over reco energy bin
-            integral = np.diff(tmp[pos_mig])
-
+            integral = np.diff(np.clip(f(migra), a_min=0, a_max=1))
             data.append(integral)
 
-        data = np.asarray(data)
-        # EnergyDispersion uses edges of true energy bins
-        e_true_edges = self.edisp_map.geom.axes[1].edges
-
-        e_lo, e_hi = e_true_edges[:-1], e_true_edges[1:]
-        ereco_lo, ereco_hi = (e_reco[:-1], e_reco[1:])
-
-        return EnergyDispersion(
-            e_true_lo=e_lo,
-            e_true_hi=e_hi,
-            e_reco_lo=ereco_lo,
-            e_reco_hi=ereco_hi,
+        return EDispKernel(
+            e_true_lo=energy_axis.edges[:-1],
+            e_true_hi=energy_axis.edges[1:],
+            e_reco_lo=e_reco[:-1],
+            e_reco_hi=e_reco[1:],
             data=data,
         )
 
@@ -333,8 +315,13 @@ class EDispMap:
 
         migra_axis = geom.get_axis_by_name("migra")
         edisp_map = Map.from_geom(geom, unit="")
-        loc = migra_axis.edges.searchsorted(1.0)
-        edisp_map.data[:, loc, :, :] = 1.0
+        migra_0 = migra_axis.coord_to_pix(1)
+
+        # distribute over two pixels
+        migra = geom.get_idx()[2]
+        data = np.abs(migra - migra_0)
+        data = np.where(data < 1, 1 - data, 0)
+        edisp_map.quantity = data
         return cls(edisp_map, exposure_edisp)
 
     def sample_coord(self, map_coord, random_state=0):
@@ -366,7 +353,9 @@ class EDispMap:
 
         sample_edisp = InverseCDFSampler(pdf_edisp, axis=1, random_state=random_state)
         pix_edisp = sample_edisp.sample_axis()
-        energy_reco = migra_axis.pix_to_coord(pix_edisp)
+        migra = migra_axis.pix_to_coord(pix_edisp)
+
+        energy_reco = map_coord["energy"] * migra
 
         return MapCoord.create({"skycoord": map_coord.skycoord, "energy": energy_reco})
 
@@ -386,12 +375,15 @@ class EDispMap:
         edisp_map : `EDispMap`
             Energy dispersion map.
         """
-        from .fit import MIGRA_AXIS_DEFAULT
+        migra_res = 1e-5
+        migra_axis_default = MapAxis.from_bounds(
+            1 - migra_res, 1 + migra_res, nbin=3, name="migra", node_type="edges"
+        )
 
-        migra_axis = migra_axis or MIGRA_AXIS_DEFAULT
+        migra_axis = migra_axis or migra_axis_default
 
         geom = WcsGeom.create(
-            npix=(4, 2), proj="CAR", binsz=90, axes=[migra_axis, energy_axis_true]
+            npix=(2, 1), proj="CAR", binsz=180, axes=[migra_axis, energy_axis_true]
         )
 
         return cls.from_geom(geom)
