@@ -19,6 +19,7 @@ from gammapy.modeling import Datasets, Fit
 from gammapy.modeling.models import (
     BackgroundModel,
     GaussianSpatialModel,
+    Models,
     PowerLawSpectralModel,
     SkyModel,
 )
@@ -33,7 +34,7 @@ def geom():
         skydir=(266.40498829, -28.93617776),
         binsz=0.02,
         width=(2, 2),
-        coordsys="CEL",
+        frame="icrs",
         axes=[axis],
     )
 
@@ -46,7 +47,7 @@ def geom_etrue():
         skydir=(266.40498829, -28.93617776),
         binsz=0.02,
         width=(2, 2),
-        coordsys="CEL",
+        frame="icrs",
         axes=[axis],
     )
 
@@ -56,7 +57,7 @@ def geom_image():
     ebounds_true = np.logspace(-1.0, 1.0, 2)
     axis = MapAxis.from_edges(ebounds_true, name="energy", unit=u.TeV, interp="log")
     return WcsGeom.create(
-        skydir=(0, 0), binsz=0.02, width=(2, 2), coordsys="GAL", axes=[axis]
+        skydir=(0, 0), binsz=0.02, width=(2, 2), frame="galactic", axes=[axis]
     )
 
 
@@ -140,6 +141,9 @@ def test_map_dataset_str(sky_model, geom, geom_etrue):
     assert "(frozen)" in str(dataset)
     assert "background" in str(dataset)
 
+    dataset.mask_safe = None
+    assert "MapDataset" in str(dataset)
+
 
 @requires_data()
 def test_fake(sky_model, geom, geom_etrue):
@@ -153,7 +157,7 @@ def test_fake(sky_model, geom, geom_etrue):
 
     assert real_dataset.counts.data.shape == dataset.counts.data.shape
     assert_allclose(real_dataset.counts.data.sum(), 8220.399727)
-    assert_allclose(dataset.counts.data.sum(), 8365)
+    assert_allclose(dataset.counts.data.sum(), 8375)
 
 
 @requires_data()
@@ -167,7 +171,7 @@ def test_different_exposure_unit(sky_model, geom):
         skydir=(266.40498829, -28.93617776),
         binsz=0.02,
         width=(2, 2),
-        coordsys="CEL",
+        frame="icrs",
         axes=[axis],
     )
 
@@ -186,22 +190,49 @@ def test_to_spectrum_dataset(sky_model, geom, geom_etrue):
 
     gti = GTI.create([0 * u.s], [1 * u.h], reference_time="2010-01-01T00:00:00")
     dataset_ref.gti = gti
-    on_region = CircleSkyRegion(center=geom.center_skydir, radius=0.1 * u.deg)
+    on_region = CircleSkyRegion(center=geom.center_skydir, radius=0.05 * u.deg)
     spectrum_dataset = dataset_ref.to_spectrum_dataset(on_region)
+    spectrum_dataset_corrected = dataset_ref.to_spectrum_dataset(
+        on_region, containment_correction=True
+    )
 
     assert np.sum(spectrum_dataset.counts.data) == 1
     assert spectrum_dataset.data_shape == (2,)
     assert spectrum_dataset.background.energy.nbin == 2
     assert spectrum_dataset.aeff.energy.nbin == 3
+    assert spectrum_dataset.aeff.data.data.unit == "m2"
     assert spectrum_dataset.edisp.e_reco.nbin == 2
     assert spectrum_dataset.edisp.e_true.nbin == 3
+    assert spectrum_dataset_corrected.aeff.data.data.unit == "m2"
+    assert_allclose(spectrum_dataset.aeff.data.data.value[1], 853023.423047, rtol=1e-5)
+    assert_allclose(
+        spectrum_dataset_corrected.aeff.data.data.value[1], 559476.3357, rtol=1e-5
+    )
 
 
+@requires_data()
 def test_to_image(geom):
+
+    counts = Map.read("$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-counts-cube.fits.gz")
+    background = Map.read(
+        "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-background-cube.fits.gz"
+    )
+    background = BackgroundModel(background)
+
+    exposure = Map.read(
+        "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-exposure-cube.fits.gz"
+    )
+    exposure = exposure.sum_over_axes(keepdims=True)
+    dataset = MapDataset(counts=counts, background_model=background, exposure=exposure)
+    dataset_im = dataset.to_image()
+    assert dataset_im.mask_safe is None
+    assert dataset_im.counts.data.sum() == dataset.counts.data.sum()
+    assert_allclose(dataset_im.background_model.map.data.sum(), 28548.625, rtol=1e-5)
+
     ebounds = np.logspace(-1.0, 1.0, 3)
     axis = MapAxis.from_edges(ebounds, name="energy", unit=u.TeV, interp="log")
     geom = WcsGeom.create(
-        skydir=(0, 0), binsz=0.5, width=(1, 1), coordsys="CEL", axes=[axis]
+        skydir=(0, 0), binsz=0.5, width=(1, 1), frame="icrs", axes=[axis]
     )
     dataset = MapDataset.create(geom)
 
@@ -210,12 +241,24 @@ def test_to_image(geom):
     dataset.mask_safe = WcsNDMap.from_geom(geom=geom, data=data)
 
     dataset_im = dataset.to_image()
-
     assert dataset_im.mask_safe.data.dtype == bool
 
     desired = np.array([[False, True], [True, True]])
     assert (dataset_im.mask_safe.data == desired).all()
 
+    # Check that missing entries in the dataset do not break
+    dataset_copy = dataset.copy()
+    dataset_copy.exposure = None
+    dataset_copy.background_model = None
+    dataset_im = dataset_copy.to_image()
+    assert dataset_im.exposure is None
+    assert dataset_im.background_model is None
+
+    dataset_copy = dataset.copy()
+    dataset_copy.counts = None
+    dataset_im = dataset_copy.to_image()
+    assert dataset_im.counts is None
+
 
 @requires_data()
 def test_map_dataset_fits_io(tmp_path, sky_model, geom, geom_etrue):
@@ -316,21 +359,21 @@ def test_map_fit(sky_model, geom, geom_etrue):
 
     npred = dataset_1.npred().data.sum()
     assert_allclose(npred, 6220.529956, rtol=1e-3)
-    assert_allclose(result.total_stat, 27040.706975, rtol=1e-3)
+    assert_allclose(result.total_stat, 26008.040889, rtol=1e-3)
 
     pars = result.parameters
     assert_allclose(pars["lon_0"].value, 0.2, rtol=1e-2)
-    assert_allclose(pars.error("lon_0"), 0.002651, rtol=1e-2)
+    assert_allclose(pars.error("lon_0"), 0.002622, rtol=1e-2)
 
     assert_allclose(pars["index"].value, 3, rtol=1e-2)
-    assert_allclose(pars.error("index"), 0.023899, rtol=1e-2)
+    assert_allclose(pars.error("index"), 0.028967, rtol=1e-2)
 
     assert_allclose(pars["amplitude"].value, 1e-11, rtol=1e-2)
-    assert_allclose(pars.error("amplitude"), 3.450585e-13, rtol=1e-2)
+    assert_allclose(pars.error("amplitude"), 4.086756e-13, rtol=1e-2)
 
     # background norm 1
     assert_allclose(pars[8].value, 0.5, rtol=1e-2)
-    assert_allclose(pars.error(pars[8]), 0.015759, rtol=1e-2)
+    assert_allclose(pars.error(pars[8]), 0.0156, rtol=1e-2)
 
     # background norm 2
     assert_allclose(pars[11].value, 1, rtol=1e-2)
@@ -342,7 +385,7 @@ def test_map_fit(sky_model, geom, geom_etrue):
     dataset_2.mask_safe = Map.from_geom(geom, data=mask_safe)
 
     stat = fit.datasets.stat_sum()
-    assert_allclose(stat, 14952.78696)
+    assert_allclose(stat, 14447.196919)
 
     # test model evaluation outside image
 
@@ -483,7 +526,7 @@ def test_stack(geom, geom_etrue):
     )
     dataset1.stack(dataset2)
     assert_allclose(dataset1.counts.data.sum(), 7987)
-    assert_allclose(dataset1.background_model.map.data.sum(), 5988)
+    assert_allclose(dataset1.background_model.map.data.sum(), 5987)
     assert_allclose(dataset1.exposure.data, 2.0 * dataset2.exposure.data)
     assert_allclose(dataset1.mask_safe.data.sum(), 20000)
 
@@ -498,6 +541,7 @@ def images():
         "acceptance": WcsNDMap.read(filename, hdu="ONEXPOSURE"),
         "acceptance_off": WcsNDMap.read(filename, hdu="OFFEXPOSURE"),
         "exposure": WcsNDMap.read(filename, hdu="EXPGAMMAMAP"),
+        "background": WcsNDMap.read(filename, hdu="BACKGROUND"),
     }
 
 
@@ -666,6 +710,7 @@ def test_stack_onoff_cutout(geom_image):
     assert_allclose(dataset.counts_off.data.sum(), dataset_cutout.counts_off.data.sum())
     assert_allclose(dataset.alpha.data.sum(), dataset_cutout.alpha.data.sum())
     assert_allclose(dataset.exposure.data.sum(), dataset_cutout.exposure.data.sum())
+    assert dataset_cutout.name != dataset.name
 
 
 def test_datasets_io_no_model(tmpdir):
@@ -683,3 +728,141 @@ def test_datasets_io_no_model(tmpdir):
 
     filename_2 = tmpdir / "test_data_2.fits"
     assert filename_2.exists()
+
+
+@requires_data()
+def test_mapdatasetonoff_to_spectrum_dataset(images):
+    e_reco = MapAxis.from_bounds(0.1, 10.0, 1, name="energy", unit=u.TeV, interp="log")
+    new_images = dict()
+    for key, image in images.items():
+        new_images[key] = Map.from_geom(
+            image.geom.to_cube([e_reco]), data=image.data[np.newaxis, :, :]
+        )
+    dataset = get_map_dataset_onoff(new_images)
+    gti = GTI.create([0 * u.s], [1 * u.h], reference_time="2010-01-01T00:00:00")
+    dataset.gti = gti
+
+    on_region = CircleSkyRegion(
+        center=dataset.counts.geom.center_skydir, radius=0.1 * u.deg
+    )
+    spectrum_dataset = dataset.to_spectrum_dataset(on_region)
+
+    assert spectrum_dataset.counts.data[0] == 8
+    assert spectrum_dataset.data_shape == (1,)
+    assert spectrum_dataset.counts_off.data[0] == 33914
+    assert_allclose(spectrum_dataset.alpha.data[0], 0.0002143, atol=1e-7)
+
+    excess_map = new_images["counts"] - new_images["background"]
+    excess_true = excess_map.get_spectrum(on_region, np.sum).data[0]
+
+    excess = spectrum_dataset.excess.data[0]
+    assert_allclose(excess, excess_true, atol=1e-6)
+
+    assert spectrum_dataset.name != dataset.name
+
+
+@requires_data()
+def test_mapdatasetonoff_cutout(images):
+    dataset = get_map_dataset_onoff(images)
+    gti = GTI.create([0 * u.s], [1 * u.h], reference_time="2010-01-01T00:00:00")
+    dataset.gti = gti
+
+    cutout_dataset = dataset.cutout(
+        images["counts"].geom.center_skydir, ["1 deg", "1 deg"]
+    )
+
+    assert cutout_dataset.counts.data.shape == (50, 50)
+    assert cutout_dataset.counts_off.data.shape == (50, 50)
+    assert cutout_dataset.acceptance.data.shape == (50, 50)
+    assert cutout_dataset.acceptance_off.data.shape == (50, 50)
+    assert cutout_dataset.background_model is None
+    assert cutout_dataset.name != dataset.name
+
+
+@requires_data()
+def test_mapdatasetonoff_to_image():
+    axis = MapAxis.from_energy_bounds(1, 10, 2, unit="TeV")
+    geom = WcsGeom.create(npix=(10, 10), binsz=0.05, axes=[axis])
+
+    counts = Map.from_geom(geom, data=np.ones((2, 10, 10)))
+    counts_off = Map.from_geom(geom, data=np.ones((2, 10, 10)))
+    acceptance = Map.from_geom(geom, data=np.ones((2, 10, 10)))
+    acceptance_off = Map.from_geom(geom, data=np.ones((2, 10, 10)))
+    acceptance_off *= 2
+
+    dataset = MapDatasetOnOff(
+        counts=counts,
+        counts_off=counts_off,
+        acceptance=acceptance,
+        acceptance_off=acceptance_off,
+    )
+    image_dataset = dataset.to_image()
+
+    assert image_dataset.counts.data.shape == (1, 10, 10)
+    assert image_dataset.acceptance_off.data.shape == (1, 10, 10)
+    assert_allclose(image_dataset.acceptance, 2)
+    assert_allclose(image_dataset.acceptance_off, 4)
+    assert_allclose(image_dataset.counts_off, 2)
+    assert image_dataset.name != dataset.name
+
+    # Try with a safe_mask
+    mask_safe = Map.from_geom(geom, data=np.ones((2, 10, 10), dtype="bool"))
+    mask_safe.data[0] = 0
+    dataset.mask_safe = mask_safe
+    image_dataset = dataset.to_image()
+
+    assert_allclose(image_dataset.acceptance, 1)
+    assert_allclose(image_dataset.acceptance_off, 2)
+    assert_allclose(image_dataset.counts_off, 1)
+
+
+def test_map_dataset_geom(geom, sky_model):
+    e_true = MapAxis.from_energy_bounds("1 TeV", "10 TeV", nbin=5)
+    dataset = MapDataset.create(geom, energy_axis_true=e_true)
+    dataset.counts = None
+    dataset.background_model = None
+
+    dataset.models = sky_model
+
+    npred = dataset.npred()
+    assert npred.geom == geom
+
+    dataset.mask_safe = None
+
+    with pytest.raises(ValueError):
+        dataset._geom
+
+
+@requires_data()
+def test_names(geom, geom_etrue, sky_model):
+
+    m = Map.from_geom(geom)
+    m.quantity = 0.2 * np.ones(m.data.shape)
+    background_model1 = BackgroundModel(m, name="bkg1")
+    assert background_model1.name == "bkg1"
+
+    c_map1 = Map.from_geom(geom)
+    c_map1.quantity = 0.3 * np.ones(c_map1.data.shape)
+
+    model1 = sky_model.copy()
+    assert model1.name != sky_model.name
+    model1 = sky_model.copy(name="model1")
+    assert model1.name == "model1"
+    model2 = sky_model.copy(name="model2")
+
+    dataset1 = MapDataset(
+        counts=c_map1,
+        background_model=background_model1,
+        models=Models([model1, model2]),
+        exposure=get_exposure(geom_etrue),
+    )
+
+    dataset2 = dataset1.copy()
+    assert dataset2.name != dataset1.name
+    assert dataset2.background_model
+    dataset2 = dataset1.copy(name="dataset2")
+    assert dataset2.name == "dataset2"
+    assert dataset2.background_model.name == "bkg1"
+    assert dataset1.background_model is not dataset2.background_model
+    assert dataset1.models.names == dataset2.models.names
+    assert dataset1.models is not dataset2.models
