@@ -23,7 +23,7 @@ def geom(ebounds, binsz=0.5):
     skydir = SkyCoord(0, -1, unit="deg", frame="galactic")
     energy_axis = MapAxis.from_edges(ebounds, name="energy", unit="TeV", interp="log")
     return WcsGeom.create(
-        skydir=skydir, binsz=binsz, width=(10, 5), coordsys="GAL", axes=[energy_axis]
+        skydir=skydir, binsz=binsz, width=(10, 5), frame="galactic", axes=[energy_axis]
     )
 
 
@@ -150,7 +150,9 @@ def test_map_maker_ring(observations):
     )
 
     for obs in observations:
-        cutout = stacked.cutout(position=obs.pointing_radec, width="4 deg")
+        cutout = stacked.cutout(
+            position=obs.pointing_radec, width="4 deg", mode="partial"
+        )
         dataset = map_dataset_maker.run(cutout, obs)
         dataset = safe_mask_maker.run(dataset, obs)
 
@@ -160,7 +162,7 @@ def test_map_maker_ring(observations):
         stacked.stack(dataset_on_off)
 
     assert_allclose(np.nansum(stacked.counts.data), 34366, rtol=1e-2)
-    assert_allclose(np.nansum(stacked.acceptance_off.data), 434.36, rtol=1e-2)
+    assert_allclose(np.nansum(stacked.acceptance_off.data), 278.142796, rtol=1e-2)
 
 
 @requires_data()
@@ -188,7 +190,6 @@ def test_map_maker_obs(observations):
     assert map_dataset.psf.psf_map.data.shape == (3, 66, 5, 10)
     assert map_dataset.psf.exposure_map.data.shape == (3, 1, 5, 10)
     assert_allclose(map_dataset.gti.time_delta, 1800.0 * u.s)
-    assert map_dataset.name == "obs_110380"
 
 
 @requires_data()
@@ -217,7 +218,7 @@ def test_safe_mask_maker(observations):
     assert_allclose(mask_energy_aeff_default.sum(), 1936)
 
     mask_edisp_bias = safe_mask_maker.make_mask_energy_edisp_bias(dataset)
-    assert_allclose(mask_edisp_bias.sum(), 1815)
+    assert_allclose(mask_edisp_bias.sum(), 121)
 
     mask_bkg_peak = safe_mask_maker.make_mask_energy_bkg_peak(dataset)
     assert_allclose(mask_bkg_peak.sum(), 1815)
