@@ -2,14 +2,13 @@
 import logging
 import subprocess
 from pathlib import Path
-from astropy.io import fits
 from astropy.coordinates import SkyCoord
-from ..utils.scripts import make_path
-from ..utils.testing import Checker
-from .obs_table import ObservationTable
+from astropy.io import fits
+from gammapy.utils.scripts import make_path
+from gammapy.utils.testing import Checker
 from .hdu_index_table import HDUIndexTable
-from .obs_table import ObservationTableChecker
-from .observations import DataStoreObservation, Observations, ObservationChecker
+from .obs_table import ObservationTable, ObservationTableChecker
+from .observations import DataStoreObservation, ObservationChecker, Observations
 
 __all__ = ["DataStore"]
 
@@ -22,7 +21,7 @@ class DataStore:
     The data selection and access happens using an observation
     and an HDU index file as described at :ref:`gadf:iact-storage`.
 
-    For a usage example see :gp-notebook:`cta_1dc_introduction`
+    For a usage example see `cta.html <../notebooks/cta.html>`__
 
     Parameters
     ----------
@@ -110,34 +109,18 @@ class DataStore:
             obs_table_filename = base_dir / cls.DEFAULT_OBS_TABLE
 
         if not hdu_table_filename.exists():
-            raise IOError("File not found: {}".format(hdu_table_filename))
-        log.debug("Reading {}".format(hdu_table_filename))
-        hdu_table = HDUIndexTable.read(str(hdu_table_filename), format="fits")
+            raise OSError(f"File not found: {hdu_table_filename}")
+        log.debug(f"Reading {hdu_table_filename}")
+        hdu_table = HDUIndexTable.read(hdu_table_filename, format="fits")
         hdu_table.meta["BASE_DIR"] = str(base_dir)
 
         if not obs_table_filename.exists():
-            raise IOError("File not found: {}".format(obs_table_filename))
-        log.debug("Reading {}".format(str(obs_table_filename)))
-        obs_table = ObservationTable.read(str(obs_table_filename), format="fits")
+            raise OSError(f"File not found: {obs_table_filename}")
+        log.debug(f"Reading {obs_table_filename}")
+        obs_table = ObservationTable.read(obs_table_filename, format="fits")
 
         return cls(hdu_table=hdu_table, obs_table=obs_table)
 
-    @classmethod
-    def from_config(cls, config):
-        """Create from a config dict."""
-        base_dir = config["base_dir"]
-        hdu_table_filename = config.get("hduindx", cls.DEFAULT_HDU_TABLE)
-        obs_table_filename = config.get("obsindx", cls.DEFAULT_OBS_TABLE)
-
-        hdu_table_filename = cls._find_file(hdu_table_filename, base_dir)
-        obs_table_filename = cls._find_file(obs_table_filename, base_dir)
-
-        return cls.from_files(
-            base_dir=base_dir,
-            hdu_table_filename=hdu_table_filename,
-            obs_table_filename=obs_table_filename,
-        )
-
     @classmethod
     def from_events_files(cls, paths):
         """Create from a list of event filenames.
@@ -188,26 +171,6 @@ class DataStore:
         """
         return DataStoreMaker(paths).run()
 
-    @staticmethod
-    def _find_file(filename, dir):
-        """Find a file at an absolute or relative location.
-
-        - First tries ``Path(filename)``
-        - Second tries ``Path(dir) / filename``
-        - Raises ``OSError`` if both don't exist.
-        """
-        path1 = make_path(filename)
-        path2 = make_path(dir) / filename
-
-        if path1.is_file():
-            filename = path1
-        elif path2.is_file():
-            filename = path2
-        else:
-            raise OSError("File not found at {} or {}".format(path1, path2))
-
-        return filename
-
     def info(self, show=True):
         """Print some info."""
         s = "Data store:\n"
@@ -259,7 +222,7 @@ class DataStore:
                 obs = self.obs(_)
             except ValueError as err:
                 if skip_missing:
-                    log.warning("Skipping missing obs_id: {!r}".format(_))
+                    log.warning(f"Skipping missing obs_id: {_!r}")
                     continue
                 else:
                     raise err
@@ -283,9 +246,11 @@ class DataStore:
         overwrite : bool
             Overwrite
         """
-        # TODO : Does rsync give any benefits here?
-
         outdir = make_path(outdir)
+
+        if not outdir.is_dir():
+            raise OSError(f"Not a directory: outdir={outdir}")
+
         if isinstance(obs_id, ObservationTable):
             obs_id = obs_id["OBS_ID"].data
 
@@ -304,17 +269,19 @@ class DataStore:
             loc = subhdutable.location_info(idx)
             targetdir = outdir / loc.file_dir
             targetdir.mkdir(exist_ok=True, parents=True)
-            cmd = ["cp", "-v"] if verbose else ["cp"]
+            cmd = ["cp"]
+            if verbose:
+                cmd += ["-v"]
             if not overwrite:
                 cmd += ["-n"]
             cmd += [str(loc.path()), str(targetdir)]
             subprocess.run(cmd)
 
-        filename = str(outdir / self.DEFAULT_HDU_TABLE)
+        filename = outdir / self.DEFAULT_HDU_TABLE
         subhdutable.write(filename, format="fits", overwrite=overwrite)
 
-        filename = str(outdir / self.DEFAULT_OBS_TABLE)
-        subobstable.write(filename, format="fits", overwrite=overwrite)
+        filename = outdir / self.DEFAULT_OBS_TABLE
+        subobstable.write(str(filename), format="fits", overwrite=overwrite)
 
     def check(self, checks="all"):
         """Check index tables and data files.
@@ -370,7 +337,7 @@ class DataStoreChecker(Checker):
             except KeyError:
                 yield {
                     "level": "error",
-                    "msg": "HDU not found: {!r}".format(location_info.__dict__),
+                    "msg": f"HDU not found: {location_info.__dict__!r}",
                 }
 
     def check_consistency(self):
@@ -426,8 +393,8 @@ class DataStoreMaker:
 
     @staticmethod
     def read_events_info(path):
-        log.debug("Reading {}".format(path))
-        with fits.open(str(path)) as hdu_list:
+        log.debug(f"Reading {path}")
+        with fits.open(path, memmap=False) as hdu_list:
             header = hdu_list["EVENTS"].header
 
         na_int, na_str = -1, "NOT AVAILABLE"
@@ -556,7 +523,7 @@ class DataStoreMaker:
             HDU_TYPE="psf",
             HDU_CLASS="psf_3gauss",
             HDU_NAME="POINT SPREAD FUNCTION",
-            **info
+            **info,
         )
         yield dict(HDU_TYPE="bkg", HDU_CLASS="bkg_3d", HDU_NAME="BACKGROUND", **info)
 
@@ -578,7 +545,7 @@ class CalDBIRF:
     def file_dir(self):
         # In CTA 1DC the header key is "CTA", but the directory is lower-case "cta"
         telescop = self.telescop.lower()
-        return "$CALDB/data/{}/{}/bcf/{}".format(telescop, self.caldb, self.irf)
+        return f"$CALDB/data/{telescop}/{self.caldb}/bcf/{self.irf}"
 
     @property
     def file_name(self):
