@@ -1,18 +1,18 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import collections
 import logging
-from collections import namedtuple
 import numpy as np
-from astropy.units import Quantity, Unit
-from astropy.coordinates import SkyCoord, Angle, AltAz
+from astropy.coordinates import AltAz, Angle, SkyCoord
 from astropy.coordinates.angle_utilities import angular_separation
 from astropy.table import Table
 from astropy.table import vstack as vstack_tables
-from ..utils.energy import energy_logspace
-from ..utils.fits import earth_location_from_dict
-from ..utils.scripts import make_path
-from ..utils.time import time_ref_from_dict
-from ..utils.testing import Checker
-from ..utils.regions import make_region
+from astropy.units import Quantity, Unit
+from gammapy.maps import MapAxis, MapCoord, WcsNDMap
+from gammapy.utils.fits import earth_location_from_dict
+from gammapy.utils.regions import make_region
+from gammapy.utils.scripts import make_path
+from gammapy.utils.testing import Checker
+from gammapy.utils.time import time_ref_from_dict
 
 __all__ = ["EventListBase", "EventList", "EventListLAT"]
 
@@ -35,6 +35,10 @@ class EventListBase:
     - ``RA``, ``DEC`` - ICRS system position (deg)
     - ``ENERGY`` - Energy (usually MeV for Fermi and TeV for IACTs)
 
+    Note that ``TIME`` is usually sorted, but sometimes it is not.
+    E.g. when simulating data, or processing it in certain ways.
+    So generally any analysis code should assume ``TIME`` is not sorted.
+
     Other optional (columns) that are sometimes useful for high-level analysis:
 
     - ``GLON``, ``GLAT`` - Galactic coordinates (deg)
@@ -56,13 +60,6 @@ class EventListBase:
     """
 
     def __init__(self, table):
-
-        # TODO: remove this temp fix once we drop support for `hess-hd-hap-prod2`
-        # There the unit wasn't set correctly in the FITS table, so this hack is needed.
-        if "ENERGY" in table.colnames:
-            if not table["ENERGY"].unit:
-                table["ENERGY"].unit = "TeV"
-
         self.table = table
 
     @classmethod
@@ -78,7 +75,7 @@ class EventListBase:
         """
         filename = make_path(filename)
         kwargs.setdefault("hdu", "EVENTS")
-        table = Table.read(str(filename), **kwargs)
+        table = Table.read(filename, **kwargs)
         return cls(table=table)
 
     @classmethod
@@ -99,10 +96,8 @@ class EventListBase:
     def __str__(self):
         ss = (
             "EventList info:\n"
-            + "- Number of events: {}\n".format(len(self.table))
-            + "- Median energy: {:.3g} {}\n".format(
-                np.median(self.energy.value), self.energy.unit
-            )
+            f"- Number of events: {len(self.table)}\n"
+            f"- Median energy: {np.median(self.energy.value):.3g} {self.energy.unit}\n"
         )
 
         if "OBS_ID" in self.table.meta:
@@ -149,8 +144,7 @@ class EventListBase:
 
     @property
     def radec(self):
-        """Event RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`).
-        """
+        """Event RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`)."""
         lon, lat = self.table["RA"], self.table["DEC"]
         return SkyCoord(lon, lat, unit="deg", frame="icrs")
 
@@ -162,50 +156,6 @@ class EventListBase:
         """
         return self.radec.galactic
 
-    @property
-    def observation_live_time_duration(self):
-        """Live-time duration in seconds (`~astropy.units.Quantity`).
-
-        The dead-time-corrected observation time.
-
-        - In Fermi-LAT it is automatically provided in the header of the event list.
-        - In IACTs is computed as ``t_live = t_observation * (1 - f_dead)``
-
-        where ``f_dead`` is the dead-time fraction.
-        """
-        return Quantity(self.table.meta["LIVETIME"], "second")
-
-    @property
-    def observation_dead_time_fraction(self):
-        """Dead-time fraction (float).
-
-        Defined as dead-time over observation time.
-
-        Dead-time is defined as the time during the observation
-        where the detector didn't record events:
-        https://en.wikipedia.org/wiki/Dead_time
-        https://ui.adsabs.harvard.edu/abs/2004APh....22..285F
-
-        The dead-time fraction is used in the live-time computation,
-        which in turn is used in the exposure and flux computation.
-        """
-        return 1 - self.table.meta["DEADC"]
-
-    @property
-    def pointing_radec(self):
-        """Pointing RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`)."""
-        info = self.table.meta
-        lon, lat = info["RA_PNT"], info["DEC_PNT"]
-        return SkyCoord(lon, lat, unit="deg", frame="icrs")
-
-    @property
-    def offset(self):
-        """Event offset from the array pointing position (`~astropy.coordinates.Angle`)."""
-        position = self.radec
-        center = self.pointing_radec
-        offset = center.separation(position)
-        return Angle(offset, unit="deg")
-
     @property
     def energy(self):
         """Event energies (`~astropy.units.Quantity`)."""
@@ -332,15 +282,15 @@ class EventListBase:
 
     def _default_plot_ebounds(self):
         energy = self.energy
-        return energy_logspace(energy.min(), energy.max(), 50)
+        return MapAxis.from_energy_bounds(energy.min(), energy.max(), 50).edges
 
     def _counts_spectrum(self, ebounds):
-        from ..spectrum import CountsSpectrum
+        from gammapy.spectrum import CountsSpectrum
 
         if not ebounds:
             ebounds = self._default_plot_ebounds()
         spec = CountsSpectrum(energy_lo=ebounds[:-1], energy_hi=ebounds[1:])
-        spec.fill(self.energy)
+        spec.fill_energy(self.energy)
         return spec
 
     def plot_energy(self, ax=None, ebounds=None, **kwargs):
@@ -460,17 +410,19 @@ class EventListBase:
 
         ax = plt.gca() if ax is None else ax
 
-        energy_bounds = self._default_plot_ebounds()
+        energy_bounds = self._default_plot_ebounds().to_value("TeV")
         offset_bounds = np.linspace(0, 4, 30)
 
         counts = np.histogram2d(
-            x=self.energy, y=self.offset, bins=(energy_bounds, offset_bounds)
+            x=self.energy.value,
+            y=self.offset.value,
+            bins=(energy_bounds, offset_bounds),
         )[0]
 
         ax.pcolormesh(energy_bounds, offset_bounds, counts.T, norm=LogNorm())
         ax.set_xscale("log")
-        ax.set_xlabel("Energy (TeV)")
-        ax.set_ylabel("Offset (deg)")
+        ax.set_xlabel(f"Energy ({self.energy.unit})")
+        ax.set_ylabel(f"Offset ({self.offset.unit})")
 
     def check(self, checks="all"):
         """Run checks.
@@ -480,19 +432,20 @@ class EventListBase:
         checker = EventListChecker(self)
         return checker.run(checks=checks)
 
-    def _get_coord_from_geom(self, geom):
-        """Return MapCoord of the EventList relative to an input geometry.
+    def map_coord(self, geom):
+        """Event map coordinates for a given geometry.
 
         Parameters
         ----------
-        geom : `~gammapy.maps.MapGeom`
-            the geom used to define the MapCoord
+        geom : `~gammapy.maps.Geom`
+            Geometry
 
         Returns
         -------
-        mapcoord : `~gammapy.Map.MapCoord`
+        coord : `~gammapy.maps.MapCoord`
+            Coordinates
         """
-        coord = dict(skycoord=self.radec)
+        coord = {"skycoord": self.radec}
 
         cols = {k.upper(): v for k, v in self.table.columns.items()}
 
@@ -501,23 +454,19 @@ class EventListBase:
                 col = cols[axis.name.upper()]
                 coord[axis.name] = Quantity(col).to(axis.unit)
             except KeyError:
-                raise KeyError("Column not found in event list: {!r}".format(axis.name))
+                raise KeyError(f"Column not found in event list: {axis.name!r}")
 
-        return coord
+        return MapCoord.create(coord)
 
     def select_map_mask(self, mask):
-        """Return EventList contained in a Map mask.
+        """Select events inside a mask (`EventList`).
 
         Parameters
         ----------
         mask : `~gammapy.maps.Map`
-            the mask to be used
-
-        Returns
-        -------
-        eventlist : `~gammapy.data.EventList`
+            Mask
         """
-        coord = self._get_coord_from_geom(mask.geom)
+        coord = self.map_coord(mask.geom)
         values = mask.get_by_coord(coord)
         valid = values > 0
         return self.select_row_subset(valid)
@@ -558,6 +507,19 @@ class EventList(EventListBase):
         """
         return Quantity(self.table.meta["ONTIME"], "second")
 
+    @property
+    def observation_live_time_duration(self):
+        """Live-time duration in seconds (`~astropy.units.Quantity`).
+
+        The dead-time-corrected observation time.
+
+        - In Fermi-LAT it is automatically provided in the header of the event list.
+        - In IACTs is computed as ``t_live = t_observation * (1 - f_dead)``
+
+        where ``f_dead`` is the dead-time fraction.
+        """
+        return Quantity(self.table.meta["LIVETIME"], "second")
+
     @property
     def observation_dead_time_fraction(self):
         """Dead-time fraction (float).
@@ -653,13 +615,11 @@ class EventList(EventListBase):
         ax.text(0, 1, txt, fontsize=12, verticalalignment="top")
 
     def _counts_image(self):
-        from ..maps import WcsNDMap
-
         opts = {
             "width": (7, 7),
             "binsz": 0.1,
             "proj": "TAN",
-            "coordsys": "GAL",
+            "frame": "galactic",
             "skydir": self.pointing_radec,
         }
         m = WcsNDMap.create(**opts)
@@ -699,9 +659,9 @@ class EventListLAT(EventListBase):
 
     def plot_image(self):
         """Quick look counts map sky plot."""
-        from ..maps import WcsNDMap
+        from gammapy.maps import WcsNDMap
 
-        m = WcsNDMap.create(npix=(360, 180), binsz=1.0, proj="AIT", coordsys="GAL")
+        m = WcsNDMap.create(npix=(360, 180), binsz=1.0, proj="AIT", frame="galactic")
         m.fill_by_coord(self.radec)
         m.plot(stretch="sqrt")
 
@@ -763,7 +723,7 @@ class EventListChecker(Checker):
         "ALTITUDE",
     ]
 
-    _col = namedtuple("col", ["name", "unit"])
+    _col = collections.namedtuple("col", ["name", "unit"])
     columns_required = [
         _col(name="EVENT_ID", unit=""),
         _col(name="TIME", unit="s"),
@@ -783,7 +743,7 @@ class EventListChecker(Checker):
         meta_missing = sorted(set(self.meta_required) - set(self.event_list.table.meta))
         if meta_missing:
             yield self._record(
-                level="error", msg="Missing meta keys: {!r}".format(meta_missing)
+                level="error", msg=f"Missing meta keys: {meta_missing!r}"
             )
 
     def check_columns(self):
@@ -794,13 +754,11 @@ class EventListChecker(Checker):
 
         for name, unit in self.columns_required:
             if name not in t.colnames:
-                yield self._record(
-                    level="error", msg="Missing table column: {!r}".format(name)
-                )
+                yield self._record(level="error", msg=f"Missing table column: {name!r}")
             else:
                 if Unit(unit) != (t[name].unit or ""):
                     yield self._record(
-                        level="error", msg="Invalid unit for column: {!r}".format(name)
+                        level="error", msg=f"Invalid unit for column: {name!r}"
                     )
 
     def check_times(self):
