@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import copy
 import logging
 
@@ -8,7 +7,7 @@ __all__ = ["ObservationFilter"]
 log = logging.getLogger(__name__)
 
 
-class ObservationFilter(object):
+class ObservationFilter:
     """Holds and applies filters to observation data.
 
     Parameters
@@ -39,16 +38,14 @@ class ObservationFilter(object):
     >>> my_obs = DataStoreObservation(obs_id=111630, data_store=ds, obs_filter=my_obs_filter)
     """
 
-    EVENT_FILTER_TYPES = dict(
-        circular_region="select_circular_region", custom="select_parameter"
-    )
+    EVENT_FILTER_TYPES = dict(sky_region="select_region", custom="select_parameter")
 
     def __init__(self, time_filter=None, event_filters=None):
         self.time_filter = time_filter
         self.event_filters = event_filters or []
 
     def filter_events(self, events):
-        """Applies the filters to an event list
+        """Apply filters to an event list.
 
         Parameters
         ----------
@@ -69,7 +66,7 @@ class ObservationFilter(object):
         return filtered_events
 
     def filter_gti(self, gti):
-        """Applies the filters to a GTI table
+        """Apply filters to a GTI table.
 
         Parameters
         ----------
@@ -81,9 +78,7 @@ class ObservationFilter(object):
         filtered_gti : `~gammapy.data.GTI`
             The filtered GTI table
         """
-        filtered_gti = self._filter_by_time(gti)
-
-        return filtered_gti
+        return self._filter_by_time(gti)
 
     def _filter_by_time(self, data):
         """Returns a new time filtered data object.
