@@ -1,10 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Source detection and measurement methods.
-"""
+"""Source detection and measurement methods."""
+from .asmooth import *
+from .find import *
 from .kernel import *
-from .cwt import *
-from .iterfind import *
-from .matched_filter import *
-from .test_statistics import *
 from .lima import *
+from .test_statistics import *
