@@ -1,11 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import logging
 import numpy as np
-from scipy.ndimage import binary_erosion
-from scipy.ndimage.morphology import binary_fill_holes
+import scipy.ndimage
+from astropy.convolution import CustomKernel, Tophat2DKernel
 from astropy.coordinates import Angle
-from astropy.convolution import Tophat2DKernel, CustomKernel
-from ..maps import Map
+from gammapy.maps import Map
 from .lima import compute_lima_image
 
 log = logging.getLogger(__name__)
@@ -44,8 +43,8 @@ class KernelBackgroundEstimator:
 
     See Also
     --------
-    gammapy.background.RingBackgroundEstimator,
-    gammapy.background.AdaptiveRingBackgroundEstimator
+    gammapy.cube.RingBackgroundEstimator,
+    gammapy.cube.AdaptiveRingBackgroundEstimator
 
     Examples
     --------
@@ -132,10 +131,7 @@ class KernelBackgroundEstimator:
                 self.images_stack.append(result)
 
             if self._is_converged(result, images) and (idx >= niter_min):
-                log.info(
-                    "Exclusion mask succesfully converged,"
-                    " after {} iterations.".format(idx)
-                )
+                log.info(f"Exclusion mask converged after {idx} iterations.")
                 break
 
         return result
@@ -176,14 +172,15 @@ class KernelBackgroundEstimator:
         mask = (
             significance.data < self.parameters["significance_threshold"]
         ) | np.isnan(significance.data)
-        mask = binary_erosion(mask, structure, border_value=1)
+        mask = scipy.ndimage.binary_erosion(mask, structure, border_value=1)
 
         return counts.copy(data=mask.astype("float"))
 
     def _estimate_background(self, counts, exclusion):
-        """
-        Estimate background by convolving the excluded counts image with
-        the background kernel and renormalizing the image.
+        """Estimate background image.
+
+        Method: convolve the excluded counts image with
+        the background kernel and re-normalise the image.
         """
         counts_excluded = counts.copy(data=counts.data * exclusion.data)
         vals = counts_excluded.convolve(self.kernel_bkg)
@@ -200,5 +197,5 @@ class KernelBackgroundEstimator:
 
         # Because of pixel to pixel noise, the masks can still differ.
         # This is handled by removing structures of the scale of one pixel
-        mask = binary_fill_holes(mask)
+        mask = scipy.ndimage.binary_fill_holes(mask)
         return np.all(mask)
