@@ -1,9 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import copy
 import logging
 import numpy as np
-from ..stats import significance, significance_on_off
+from gammapy.stats import significance, significance_on_off
 
 __all__ = ["compute_lima_image", "compute_lima_on_off_image"]
 
@@ -73,7 +72,7 @@ def compute_lima_on_off_image(n_on, n_off, a_on, a_off, kernel):
         Dictionary containing result maps
         Keys are: significance, n_on, background, excess, alpha
 
-    See also
+    See Also
     --------
     gammapy.stats.significance_on_off
     """
@@ -85,7 +84,9 @@ def compute_lima_on_off_image(n_on, n_off, a_on, a_off, kernel):
     # np.rint
     n_on_conv = np.rint(n_on.convolve(kernel.array).data)
     a_on_conv = a_on.convolve(kernel.array).data
-    alpha_conv = a_on_conv / a_off.data
+
+    with np.errstate(invalid="ignore", divide="ignore"):
+        alpha_conv = a_on_conv / a_off.data
 
     significance_conv = significance_on_off(
         n_on_conv, n_off.data, alpha_conv, method="lima"
