@@ -1,13 +1,13 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from collections import OrderedDict
 import numpy as np
-from astropy.table import Table
-from astropy.io import fits
 import astropy.units as u
-from ..maps import MapAxis
-from ..maps.utils import edges_from_lo_hi
-from ..utils.nddata import NDDataArray
-from ..utils.scripts import make_path
+from astropy.io import fits
+from astropy.table import Table
+from gammapy.maps import MapAxis
+from gammapy.maps.utils import edges_from_lo_hi
+from gammapy.utils.integrate import trapz_loglog
+from gammapy.utils.nddata import NDDataArray
+from gammapy.utils.scripts import make_path
 
 __all__ = ["Background3D", "Background2D"]
 
@@ -61,7 +61,6 @@ class Background3D:
         meta=None,
         interp_kwargs=None,
     ):
-
         if interp_kwargs is None:
             interp_kwargs = self.default_interp_kwargs
 
@@ -79,11 +78,11 @@ class Background3D:
             data=data,
             interp_kwargs=interp_kwargs,
         )
-        self.meta = OrderedDict(meta) if meta else OrderedDict()
+        self.meta = meta or {}
 
     def __str__(self):
         ss = self.__class__.__name__
-        ss += "\n{}".format(self.data)
+        ss += f"\n{self.data}"
         return ss
 
     @classmethod
@@ -99,7 +98,7 @@ class Background3D:
             raise ValueError('Invalid column names. Need "BKG" or "BGD".')
 
         # Currently some files (e.g. CTA 1DC) contain unit in the FITS file
-        # '1/s/MeV/sr', which is invalid ( try: astropy.unit.Unit('1/s/MeV/sr')
+        # '1/s/MeV/sr', which is invalid ( try: astropy.units.Unit('1/s/MeV/sr')
         # This should be corrected.
         # For now, we hard-code the unit here:
         data_unit = u.Unit("s-1 MeV-1 sr-1")
@@ -123,11 +122,8 @@ class Background3D:
     @classmethod
     def read(cls, filename, hdu="BACKGROUND"):
         """Read from file."""
-        filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
-            bkg = cls.from_hdulist(hdulist, hdu=hdu)
-
-        return bkg
+        with fits.open(make_path(filename), memmap=False) as hdulist:
+            return cls.from_hdulist(hdulist, hdu=hdu)
 
     def to_table(self):
         """Convert to `~astropy.table.Table`."""
@@ -175,7 +171,7 @@ class Background3D:
             fov_lat=fov_lat,
             energy=energy_reco,
             method=method,
-            **kwargs
+            **kwargs,
         )
         return values
 
@@ -198,10 +194,8 @@ class Background3D:
         array : `~astropy.units.Quantity`
             Returns 2D array with axes offset
         """
-        from ..spectrum.utils import _trapz_loglog
-
         data = self.evaluate(fov_lon, fov_lat, energy_reco, method=method)
-        return _trapz_loglog(data, energy_reco, axis=0, intervals=True)
+        return trapz_loglog(data, energy_reco, axis=0)
 
     def to_2d(self):
         """Convert to `Background2D`.
@@ -252,7 +246,6 @@ class Background2D:
         meta=None,
         interp_kwargs=None,
     ):
-
         if interp_kwargs is None:
             interp_kwargs = self.default_interp_kwargs
 
@@ -265,11 +258,11 @@ class Background2D:
         self.data = NDDataArray(
             axes=[energy_axis, offset_axis], data=data, interp_kwargs=interp_kwargs
         )
-        self.meta = OrderedDict(meta) if meta else OrderedDict()
+        self.meta = meta or {}
 
     def __str__(self):
         ss = self.__class__.__name__
-        ss += "\n{}".format(self.data)
+        ss += f"\n{self.data}"
         return ss
 
     @classmethod
@@ -285,7 +278,7 @@ class Background2D:
             raise ValueError('Invalid column names. Need "BKG" or "BGD".')
 
         # Currently some files (e.g. CTA 1DC) contain unit in the FITS file
-        # '1/s/MeV/sr', which is invalid ( try: astropy.unit.Unit('1/s/MeV/sr')
+        # '1/s/MeV/sr', which is invalid ( try: astropy.units.Unit('1/s/MeV/sr')
         # This should be corrected.
         # For now, we hard-code the unit here:
         data_unit = u.Unit("s-1 MeV-1 sr-1")
@@ -306,11 +299,8 @@ class Background2D:
     @classmethod
     def read(cls, filename, hdu="BACKGROUND"):
         """Read from file."""
-        filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
-            bkg = cls.from_hdulist(hdulist, hdu=hdu)
-
-        return bkg
+        with fits.open(make_path(filename), memmap=False) as hdulist:
+            return cls.from_hdulist(hdulist, hdu=hdu)
 
     def to_table(self):
         """Convert to `~astropy.table.Table`."""
@@ -378,10 +368,8 @@ class Background2D:
         array : `~astropy.units.Quantity`
             Returns 2D array with axes offset
         """
-        from ..spectrum.utils import _trapz_loglog
-
         data = self.evaluate(fov_lon, fov_lat, energy_reco, method=method)
-        return _trapz_loglog(data, energy_reco, axis=0, intervals=True)
+        return trapz_loglog(data, energy_reco, axis=0)
 
     def to_3d(self):
         """Convert to `Background3D`.
@@ -398,8 +386,8 @@ class Background2D:
 
         ax = plt.gca() if ax is None else ax
 
-        x = self.data.axis("energy").edges
-        y = self.data.axis("offset").edges
+        x = self.data.axis("energy").edges.to_value("TeV")
+        y = self.data.axis("offset").edges.to_value("deg")
         z = self.data.data.T.value
 
         kwargs.setdefault("cmap", "GnBu")
@@ -407,14 +395,14 @@ class Background2D:
 
         caxes = ax.pcolormesh(x, y, z, norm=LogNorm(), **kwargs)
         ax.set_xscale("log")
-        ax.set_ylabel("Offset ({})".format(y.unit))
-        ax.set_xlabel("Energy ({})".format(x.unit))
+        ax.set_ylabel(f"Offset (deg)")
+        ax.set_xlabel(f"Energy (TeV)")
 
-        xmin, xmax = x.value.min(), x.value.max()
+        xmin, xmax = x.min(), x.max()
         ax.set_xlim(xmin, xmax)
 
         if add_cbar:
-            label = "Background rate ({unit})".format(unit=self.data.data.unit)
+            label = f"Background rate ({self.data.data.unit})"
             ax.figure.colorbar(caxes, ax=ax, label=label)
 
     def peek(self):
