@@ -1,14 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from collections import OrderedDict
 import numpy as np
 import astropy.units as u
 from astropy.io import fits
 from astropy.table import Table
-from ..utils.nddata import NDDataArray
-from ..maps import MapAxis
-from ..maps.utils import edges_from_lo_hi
-from ..utils.energy import energy_logcenter
-from ..utils.scripts import make_path
+from gammapy.maps import MapAxis
+from gammapy.maps.utils import edges_from_lo_hi
+from gammapy.utils.nddata import NDDataArray
+from gammapy.utils.scripts import make_path
 
 __all__ = ["EffectiveAreaTable", "EffectiveAreaTable2D"]
 
@@ -72,7 +70,7 @@ class EffectiveAreaTable:
         self.data = NDDataArray(
             axes=[energy_axis], data=data, interp_kwargs=interp_kwargs
         )
-        self.meta = OrderedDict(meta) if meta else OrderedDict()
+        self.meta = meta or {}
 
     @property
     def energy(self):
@@ -116,14 +114,14 @@ class EffectiveAreaTable:
             ener_val = u.Quantity(show_energy).to_value(self.energy.unit)
             ax.vlines(ener_val, 0, 1.1 * self.max_area.value, linestyles="dashed")
         ax.set_xscale("log")
-        ax.set_xlabel("Energy [{}]".format(self.energy.unit))
-        ax.set_ylabel("Effective Area [{}]".format(self.data.data.unit))
+        ax.set_xlabel(f"Energy [{self.energy.unit}]")
+        ax.set_ylabel(f"Effective Area [{self.data.data.unit}]")
 
         return ax
 
     @classmethod
     def from_parametrization(cls, energy, instrument="HESS"):
-        r"""Get parametrized effective area.
+        r"""Create parametrized effective area.
 
         Parametrizations of the effective areas of different Cherenkov
         telescopes taken from Appendix B of Abramowski et al. (2010), see
@@ -151,11 +149,11 @@ class EffectiveAreaTable:
         }
 
         if instrument not in pars.keys():
-            ss = "Unknown instrument: {}\n".format(instrument)
+            ss = f"Unknown instrument: {instrument}\n"
             ss += "Valid instruments: HESS, HESS2, CTA"
             raise ValueError(ss)
 
-        xx = energy_logcenter(energy).to_value("MeV")
+        xx = MapAxis.from_edges(energy, interp="log").center.to_value("MeV")
 
         g1 = pars[instrument][0]
         g2 = pars[instrument][1]
@@ -166,6 +164,20 @@ class EffectiveAreaTable:
 
         return cls(energy_lo=energy[:-1], energy_hi=energy[1:], data=data)
 
+    @classmethod
+    def from_constant(cls, energy, value):
+        """Create constant value effective area.
+
+        Parameters
+        ----------
+        energy : `~astropy.units.Quantity`
+            Energy binning, analytic function is evaluated at log centers
+        value : `~astropy.units.Quantity`
+            Effective area
+        """
+        data = np.ones((len(energy) - 1)) * u.Quantity(value)
+        return cls(energy_lo=energy[:-1], energy_hi=energy[1:], data=data)
+
     @classmethod
     def from_table(cls, table):
         """Create from `~astropy.table.Table` in ARF format.
@@ -186,15 +198,14 @@ class EffectiveAreaTable:
     def read(cls, filename, hdu="SPECRESP"):
         """Read from file."""
         filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
+        with fits.open(filename, memmap=False) as hdulist:
             try:
-                aeff = cls.from_hdulist(hdulist, hdu=hdu)
+                return cls.from_hdulist(hdulist, hdu=hdu)
             except KeyError:
-                msg = 'File {} contains no HDU "{}"'.format(filename, hdu)
-                msg += "\n Available {}".format([_.name for _ in hdulist])
-                raise ValueError(msg)
-
-        return aeff
+                raise ValueError(
+                    f"File {filename} contains no HDU {hdu!r}\n"
+                    f"Available: {[_.name for _ in hdulist]}"
+                )
 
     def to_table(self):
         """Convert to `~astropy.table.Table` in ARF format.
@@ -202,14 +213,12 @@ class EffectiveAreaTable:
         Data format specification: :ref:`gadf:ogip-arf`
         """
         table = Table()
-        table.meta = OrderedDict(
-            [
-                ("EXTNAME", "SPECRESP"),
-                ("hduclass", "OGIP"),
-                ("hduclas1", "RESPONSE"),
-                ("hduclas2", "SPECRESP"),
-            ]
-        )
+        table.meta = {
+            "EXTNAME": "SPECRESP",
+            "hduclass": "OGIP",
+            "hduclas1": "RESPONSE",
+            "hduclas2": "SPECRESP",
+        }
 
         energy = self.energy.edges
         table["ENERG_LO"] = energy[:-1]
@@ -231,7 +240,7 @@ class EffectiveAreaTable:
     def write(self, filename, use_sherpa=False, **kwargs):
         """Write to file."""
         filename = make_path(filename)
-        self.to_hdulist(use_sherpa=use_sherpa).writeto(str(filename), **kwargs)
+        self.to_hdulist(use_sherpa=use_sherpa).writeto(filename, **kwargs)
 
     def evaluate_fill_nan(self, **kwargs):
         """Modified evaluate function.
@@ -276,7 +285,7 @@ class EffectiveAreaTable:
         energy : `~astropy.units.Quantity`
             Energy corresponding to the given aeff.
         """
-        from ..spectrum.models import TableModel
+        from gammapy.modeling.models import TemplateSpectralModel
 
         energy = self.energy.center
 
@@ -286,27 +295,9 @@ class EffectiveAreaTable:
             # use the peak effective area as a default for the energy maximum
             emax = energy[np.argmax(self.data.data)]
 
-        aeff_spectrum = TableModel(energy, self.data.data, values_scale="lin")
+        aeff_spectrum = TemplateSpectralModel(energy, self.data.data)
         return aeff_spectrum.inverse(aeff, emin=emin, emax=emax)
 
-    def to_sherpa(self, name):
-        """Convert to `~sherpa.astro.data.DataARF`
-
-        Parameters
-        ----------
-        name : str
-            Instance name
-        """
-        from sherpa.astro.data import DataARF
-
-        table = self.to_table()
-        return DataARF(
-            name=name,
-            energ_lo=table["ENERG_LO"].quantity.to_value("keV"),
-            energ_hi=table["ENERG_HI"].quantity.to_value("keV"),
-            specresp=table["SPECRESP"].quantity.to_value("cm2"),
-        )
-
 
 class EffectiveAreaTable2D:
     """2D effective area table.
@@ -383,11 +374,11 @@ class EffectiveAreaTable2D:
         self.data = NDDataArray(
             axes=[energy_axis, offset_axis], data=data, interp_kwargs=interp_kwargs
         )
-        self.meta = OrderedDict(meta) if meta else OrderedDict()
+        self.meta = meta or {}
 
     def __str__(self):
         ss = self.__class__.__name__
-        ss += "\n{}".format(self.data)
+        ss += f"\n{self.data}"
         return ss
 
     @property
@@ -420,11 +411,8 @@ class EffectiveAreaTable2D:
     @classmethod
     def read(cls, filename, hdu="EFFECTIVE AREA"):
         """Read from file."""
-        filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
-            aeff = cls.from_hdulist(hdulist, hdu=hdu)
-
-        return aeff
+        with fits.open(make_path(filename), memmap=False) as hdulist:
+            return cls.from_hdulist(hdulist, hdu=hdu)
 
     def to_effective_area_table(self, offset, energy=None):
         """Evaluate at a given offset and return `~gammapy.irf.EffectiveAreaTable`.
@@ -439,7 +427,9 @@ class EffectiveAreaTable2D:
         if energy is None:
             energy = self.data.axis("energy").edges
 
-        area = self.data.evaluate(offset=offset, energy=energy_logcenter(energy))
+        area = self.data.evaluate(
+            offset=offset, energy=MapAxis.from_edges(energy, interp="log").center
+        )
 
         return EffectiveAreaTable(
             energy_lo=energy[:-1], energy_hi=energy[1:], data=area
@@ -477,12 +467,12 @@ class EffectiveAreaTable2D:
 
         for off in offset:
             area = self.data.evaluate(offset=off, energy=energy)
-            label = "offset = {:.1f}".format(off)
+            label = f"offset = {off:.1f}"
             ax.plot(energy, area.value, label=label, **kwargs)
 
         ax.set_xscale("log")
-        ax.set_xlabel("Energy [{}]".format(self.data.axis("energy").unit))
-        ax.set_ylabel("Effective Area [{}]".format(self.data.data.unit))
+        ax.set_xlabel(f"Energy [{self.data.axis('energy').unit}]")
+        ax.set_ylabel(f"Effective Area [{self.data.data.unit}]")
         ax.set_xlim(min(energy.value), max(energy.value))
         ax.legend(loc="upper left")
 
@@ -521,11 +511,11 @@ class EffectiveAreaTable2D:
             area /= np.nanmax(area)
             if np.isnan(area).all():
                 continue
-            label = "energy = {:.1f}".format(ee)
+            label = f"energy = {ee:.1f}"
             ax.plot(offset, area, label=label, **kwargs)
 
         ax.set_ylim(0, 1.1)
-        ax.set_xlabel("Offset ({})".format(self.data.axis("offset").unit))
+        ax.set_xlabel(f"Offset ({self.data.axis('offset').unit})")
         ax.set_ylabel("Relative Effective Area")
         ax.legend(loc="best")
 
@@ -551,14 +541,14 @@ class EffectiveAreaTable2D:
         caxes = ax.pcolormesh(energy.value, offset.value, aeff.value.T, **kwargs)
 
         ax.set_xscale("log")
-        ax.set_ylabel("Offset ({})".format(offset.unit))
-        ax.set_xlabel("Energy ({})".format(energy.unit))
+        ax.set_ylabel(f"Offset ({offset.unit})")
+        ax.set_xlabel(f"Energy ({energy.unit})")
 
         xmin, xmax = energy.value.min(), energy.value.max()
         ax.set_xlim(xmin, xmax)
 
         if add_cbar:
-            label = "Effective Area ({unit})".format(unit=aeff.unit)
+            label = f"Effective Area ({aeff.unit})"
             ax.figure.colorbar(caxes, ax=ax, label=label)
 
         return ax
@@ -589,5 +579,5 @@ class EffectiveAreaTable2D:
         return table
 
     def to_fits(self, name="EFFECTIVE AREA"):
-        """Convert to `~astropy.io.fits.BinTable`."""
+        """Convert to `~astropy.io.fits.BinTableHDU`."""
         return fits.BinTableHDU(self.to_table(), name=name)
