@@ -1,27 +1,26 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
-import numpy as np
 import logging
+import numpy as np
+from astropy.convolution import Gaussian2DKernel
+from astropy.coordinates import Angle
 from astropy.io import fits
+from astropy.stats import gaussian_fwhm_to_sigma
 from astropy.table import Table
 from astropy.units import Quantity, Unit
-from astropy.coordinates import Angle
-from astropy.convolution import Gaussian2DKernel
-from astropy.stats import gaussian_fwhm_to_sigma
-from ..extern.validator import validate_physical_type
-from ..utils.array import array_stats_str
-from ..utils.energy import Energy, EnergyBounds
-from ..utils.scripts import make_path
-from ..utils.gauss import MultiGauss2D
+from gammapy.maps import MapAxis
+from gammapy.utils.array import array_stats_str
+from gammapy.utils.gauss import MultiGauss2D
+from gammapy.utils.interpolation import ScaledRegularGridInterpolator
+from gammapy.utils.scripts import make_path
 from .psf_3d import PSF3D
-from . import EnergyDependentTablePSF
+from .psf_table import EnergyDependentTablePSF
 
 __all__ = ["EnergyDependentMultiGaussPSF"]
 
 log = logging.getLogger(__name__)
 
 
-class EnergyDependentMultiGaussPSF(object):
+class EnergyDependentMultiGaussPSF:
     """
     Triple Gauss analytical PSF depending on energy and theta.
 
@@ -58,7 +57,7 @@ class EnergyDependentMultiGaussPSF(object):
 
         import matplotlib.pyplot as plt
         from gammapy.irf import EnergyDependentMultiGaussPSF
-        filename = '$GAMMAPY_DATA/tests/unbundled/irfs/psf.fits'
+        filename = '$GAMMAPY_DATA/cta-1dc/caldb/data/cta/1dc/bcf/South_z20_50h/irf_file.fits'
         psf = EnergyDependentMultiGaussPSF.read(filename, hdu='POINT SPREAD FUNCTION')
         psf.plot_containment(0.68, show_safe_energy=False)
         plt.show()
@@ -71,33 +70,33 @@ class EnergyDependentMultiGaussPSF(object):
         theta,
         sigmas,
         norms,
-        energy_thresh_lo=Quantity(0.1, "TeV"),
-        energy_thresh_hi=Quantity(100, "TeV"),
+        energy_thresh_lo="0.1 TeV",
+        energy_thresh_hi="100 TeV",
     ):
-
-        # Validate input
-        validate_physical_type("energy_lo", energy_lo, "energy")
-        validate_physical_type("energy_hi", energy_hi, "energy")
-        validate_physical_type("theta", theta, "angle")
-        validate_physical_type("energy_thresh_lo", energy_thresh_lo, "energy")
-        validate_physical_type("energy_thresh_hi", energy_thresh_hi, "energy")
-
-        # Set attributes
-        self.energy_lo = energy_lo.to("TeV")
-        self.energy_hi = energy_hi.to("TeV")
-        ebounds = EnergyBounds.from_lower_and_upper_bounds(
-            self.energy_lo, self.energy_hi
-        )
-        self.energy = ebounds.log_centers
-        self.theta = theta.to("deg")
+        self.energy_lo = Quantity(energy_lo, "TeV")
+        self.energy_hi = Quantity(energy_hi, "TeV")
+        self.energy = np.sqrt(self.energy_hi * self.energy_lo)
+        self.theta = Quantity(theta, "deg")
         sigmas[0][sigmas[0] == 0] = 1
         sigmas[1][sigmas[1] == 0] = 1
         sigmas[2][sigmas[2] == 0] = 1
         self.sigmas = sigmas
 
         self.norms = norms
-        self.energy_thresh_lo = energy_thresh_lo.to("TeV")
-        self.energy_thresh_hi = energy_thresh_hi.to("TeV")
+        self.energy_thresh_lo = Quantity(energy_thresh_lo, "TeV")
+        self.energy_thresh_hi = Quantity(energy_thresh_hi, "TeV")
+
+        self._interp_norms = self._setup_interpolators(self.norms)
+        self._interp_sigmas = self._setup_interpolators(self.sigmas)
+
+    def _setup_interpolators(self, values_list):
+        interps = []
+        for values in values_list:
+            interp = ScaledRegularGridInterpolator(
+                points=(self.theta, self.energy), values=values
+            )
+            interps.append(interp)
+        return interps
 
     @classmethod
     def read(cls, filename, hdu="PSF_2D_GAUSS"):
@@ -108,11 +107,8 @@ class EnergyDependentMultiGaussPSF(object):
         filename : str
             File name
         """
-        filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
-            psf = cls.from_fits(hdulist[hdu])
-
-        return psf
+        with fits.open(make_path(filename), memmap=False) as hdulist:
+            return cls.from_fits(hdulist[hdu])
 
     @classmethod
     def from_fits(cls, hdu):
@@ -120,7 +116,7 @@ class EnergyDependentMultiGaussPSF(object):
 
         Parameters
         ----------
-        hdu : `~astropy.io.fits.BintableHDU`
+        hdu : `~astropy.io.fits.BinTableHDU`
             HDU
         """
         energy_lo = Quantity(hdu.data["ENERG_LO"][0], "TeV")
@@ -207,7 +203,7 @@ class EnergyDependentMultiGaussPSF(object):
 
     def psf_at_energy_and_theta(self, energy, theta):
         """
-        Get `~gammapy.image.models.MultiGauss2D` model for given energy and theta.
+        Get `~gammapy.modeling.models.MultiGauss2D` model for given energy and theta.
 
         No interpolation is used.
 
@@ -223,23 +219,16 @@ class EnergyDependentMultiGaussPSF(object):
         psf : `~gammapy.morphology.MultiGauss2D`
             Multigauss PSF object.
         """
-        energy = Energy(energy)
-        theta = Angle(theta)
-
-        # Find nearest energy value
-        i = np.argmin(np.abs(self.energy - energy))
-        j = np.argmin(np.abs(self.theta - theta))
-
-        # TODO: Use some kind of interpolation to get PSF
-        # parameters for every energy and theta
-
-        # Select correct gauss parameters for given energy and theta
-        sigmas = [_[j][i] for _ in self.sigmas]
-        norms = [_[j][i] for _ in self.norms]
+        energy = Quantity(energy)
+        theta = Quantity(theta)
 
         pars = {}
-        pars["scale"], pars["A_2"], pars["A_3"] = norms
-        pars["sigma_1"], pars["sigma_2"], pars["sigma_3"] = sigmas
+        for name, interp_norm in zip(["scale", "A_2", "A_3"], self._interp_norms):
+            pars[name] = interp_norm((theta, energy))
+
+        for idx, interp_sigma in enumerate(self._interp_sigmas):
+            pars[f"sigma_{idx + 1}"] = interp_sigma((theta, energy))
+
         psf = HESSMultiGaussPSF(pars)
         return psf.to_MultiGauss2D(normalize=True)
 
@@ -247,24 +236,24 @@ class EnergyDependentMultiGaussPSF(object):
         """Compute containment for all energy and theta values"""
         # This is a false positive from pylint
         # See https://github.com/PyCQA/pylint/issues/2435
-        energy = Energy(energy).flatten()  # pylint:disable=assignment-from-no-return
-        theta = Angle(theta).flatten()
+        energies = Quantity(
+            energy
+        ).flatten()  # pylint:disable=assignment-from-no-return
+        thetas = Angle(theta).flatten()
         radius = np.empty((theta.size, energy.size))
 
-        for idx_energy in range(len(energy)):
-            for idx_theta in range(len(theta)):
+        for idx, energy in enumerate(energies):
+            for jdx, theta in enumerate(thetas):
                 try:
-                    psf = self.psf_at_energy_and_theta(
-                        energy[idx_energy], theta[idx_theta]
-                    )
-                    radius[idx_theta, idx_energy] = psf.containment_radius(fraction)
+                    psf = self.psf_at_energy_and_theta(energy, theta)
+                    radius[jdx, idx] = psf.containment_radius(fraction)
                 except ValueError:
                     log.debug(
-                        "Computing containment failed for E = {:.2f}"
-                        " and Theta={:.2f}".format(energy[idx_energy], theta[idx_theta])
+                        f"Computing containment failed for energy = {energy:.2f}"
+                        f" and theta={theta:.2f}"
                     )
-                    log.debug("Sigmas: {} Norms: {}".format(psf.sigmas, psf.norms))
-                    radius[idx_theta, idx_energy] = np.nan
+                    log.debug(f"Sigmas: {psf.sigmas} Norms: {psf.norms}")
+                    radius[jdx, idx] = np.nan
 
         return Angle(radius, "deg")
 
@@ -303,8 +292,8 @@ class EnergyDependentMultiGaussPSF(object):
 
         # Axes labels and ticks, colobar
         ax.semilogx()
-        ax.set_ylabel("Offset ({unit})".format(unit=offset.unit))
-        ax.set_xlabel("Energy ({unit})".format(unit=energy.unit))
+        ax.set_ylabel(f"Offset ({offset.unit})")
+        ax.set_xlabel(f"Energy ({energy.unit})")
         ax.set_xlim(x.min(), x.max())
         ax.set_ylim(y.min(), y.max())
 
@@ -312,9 +301,7 @@ class EnergyDependentMultiGaussPSF(object):
             self._plot_safe_energy_range(ax)
 
         if add_cbar:
-            label = "Containment radius R{0:.0f} ({1})".format(
-                100 * fraction, containment.unit
-            )
+            label = f"Containment radius R{100 * fraction:.0f} ({containment.unit})"
             ax.figure.colorbar(caxes, ax=ax, label=label)
 
         return ax
@@ -325,7 +312,7 @@ class EnergyDependentMultiGaussPSF(object):
         omin = self.offset.value.min()
         omax = self.offset.value.max()
         ax.hlines(y=esafe.value, xmin=omin, xmax=omax)
-        label = "Safe energy threshold: {0:3.2f}".format(esafe)
+        label = f"Safe energy threshold: {esafe:3.2f}"
         ax.text(x=0.1, y=0.9 * esafe.value, s=label, va="top")
 
     def plot_containment_vs_energy(
@@ -337,12 +324,14 @@ class EnergyDependentMultiGaussPSF(object):
 
         ax = plt.gca() if ax is None else ax
 
-        energy = Energy.equal_log_spacing(self.energy_lo[0], self.energy_hi[-1], 100)
+        energy = MapAxis.from_energy_bounds(
+            self.energy_lo[0], self.energy_hi[-1], 100
+        ).edges
 
         for theta in thetas:
             for fraction in fractions:
                 radius = self.containment_radius(energy, theta, fraction).squeeze()
-                label = "{} deg, {:.1f}%".format(theta, 100 * fraction)
+                label = f"{theta.deg} deg, {100 * fraction:.1f}%"
                 ax.plot(energy.value, radius.value, label=label)
 
         ax.semilogx()
@@ -394,12 +383,11 @@ class EnergyDependentMultiGaussPSF(object):
         """
         ss = "\nSummary PSF info\n"
         ss += "----------------\n"
-        # Summarise data members
         ss += array_stats_str(self.theta.to("deg"), "Theta")
         ss += array_stats_str(self.energy_hi, "Energy hi")
         ss += array_stats_str(self.energy_lo, "Energy lo")
-        ss += "Safe energy threshold lo: {0:6.3f}\n".format(self.energy_thresh_lo)
-        ss += "Safe energy threshold hi: {0:6.3f}\n".format(self.energy_thresh_hi)
+        ss += f"Safe energy threshold lo: {self.energy_thresh_lo:6.3f}\n"
+        ss += f"Safe energy threshold hi: {self.energy_thresh_hi:6.3f}\n"
 
         for fraction in fractions:
             containment = self.containment_radius(energies, thetas, fraction)
@@ -407,8 +395,8 @@ class EnergyDependentMultiGaussPSF(object):
                 for j, theta in enumerate(thetas):
                     radius = containment[j, i]
                     ss += (
-                        "{0:2.0f}% containment radius at theta = {1} and "
-                        "E = {2:4.1f}: {3:5.8f}\n"
+                        "{:2.0f}% containment radius at theta = {} and "
+                        "E = {:4.1f}: {:5.8f}\n"
                         "".format(100 * fraction, theta, energy, radius)
                     )
         return ss
@@ -456,8 +444,8 @@ class EnergyDependentMultiGaussPSF(object):
             energy=energies, rad=rad, exposure=exposure, psf_value=psf_value
         )
 
-    def to_psf3d(self, rad):
-        """ Creates a PSF3D from an analytical PSF.
+    def to_psf3d(self, rad=None):
+        """Create a PSF3D from an analytical PSF.
 
         Parameters
         ----------
@@ -473,6 +461,10 @@ class EnergyDependentMultiGaussPSF(object):
         energy = self.energy
         energy_lo = self.energy_lo
         energy_hi = self.energy_hi
+        if rad is None:
+            rad = np.linspace(0, 0.66, 67) * Unit(
+                "deg"
+            )  # Arbitrary binning of 0.01 in rad
         rad_lo = rad[:-1]
         rad_hi = rad[1:]
 
@@ -496,7 +488,7 @@ class EnergyDependentMultiGaussPSF(object):
         )
 
 
-class HESSMultiGaussPSF(object):
+class HESSMultiGaussPSF:
     """Multi-Gauss PSF as represented in the HESS software.
 
     The 2D Gaussian is represented as a 1D exponential
@@ -550,8 +542,8 @@ class HESSMultiGaussPSF(object):
         theta2 = np.asarray(theta2, "f")
         total = np.zeros_like(theta2)
         for ii in range(1, self.n_gauss() + 1):
-            A = self.pars["A_{}".format(ii)]
-            sigma = self.pars["sigma_{}".format(ii)]
+            A = self.pars[f"A_{ii}"]
+            sigma = self.pars[f"sigma_{ii}"]
             total += A * np.exp(-theta2 / (2 * sigma ** 2))
         return self.pars["scale"] * total
 
@@ -560,11 +552,12 @@ class HESSMultiGaussPSF(object):
 
         Note: We have to set norm = 2 * A * sigma ^ 2, because in
         MultiGauss2D norm represents the integral, and in HESS A
-        represents the amplitude at 0."""
+        represents the amplitude at 0.
+        """
         sigmas, norms = [], []
         for ii in range(1, self.n_gauss() + 1):
-            A = self.pars["A_{}".format(ii)]
-            sigma = self.pars["sigma_{}".format(ii)]
+            A = self.pars[f"A_{ii}"]
+            sigma = self.pars[f"sigma_{ii}"]
             norm = self.pars["scale"] * 2 * A * sigma ** 2
             sigmas.append(sigma)
             norms.append(norm)
@@ -606,7 +599,7 @@ def multi_gauss_psf_kernel(psf_parameters, BINSZ=0.02, NEW_BINSZ=0.02, **kwargs)
     psf = None
     for ii in range(1, 4):
         # Convert sigma and amplitude
-        pars = psf_parameters["psf{}".format(ii)]
+        pars = psf_parameters[f"psf{ii}"]
         sigma = gaussian_fwhm_to_sigma * pars["fwhm"] * BINSZ / NEW_BINSZ
         ampl = 2 * np.pi * sigma ** 2 * pars["ampl"]
         if psf is None:
