@@ -4,18 +4,18 @@ import numpy as np
 from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
 from astropy.coordinates import Angle
-from gammapy.irf import EnergyDispersion, EnergyDispersion2D
+from gammapy.irf import EDispKernel, EnergyDispersion2D
 from gammapy.maps import MapAxis
 from gammapy.utils.testing import mpl_plot_check, requires_data, requires_dependency
 
 
-class TestEnergyDispersion:
+class TestEDispKernel:
     def setup(self):
         self.e_true = np.logspace(0, 1, 101) * u.TeV
         self.e_reco = self.e_true
         self.resolution = 0.1
         self.bias = 0
-        self.edisp = EnergyDispersion.from_gauss(
+        self.edisp = EDispKernel.from_gauss(
             e_true=self.e_true,
             e_reco=self.e_reco,
             pdf_threshold=1e-7,
@@ -27,7 +27,7 @@ class TestEnergyDispersion:
         e_true = [0.5, 1, 2, 4, 6] * u.TeV
         e_reco = [2, 4, 6] * u.TeV
 
-        edisp = EnergyDispersion.from_diagonal_response(e_true, e_reco)
+        edisp = EDispKernel.from_diagonal_response(e_true, e_reco)
 
         assert edisp.pdf_matrix.shape == (4, 2)
         expected = [[0, 0], [0, 0], [1, 0], [0, 1]]
@@ -35,7 +35,7 @@ class TestEnergyDispersion:
         assert_equal(edisp.pdf_matrix, expected)
 
         # Test square matrix
-        edisp = EnergyDispersion.from_diagonal_response(e_true)
+        edisp = EDispKernel.from_diagonal_response(e_true)
         assert_allclose(edisp.e_reco.edges.value, e_true.value)
         assert edisp.e_reco.unit == "TeV"
         assert_equal(edisp.pdf_matrix[0][0], 1)
@@ -43,7 +43,7 @@ class TestEnergyDispersion:
         assert edisp.pdf_matrix.sum() == 4
 
     def test_str(self):
-        assert "EnergyDispersion" in str(self.edisp)
+        assert "EDispKernel" in str(self.edisp)
 
     def test_evaluate(self):
         # Check for correct normalization
@@ -53,12 +53,12 @@ class TestEnergyDispersion:
     def test_apply(self):
         counts = np.arange(len(self.e_true) - 1)
         actual = self.edisp.apply(counts)
-        assert_allclose(actual[0], 1.862299, atol=1e-3)
+        assert_allclose(actual[0], 1.853746, atol=1e-3)
 
         counts = np.arange(len(self.e_true) - 4)
         with pytest.raises(ValueError):
             self.edisp.apply(counts)
-        assert_allclose(actual[0], 1.862299, atol=1e-3)
+        assert_allclose(actual[0], 1.853746, atol=1e-3)
 
     def test_get_bias(self):
         bias = self.edisp.get_bias(3.34 * u.TeV)
@@ -72,7 +72,7 @@ class TestEnergyDispersion:
         indices = np.array([[1, 3, 6], [3, 3, 2]])
         desired = self.edisp.pdf_matrix[indices]
         self.edisp.write(tmp_path / "tmp.fits")
-        edisp2 = EnergyDispersion.read(tmp_path / "tmp.fits")
+        edisp2 = EDispKernel.read(tmp_path / "tmp.fits")
         actual = edisp2.pdf_matrix[indices]
         assert_allclose(actual, desired)
 
@@ -134,7 +134,7 @@ class TestEnergyDispersion2D:
     def test_get_response(self):
         pdf = self.edisp2.get_response(offset=0.7 * u.deg, e_true=1 * u.TeV)
         assert_allclose(pdf.sum(), 1)
-        assert_allclose(pdf.max(), 0.0130256, rtol=1e-5)
+        assert_allclose(pdf.max(), 0.010421, rtol=1e-4)
 
     def test_exporter(self):
         # Check RMF exporter
@@ -195,6 +195,6 @@ class TestEnergyDispersion2D:
 def test_get_bias_energy():
     """Obs read from file"""
     rmffile = "$GAMMAPY_DATA/joint-crab/spectra/hess/rmf_obs23523.fits"
-    edisp = EnergyDispersion.read(rmffile)
+    edisp = EDispKernel.read(rmffile)
     thresh_lo = edisp.get_bias_energy(0.1)
     assert_allclose(thresh_lo.to("TeV").value, 0.9174, rtol=1e-4)
