@@ -3,10 +3,11 @@
 from .base import *
 from .geom import *
 from .hpx import *
-from .hpxnd import *
-from .hpxsparse import *
 from .hpxmap import *
+from .hpxnd import *
+from .image_utils import *
+from .plotting import *
+from .profile import *
 from .wcs import *
-from .wcsnd import *
 from .wcsmap import *
-from .sparse import *
+from .wcsnd import *
