@@ -2,37 +2,34 @@
 import abc
 import copy
 import inspect
-import re
-from collections import OrderedDict
 import logging
 import numpy as np
-from scipy.interpolate import interp1d
-from astropy.io import fits
+import scipy.interpolate
 from astropy import units as u
 from astropy.coordinates import SkyCoord
-from astropy.table import QTable, Column
-from ..utils.interpolation import interpolation_scale
-from .utils import find_hdu, find_bands_hdu, INVALID_INDEX
+from astropy.io import fits
+from astropy.table import Column, QTable, Table
+from astropy.utils import lazyproperty
+from gammapy.utils.interpolation import interpolation_scale
+from .utils import INVALID_INDEX, edges_from_lo_hi, find_bands_hdu, find_hdu
 
-__all__ = ["MapCoord", "MapGeom", "MapAxis"]
+__all__ = ["MapCoord", "Geom", "MapAxis"]
 
 log = logging.getLogger(__name__)
 
 
-def make_axes(axes_in, conv):
+def make_axes(axes_in):
     """Make a sequence of `~MapAxis` objects."""
     if axes_in is None:
         return []
 
     axes_out = []
-    for i, ax in enumerate(axes_in):
+    for idx, ax in enumerate(axes_in):
         if isinstance(ax, np.ndarray):
             ax = MapAxis(ax)
 
-        if conv in ["fgst-ccube", "fgst-template"]:
-            ax.name = "energy"
-        elif ax.name == "":
-            ax.name = "axis%i" % i
+        if ax.name == "":
+            ax.name = "axis{}".format(idx)
 
         axes_out += [ax]
 
@@ -80,71 +77,84 @@ def make_axes_cols(axes, axis_names=None):
     return cols
 
 
-def find_and_read_bands(hdu, header=None):
+def energy_axis_from_fgst_ccube(hdu):
+    bands = Table.read(hdu)
+    edges_min = bands["E_MIN"].quantity
+    edges_max = bands["E_MAX"].quantity
+    edges = edges_from_lo_hi(edges_min, edges_max)
+    return [MapAxis.from_edges(edges=edges, name="energy", interp="log")]
+
+
+def energy_axis_from_fgst_template(hdu):
+    bands = Table.read(hdu)
+
+    allowed_names = ["Energy", "ENERGY", "energy"]
+    for colname in bands.colnames:
+        if colname in allowed_names:
+            tag = colname
+            break
+
+    nodes = bands[tag].data
+
+    return [MapAxis.from_nodes(nodes=nodes, name="energy", unit="MeV", interp="log")]
+
+
+def axes_from_bands_hdu(hdu):
     """Read and returns the map axes from a BANDS table.
 
     Parameters
     ----------
     hdu : `~astropy.io.fits.BinTableHDU`
         The BANDS table HDU.
-    header : `~astropy.io.fits.Header`
-        Header
 
     Returns
     -------
     axes : list of `~MapAxis`
         List of axis objects.
     """
+    axes = []
+
+    bands = Table.read(hdu)
+
+    for idx in range(5):
+        axcols = bands.meta.get("AXCOLS{}".format(idx + 1))
+
+        if axcols is None:
+            break
+
+        colnames = axcols.split(",")
+        node_type = "edges" if len(colnames) == 2 else "center"
+
+        # TODO: check why this extra case is needed
+        if colnames[0] == "E_MIN":
+            name = "energy"
+        else:
+            name = colnames[0].split("_")[0].lower()
+        interp = bands.meta.get("INTERP{}".format(idx + 1), "lin")
+
+        if node_type == "center":
+            nodes = np.unique(bands[colnames[0]].quantity)
+        else:
+            edges_min = np.unique(bands[colnames[0]].quantity)
+            edges_max = np.unique(bands[colnames[1]].quantity)
+            nodes = edges_from_lo_hi(edges_min, edges_max)
+
+        axis = MapAxis(nodes=nodes, node_type=node_type, interp=interp, name=name)
+        axes.append(axis)
+
+    return axes
+
+
+def find_and_read_bands(hdu):
     if hdu is None:
         return []
 
-    axes = []
-    axis_cols = []
     if hdu.name == "ENERGIES":
-        axis_cols = [["ENERGY"]]
+        axes = energy_axis_from_fgst_template(hdu)
     elif hdu.name == "EBOUNDS":
-        axis_cols = [["E_MIN", "E_MAX"]]
+        axes = energy_axis_from_fgst_ccube(hdu)
     else:
-        for i in range(5):
-            if "AXCOLS%i" % i in hdu.header:
-                axis_cols += [hdu.header["AXCOLS%i" % i].split(",")]
-
-    interp = "lin"
-    for i, cols in enumerate(axis_cols):
-
-        if "ENERGY" in cols or "E_MIN" in cols:
-            name = "energy"
-            interp = "log"
-        elif re.search("(.+)_MIN", cols[0]):
-            name = re.search("(.+)_MIN", cols[0]).group(1)
-        else:
-            name = cols[0]
-
-        interp_header_key = "INTERP%i" % (i + 1)
-        if header is not None and interp_header_key in header:
-            interp_header_val = header[interp_header_key]
-            if interp_header_val in ["sqrt", "log", "lin"]:
-                interp = interp_header_val
-            else:
-                log.warning(
-                    "Invalid map axis interp: {!r}. Using default: {!r}".format(
-                        interp_header_val, interp
-                    )
-                )
-
-        unit = hdu.data.columns[cols[0]].unit
-        if unit is None and header is not None:
-            unit = header.get("CUNIT%i" % (3 + i), "")
-        if unit is None:
-            unit = ""
-        if len(cols) == 2:
-            xmin = np.unique(hdu.data.field(cols[0]))
-            xmax = np.unique(hdu.data.field(cols[1]))
-            nodes = np.append(xmin, xmax[-1])
-            axes.append(MapAxis(nodes, name=name, unit=unit, interp=interp))
-        else:
-            nodes = np.unique(hdu.data.field(cols[0]))
-            axes.append(MapAxis.from_nodes(nodes, name=name, unit=unit, interp=interp))
+        axes = axes_from_bands_hdu(hdu)
 
     return axes
 
@@ -159,17 +169,7 @@ def get_shape(param):
     return max([np.array(p, ndmin=1).shape for p in param])
 
 
-def coordsys_to_frame(coordsys):
-    if coordsys in ["CEL", "C"]:
-        return "icrs"
-    elif coordsys in ["GAL", "G"]:
-        return "galactic"
-    else:
-        raise ValueError("Unrecognized coordinate system: {!r}".format(coordsys))
-
-
-# TODO: remove (or improve)
-def skycoord_to_lonlat(skycoord, coordsys=None):
+def skycoord_to_lonlat(skycoord, frame=None):
     """Convert SkyCoord to lon, lat, frame.
 
     Returns
@@ -178,25 +178,11 @@ def skycoord_to_lonlat(skycoord, coordsys=None):
         Longitude in degrees.
     lat : `~numpy.ndarray`
         Latitude in degrees.
-    frame : str
-        Name of coordinate frame.
     """
-    if coordsys in ["CEL", "C"]:
-        skycoord = skycoord.transform_to("icrs")
-    elif coordsys in ["GAL", "G"]:
-        skycoord = skycoord.transform_to("galactic")
+    if frame:
+        skycoord = skycoord.transform_to(frame)
 
-    frame = skycoord.frame.name
-    if frame in ["icrs", "fk5"]:
-        return skycoord.ra.deg, skycoord.dec.deg, frame
-    elif frame in ["galactic"]:
-        return skycoord.l.deg, skycoord.b.deg, frame
-    else:
-        raise ValueError("Unrecognized SkyCoord frame: {!r}".format(frame))
-
-
-def lonlat_to_skycoord(lon, lat, coordsys):
-    return SkyCoord(lon, lat, frame=coordsys_to_frame(coordsys), unit="deg")
+    return skycoord.data.lon.deg, skycoord.data.lat.deg, skycoord.frame.name
 
 
 def pix_tuple_to_idx(pix):
@@ -227,23 +213,6 @@ def pix_tuple_to_idx(pix):
     return tuple(idx)
 
 
-def axes_pix_to_coord(axes, pix):
-    """Perform pixel to axis coordinates for a list of `~MapAxis` objects.
-
-    Parameters
-    ----------
-    axes : list
-        List of `~MapAxis`.
-    pix : tuple
-        Tuple of pixel coordinates.
-    """
-    coords = []
-    for ax, t in zip(axes, pix):
-        coords += [ax.pix_to_coord(t)]
-
-    return coords
-
-
 def coord_to_idx(edges, x, clip=False):
     """Convert axis coordinates ``x`` to bin indices.
 
@@ -263,16 +232,11 @@ def coord_to_idx(edges, x, clip=False):
     return ibin
 
 
-def bin_to_val(edges, bins):
-    ctr = 0.5 * (edges[1:] + edges[:-1])
-    return ctr[bins]
-
-
 def coord_to_pix(edges, coord, interp="lin"):
     """Convert axis to pixel coordinates for given interpolation scheme."""
     scale = interpolation_scale(interp)
 
-    interp_fn = interp1d(
+    interp_fn = scipy.interpolate.interp1d(
         scale(edges), np.arange(len(edges), dtype=float), fill_value="extrapolate"
     )
 
@@ -283,7 +247,7 @@ def pix_to_coord(edges, pix, interp="lin"):
     """Convert pixel to grid coordinates for given interpolation scheme."""
     scale = interpolation_scale(interp)
 
-    interp_fn = interp1d(
+    interp_fn = scipy.interpolate.interp1d(
         np.arange(len(edges), dtype=float), scale(edges), fill_value="extrapolate"
     )
 
@@ -323,19 +287,8 @@ class MapAxis:
         String specifying the data units.
     """
 
-    __slots__ = [
-        "_name",
-        "_nodes",
-        "_node_type",
-        "_interp",
-        "_pix_offset",
-        "_nbin",
-        "_unit",
-    ]
-
     # TODO: Add methods to faciliate FITS I/O.
     # TODO: Cache an interpolation object?
-
     def __init__(self, nodes, interp="lin", name="", node_type="edges", unit=""):
 
         self.name = name
@@ -345,22 +298,23 @@ class MapAxis:
         if ~(np.all(nodes == np.sort(nodes)) or np.all(nodes[::-1] == np.sort(nodes))):
             raise ValueError("MapAxis: node values must be sorted")
 
+        if len(nodes) == 1 and node_type == "center":
+            raise ValueError("Single bins can only be used with node-type 'edges'")
+
         if isinstance(nodes, u.Quantity):
             unit = nodes.unit if nodes.unit is not None else ""
             nodes = nodes.value
         else:
             nodes = np.array(nodes)
 
-        self.unit = unit
+        self._unit = u.Unit(unit)
         self._nodes = nodes
         self._node_type = node_type
         self._interp = interp
 
         if (self._nodes < 0).any() and interp != "lin":
             raise ValueError(
-                "Interpolation scaling '{}' only support for positive node values.".format(
-                    interp
-                )
+                f"Interpolation scaling {interp!r} only support for positive node values."
             )
 
         # Set pixel coordinate of first node
@@ -371,7 +325,7 @@ class MapAxis:
             self._pix_offset = 0.0
             nbin = len(nodes)
         else:
-            raise ValueError("Invalid node type: {!r}".format(node_type))
+            raise ValueError(f"Invalid node type: {node_type!r}")
 
         self._nbin = nbin
 
@@ -396,6 +350,9 @@ class MapAxis:
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     @property
     def interp(self):
         """Interpolation scale of the axis."""
@@ -410,18 +367,23 @@ class MapAxis:
     def name(self, val):
         self._name = val
 
-    @property
+    @lazyproperty
     def edges(self):
         """Return array of bin edges."""
         pix = np.arange(self.nbin + 1, dtype=float) - 0.5
         return u.Quantity(self.pix_to_coord(pix), self._unit, copy=False)
 
-    @property
+    @lazyproperty
     def center(self):
         """Return array of bin centers."""
         pix = np.arange(self.nbin, dtype=float)
         return u.Quantity(self.pix_to_coord(pix), self._unit, copy=False)
 
+    @lazyproperty
+    def bin_width(self):
+        """Array of bin widths."""
+        return np.diff(self.edges)
+
     @property
     def nbin(self):
         """Return number of bins."""
@@ -437,10 +399,6 @@ class MapAxis:
         """Return coordinate axis unit."""
         return self._unit
 
-    @unit.setter
-    def unit(self, val):
-        self._unit = u.Unit(val)
-
     @classmethod
     def from_bounds(cls, lo_bnd, hi_bnd, nbin, **kwargs):
         """Generate an axis object from a lower/upper bound and number of bins.
@@ -462,6 +420,7 @@ class MapAxis:
             Interpolation method used to transform between axis and pixel
             coordinates.  Default: 'lin'.
         """
+        nbin = int(nbin)
         interp = kwargs.setdefault("interp", "lin")
         node_type = kwargs.setdefault("node_type", "edges")
 
@@ -470,7 +429,7 @@ class MapAxis:
         elif node_type == "center":
             nnode = nbin
         else:
-            raise ValueError("Invalid node type: {!r}".format(node_type))
+            raise ValueError(f"Invalid node type: {node_type!r}")
 
         if interp == "lin":
             nodes = np.linspace(lo_bnd, hi_bnd, nnode)
@@ -479,10 +438,47 @@ class MapAxis:
         elif interp == "sqrt":
             nodes = np.linspace(lo_bnd ** 0.5, hi_bnd ** 0.5, nnode) ** 2.0
         else:
-            raise ValueError("Invalid interp: {}".format(interp))
+            raise ValueError(f"Invalid interp: {interp}")
 
         return cls(nodes, **kwargs)
 
+    @classmethod
+    def from_energy_bounds(cls, emin, emax, nbin, unit=None, per_decade=False):
+        """Make an energy axis.
+
+        Used frequently also to make energy grids, by making
+        the axis, and then using ``axis.center`` or ``axis.edges``.
+
+        Parameters
+        ----------
+        emin, emax : `~astropy.units.Quantity`, float
+            Energy range
+        nbin : int
+            Number of bins
+        unit : `~astropy.units.Unit`
+            Energy unit
+        per_decade : bool
+            Whether `nbin` is given per decade.
+
+        Returns
+        -------
+        axis : `MapAxis`
+            Axis with name "energy" and interp "log".
+        """
+        emin = u.Quantity(emin, unit)
+        emax = u.Quantity(emax, unit)
+
+        if unit is None:
+            unit = emax.unit
+            emin = emin.to(unit)
+
+        if per_decade:
+            nbin = np.ceil(np.log10(emax / emin).value * nbin)
+
+        return cls.from_bounds(
+            emin.value, emax.value, nbin=nbin, unit=unit, interp="log", name="energy"
+        )
+
     @classmethod
     def from_nodes(cls, nodes, **kwargs):
         """Generate an axis object from a sequence of nodes (bin centers).
@@ -540,7 +536,8 @@ class MapAxis:
             Array of axis coordinate values.
         """
         pix = pix - self._pix_offset
-        return pix_to_coord(self._nodes, pix, interp=self._interp)
+        values = pix_to_coord(self._nodes, pix, interp=self._interp)
+        return u.Quantity(values, unit=self.unit, copy=False)
 
     def coord_to_pix(self, coord):
         """Transform from axis to pixel coordinates.
@@ -635,8 +632,8 @@ class MapAxis:
         str_ += fmt.format("nbins", str(self.nbin))
         str_ += fmt.format("node type", self.node_type)
         vals = self.edges if self.node_type == "edges" else self.center
-        str_ += fmt.format("{} min".format(self.node_type), "{:.1e}".format(vals.min()))
-        str_ += fmt.format("{} max".format(self.node_type), "{:.1e}".format(vals.max()))
+        str_ += fmt.format(f"{self.node_type} min", "{:.1e}".format(vals.min()))
+        str_ += fmt.format(f"{self.node_type} max", "{:.1e}".format(vals.max()))
         str_ += fmt.format("interp", self._interp)
         return str_
 
@@ -688,11 +685,11 @@ class MapAxis:
         edges_pix = np.clip(edges_pix, -0.5, self.nbin - 0.5)
         edges_idx = np.round(edges_pix + 0.5) - 0.5
         edges_idx = np.unique(edges_idx)
-        edges_ref = self.pix_to_coord(edges_idx) * self.unit
+        edges_ref = self.pix_to_coord(edges_idx)
 
         groups = QTable()
-        groups["{}_min".format(self.name)] = edges_ref[:-1]
-        groups["{}_max".format(self.name)] = edges_ref[1:]
+        groups[f"{self.name}_min"] = edges_ref[:-1]
+        groups[f"{self.name}_max"] = edges_ref[1:]
 
         groups["idx_min"] = (edges_idx[:-1] + 0.5).astype(int)
         groups["idx_max"] = (edges_idx[1:] - 0.5).astype(int)
@@ -708,8 +705,8 @@ class MapAxis:
                 "bin_type": "underflow",
                 "idx_min": 0,
                 "idx_max": edge_idx_start,
-                "{}_min".format(self.name): self.pix_to_coord(-0.5) * self.unit,
-                "{}_max".format(self.name): edge_ref_start,
+                f"{self.name}_min": self.pix_to_coord(-0.5),
+                f"{self.name}_max": edge_ref_start,
             }
             groups.insert_row(0, vals=underflow)
 
@@ -720,9 +717,8 @@ class MapAxis:
                 "bin_type": "overflow",
                 "idx_min": edge_idx_end + 1,
                 "idx_max": self.nbin - 1,
-                "{}_min".format(self.name): edge_ref_end,
-                "{}_max".format(self.name): self.pix_to_coord(self.nbin - 0.5)
-                * self.unit,
+                f"{self.name}_min": edge_ref_end,
+                f"{self.name}_max": self.pix_to_coord(self.nbin - 0.5),
             }
             groups.add_row(vals=overflow)
 
@@ -795,9 +791,9 @@ class MapCoord:
 
     Parameters
     ----------
-    data : `~collections.OrderedDict` of `~numpy.ndarray`
+    data : `dict` of `~numpy.ndarray`
         Dictionary of coordinate arrays.
-    coordsys : {'CEL', 'GAL', None}
+    frame : {"icrs", "galactic", None}
         Spatial coordinate system.  If None then the coordinate system
         will be set to the native coordinate system of the geometry.
     match_by_name : bool
@@ -805,22 +801,15 @@ class MapCoord:
         If false coordinates will be matched by index.
     """
 
-    def __init__(self, data, coordsys=None, match_by_name=True):
+    def __init__(self, data, frame=None, match_by_name=True):
 
         if "lon" not in data or "lat" not in data:
             raise ValueError("data dictionary must contain axes named 'lon' and 'lat'.")
 
-        if issubclass(data["lon"].__class__, u.Quantity):
-            raise ValueError("Quantity not supported for 'lon'")
-        if issubclass(data["lat"].__class__, u.Quantity):
-            raise ValueError("Quantity not supported for 'lat'")
-
-        data = OrderedDict(
-            [(k, np.atleast_1d(np.asanyarray(v))) for k, v in data.items()]
-        )
+        data = {k: np.atleast_1d(np.asanyarray(v)) for k, v in data.items()}
         vals = np.broadcast_arrays(*data.values(), subok=True)
-        self._data = OrderedDict(zip(data.keys(), vals))
-        self._coordsys = coordsys
+        self._data = dict(zip(data.keys(), vals))
+        self._frame = frame
         self._match_by_name = match_by_name
 
     def __getitem__(self, key):
@@ -859,17 +848,19 @@ class MapCoord:
     @property
     def theta(self):
         """Theta co-latitude angle in radians."""
-        return np.pi / 2.0 - np.radians(self.lat)
+        theta = u.Quantity(self.lat, unit="deg", copy=False).to_value("rad")
+        return np.pi / 2.0 - theta
 
     @property
     def phi(self):
         """Phi longitude angle in radians."""
-        return np.radians(self.lon)
+        phi = u.Quantity(self.lon, unit="deg", copy=False).to_value("rad")
+        return phi
 
     @property
-    def coordsys(self):
+    def frame(self):
         """Coordinate system (str)."""
-        return self._coordsys
+        return self._frame
 
     @property
     def match_by_name(self):
@@ -878,12 +869,10 @@ class MapCoord:
 
     @property
     def skycoord(self):
-        return SkyCoord(
-            self.lon, self.lat, unit="deg", frame=coordsys_to_frame(self.coordsys)
-        )
+        return SkyCoord(self.lon, self.lat, unit="deg", frame=self.frame)
 
     @classmethod
-    def _from_lonlat(cls, coords, coordsys=None):
+    def _from_lonlat(cls, coords, frame=None):
         """Create a `~MapCoord` from a tuple of coordinate vectors.
 
         The first two elements of the tuple should be longitude and latitude in degrees.
@@ -899,74 +888,44 @@ class MapCoord:
             A coordinates object.
         """
         if isinstance(coords, (list, tuple)):
-            coords_dict = OrderedDict([("lon", coords[0]), ("lat", coords[1])])
+            coords_dict = {"lon": coords[0], "lat": coords[1]}
             for i, c in enumerate(coords[2:]):
-                coords_dict["axis{}".format(i)] = c
+                coords_dict[f"axis{i}"] = c
         else:
             raise ValueError("Unrecognized input type.")
 
-        return cls(coords_dict, coordsys=coordsys, match_by_name=False)
+        return cls(coords_dict, frame=frame, match_by_name=False)
 
     @classmethod
-    def _from_skycoord(cls, coords, coordsys=None):
-        """Create from vector of `~astropy.coordinates.SkyCoord`.
-
-        Parameters
-        ----------
-        coords : tuple
-            Coordinate tuple with first element of type
-            `~astropy.coordinates.SkyCoord`.
-        coordsys : {'CEL', 'GAL', None}
-            Spatial coordinate system of output `~MapCoord` object.
-            If None the coordinate system will be set to the frame of
-            the `~astropy.coordinates.SkyCoord` object.
-        """
-        skycoord = coords[0]
-        name = skycoord.frame.name
-        if name in ["icrs", "fk5"]:
-            coords = (skycoord.ra.deg, skycoord.dec.deg) + coords[1:]
-            coords = cls._from_lonlat(coords, coordsys="CEL")
-        elif name in ["galactic"]:
-            coords = (skycoord.l.deg, skycoord.b.deg) + coords[1:]
-            coords = cls._from_lonlat(coords, coordsys="GAL")
-        else:
-            raise ValueError("Unrecognized coordinate frame: {!r}".format(name))
-
-        if coordsys is None:
-            return coords
-        else:
-            return coords.to_coordsys(coordsys)
-
-    @classmethod
-    def _from_tuple(cls, coords, coordsys=None):
+    def _from_tuple(cls, coords, frame=None):
         """Create from tuple of coordinate vectors."""
         if isinstance(coords[0], (list, np.ndarray)) or np.isscalar(coords[0]):
-            return cls._from_lonlat(coords, coordsys=coordsys)
+            return cls._from_lonlat(coords, frame=frame)
         elif isinstance(coords[0], SkyCoord):
-            return cls._from_skycoord(coords, coordsys=coordsys)
+            lon, lat, frame = skycoord_to_lonlat(coords[0], frame=frame)
+            coords = (lon, lat) + coords[1:]
+            return cls._from_lonlat(coords, frame=frame)
         else:
-            raise TypeError("Type not supported: {!r}".format(type(coords)))
+            raise TypeError(f"Type not supported: {type(coords)!r}")
 
     @classmethod
-    def _from_dict(cls, coords, coordsys=None):
+    def _from_dict(cls, coords, frame=None):
         """Create from a dictionary of coordinate vectors."""
         if "lon" in coords and "lat" in coords:
-            return cls(coords, coordsys=coordsys)
+            return cls(coords, frame=frame)
         elif "skycoord" in coords:
-            coords_dict = OrderedDict()
-            lon, lat, frame = skycoord_to_lonlat(coords["skycoord"], coordsys=coordsys)
-            coords_dict["lon"] = lon
-            coords_dict["lat"] = lat
+            lon, lat, frame = skycoord_to_lonlat(coords["skycoord"], frame=frame)
+            coords_dict = {"lon": lon, "lat": lat}
             for k, v in coords.items():
                 if k == "skycoord":
                     continue
                 coords_dict[k] = v
-            return cls(coords_dict, coordsys=coordsys)
+            return cls(coords_dict, frame=frame)
         else:
             raise ValueError("coords dict must contain 'lon'/'lat' or 'skycoord'.")
 
     @classmethod
-    def create(cls, data, coordsys=None):
+    def create(cls, data, frame=None):
         """Create a new `~MapCoord` object.
 
         This method can be used to create either unnamed (with tuple input)
@@ -976,7 +935,7 @@ class MapCoord:
         ----------
         data : tuple, dict, `MapCoord` or `~astropy.coordinates.SkyCoord`
             Object containing coordinate arrays.
-        coordsys : {'CEL', 'GAL', None}, optional
+        frame : {"icrs", "galactic", None}, optional
             Set the coordinate system for longitude and latitude. If
             None longitude and latitude will be assumed to be in
             the coordinate system native to a given map geometry.
@@ -997,41 +956,46 @@ class MapCoord:
         >>> c = MapCoord.create(dict(skycoord=skycoord,energy=energy))
         """
         if isinstance(data, cls):
-            if data.coordsys is None or coordsys == data.coordsys:
+            if data.frame is None or frame == data.frame:
                 return data
             else:
-                return data.to_coordsys(coordsys)
+                return data.to_frame(frame)
         elif isinstance(data, dict):
-            return cls._from_dict(data, coordsys=coordsys)
+            return cls._from_dict(data, frame=frame)
         elif isinstance(data, (list, tuple)):
-            return cls._from_tuple(data, coordsys=coordsys)
+            return cls._from_tuple(data, frame=frame)
         elif isinstance(data, SkyCoord):
-            return cls._from_skycoord((data,), coordsys=coordsys)
+            return cls._from_tuple((data,), frame=frame)
         else:
-            raise TypeError("Unsupported input type: {!r}".format(type(data)))
+            raise TypeError(f"Unsupported input type: {type(data)!r}")
 
-    def to_coordsys(self, coordsys):
+    def to_frame(self, frame):
         """Convert to a different coordinate frame.
 
         Parameters
         ----------
-        coordsys : {'CEL', 'GAL'}
-            Coordinate system, either Galactic ('GAL') or Equatorial ('CEL').
+        frame : {"icrs", "galactic"}
+            Coordinate system, either Galactic ("galactic") or Equatorial ("icrs").
 
         Returns
         -------
         coords : `~MapCoord`
             A coordinates object.
         """
-        if coordsys == self.coordsys:
+        if frame == self.frame:
             return copy.deepcopy(self)
         else:
-            skycoord = lonlat_to_skycoord(self.lon, self.lat, self.coordsys)
-            lon, lat, frame = skycoord_to_lonlat(skycoord, coordsys=coordsys)
+            lon, lat, frame = skycoord_to_lonlat(self.skycoord, frame=frame)
             data = copy.deepcopy(self._data)
+            if isinstance(self.lon, u.Quantity):
+                lon = u.Quantity(lon, unit="deg", copy=False)
+
+            if isinstance(self.lon, u.Quantity):
+                lat = u.Quantity(lat, unit="deg", copy=False)
+
             data["lon"] = lon
             data["lat"] = lat
-            return self.__class__(data, coordsys, self._match_by_name)
+            return self.__class__(data, frame, self._match_by_name)
 
     def apply_mask(self, mask):
         """Return a masked copy of this coordinate object.
@@ -1046,52 +1010,28 @@ class MapCoord:
         coords : `~MapCoord`
             A coordinates object.
         """
-        data = OrderedDict([(k, v[mask]) for k, v in self._data.items()])
-        return self.__class__(data, self.coordsys, self._match_by_name)
+        data = {k: v[mask] for k, v in self._data.items()}
+        return self.__class__(data, self.frame, self._match_by_name)
 
     def copy(self):
         """Copy `MapCoord` object."""
         return copy.deepcopy(self)
 
     def __repr__(self):
-        str_ = self.__class__.__name__
-        str_ += "\n\n"
-        str_ += "\taxes     : {}\n".format(", ".join(self._data.keys()))
-        str_ += "\tshape    : {}\n".format(self.shape[::-1])
-        str_ += "\tndim     : {}\n".format(self.ndim)
-        str_ += "\tcoordsys : {}\n".format(self.coordsys)
-        return str_
-
-    # TODO: this is a temporary solution until we have decided how to handle
-    # quantities uniformly. This should be called after any `MapCoord.create()`
-    # to support that users can pass quantities in any Map.xxx_by_coord() method.
-    def match_axes_units(self, geom):
-        """Match the units of the non-spatial axes to a given map geometry.
-
-        Parameters
-        ----------
-        geom : `MapGeom`
-            Map geometry with specified units per axis.
-
-        Returns
-        -------
-        coords : `MapCoord`
-            Map coord object with matched units
-        """
-        coords = OrderedDict()
-
-        for name, coord in self._data.items():
-            if name in ["lon", "lat"]:
-                coords[name] = coord
-            else:
-                ax = geom.get_axis_by_name(name)
-                coords[name] = u.Quantity(coord, ax.unit, copy=False).value
-
-        return self.__class__(coords, coordsys=self.coordsys)
+        return (
+            f"{self.__class__.__name__}\n\n"
+            f"\taxes     : {list(self._data.keys())}\n"
+            f"\tshape    : {self.shape[::-1]}\n"
+            f"\tndim     : {self.ndim}\n"
+            f"\tframe : {self.frame}\n"
+        )
 
 
-class MapGeom(abc.ABC):
-    """Base class for WCS and HEALPix geometries."""
+class Geom(abc.ABC):
+    """Map geometry base class.
+
+    See also: `~gammapy.maps.WcsGeom` and `~gammapy.maps.HpxGeom`
+    """
 
     @property
     @abc.abstractmethod
@@ -1136,7 +1076,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Geometry object.
         """
         if hdu is None:
@@ -1153,7 +1093,6 @@ class MapGeom(abc.ABC):
         return cls.from_header(hdu.header, hdu_bands)
 
     def make_bands_hdu(self, hdu=None, hdu_skymap=None, conv=None):
-        conv = self.conv if conv is None else conv
         header = fits.Header()
         self._fill_header_from_axes(header)
         axis_names = None
@@ -1169,7 +1108,7 @@ class MapGeom(abc.ABC):
             axis_names = ["energy"]
         elif conv == "gadf" and hdu is None:
             if hdu_skymap:
-                hdu = "{}_{}".format(hdu_skymap, "BANDS")
+                hdu = f"{hdu_skymap}_BANDS"
             else:
                 hdu = "BANDS"
         # else:
@@ -1371,7 +1310,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Sliced geometry.
         """
         axes = []
@@ -1390,7 +1329,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Image geometry.
         """
         pass
@@ -1410,7 +1349,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Map geometry.
         """
         pass
@@ -1446,7 +1385,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Padded geometry.
         """
         pass
@@ -1463,7 +1402,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Cropped geometry.
         """
         pass
@@ -1481,7 +1420,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Downsampled geometry.
 
         """
@@ -1500,7 +1439,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        geom : `~MapGeom`
+        geom : `~Geom`
             Upsampled geometry.
 
         """
@@ -1520,11 +1459,11 @@ class MapGeom(abc.ABC):
             elif ax.name == "energy" and ax.node_type == "center":
                 header[key] = "ENERGY"
             elif ax.node_type == "edges":
-                header[key] = "{}_MIN,{}_MAX".format(name, name)
+                header[key] = f"{name}_MIN,{name}_MAX"
             elif ax.node_type == "center":
                 header[key] = name
             else:
-                raise ValueError("Invalid node type {!r}".format(ax.node_type))
+                raise ValueError(f"Invalid node type {ax.node_type!r}")
 
             key_interp = "INTERP%i" % idx
             header[key_interp] = ax._interp
@@ -1581,7 +1520,7 @@ class MapGeom(abc.ABC):
         return self.__class__(**kwargs)
 
     def copy(self, **kwargs):
-        """Copy `MapGeom` instance and overwrite given attributes.
+        """Copy and overwrite given attributes.
 
         Parameters
         ----------
@@ -1590,7 +1529,7 @@ class MapGeom(abc.ABC):
 
         Returns
         -------
-        copy : `MapGeom`
+        copy : `Geom`
             Copied map geometry.
         """
         return self._init_copy(**kwargs)
@@ -1613,6 +1552,6 @@ class MapGeom(abc.ABC):
 
         # create mask
         coords = self.get_coord()
-        mask = coords["energy"] > emin.to_value(energy_axis.unit)
-        mask &= coords["energy"] < emax.to_value(energy_axis.unit)
+        mask = coords["energy"] > emin
+        mask &= coords["energy"] < emax
         return mask
