@@ -9,13 +9,12 @@ from astropy.units import Quantity
 from .geom import (
     Geom,
     MapCoord,
-    coordsys_to_frame,
     find_and_read_bands,
     make_axes,
     pix_tuple_to_idx,
     skycoord_to_lonlat,
 )
-from .utils import INVALID_INDEX
+from .utils import INVALID_INDEX, coordsys_to_frame, frame_to_coordsys
 from .wcs import WcsGeom
 
 # Not sure if we should expose this in the docs or not:
@@ -39,7 +38,7 @@ class HpxConv:
         self.hduname = kwargs.get("hduname", "SKYMAP")
         self.bands_hdu = kwargs.get("bands_hdu", "EBOUNDS")
         self.quantity_type = kwargs.get("quantity_type", "integral")
-        self.coordsys = kwargs.get("coordsys", "COORDSYS")
+        self.frame = kwargs.get("frame", "COORDSYS")
 
     def colname(self, indx):
         return f"{self.colstring}{indx}"
@@ -75,7 +74,7 @@ HPX_FITS_CONVENTIONS["galprop"] = HpxConv(
     hduname="SKYMAP2",
     bands_hdu="ENERGIES",
     quantity_type="differential",
-    coordsys="COORDTYPE",
+    frame="COORDTYPE",
 )
 HPX_FITS_CONVENTIONS["galprop2"] = HpxConv(
     "galprop",
@@ -197,61 +196,6 @@ def hpx_to_axes(h, npix):
     return x, z
 
 
-def hpx_to_coords(h, shape):
-    """Generate an N x D list of pixel center coordinates.
-
-    ``N`` is the number of pixels and ``D`` is the dimensionality of the map.
-    """
-    x, z = hpx_to_axes(h, shape)
-
-    x = np.sqrt(x[0:-1] * x[1:])
-    z = z[:-1] + 0.5
-
-    x = np.ravel(np.ones(shape) * x[:, np.newaxis])
-    z = np.ravel(np.ones(shape) * z[np.newaxis, :])
-
-    return np.vstack((x, z))
-
-
-def make_hpx_to_wcs_mapping_centers(hpx, wcs):
-    """Make the mapping data needed to from from HPX pixelization to a WCS-based array.
-
-    Parameters
-    ----------
-    hpx : `~gammapy.maps.HpxGeom`
-        The HEALPIX geometry.
-    wcs : `~gammapy.maps.WcsGeom`
-        The WCS geometry.
-
-    Returns
-    -------
-    ipixs : array(nx,ny)
-        HEALPIX pixel indices for each WCS pixel
-        -1 indicates the wcs pixel does not contain the center of a HEALPIX pixel
-    mult_val : array
-        (nx,ny) of 1.
-    npix : tuple
-        (nx,ny) with the shape of the WCS grid
-    """
-    npix = (int(wcs.wcs.crpix[0] * 2), int(wcs.wcs.crpix[1] * 2))
-    mult_val = np.ones(npix).T.flatten()
-    sky_crds = hpx.get_sky_coords()
-    pix_crds = wcs.wcs_world2pix(sky_crds, 0).astype(int)
-    ipixs = -1 * np.ones(npix, int).T.flatten()
-    pix_index = npix[1] * pix_crds[0:, 0] + pix_crds[0:, 1]
-
-    if hpx._ipix is None:
-        for ipix, pix_crd in enumerate(pix_index):
-            ipixs[pix_crd] = ipix
-    else:
-        for pix_crd, ipix in zip(pix_index, hpx._ipix):
-            ipixs[pix_crd] = ipix
-
-    ipixs = ipixs.reshape(npix).T.flatten()
-
-    return ipixs, mult_val, npix
-
-
 def make_hpx_to_wcs_mapping(hpx, wcs):
     """Make the pixel mapping from HPX- to a WCS-based geometry.
 
@@ -336,20 +280,18 @@ def parse_hpxregion(region):
         return [m.group(1)] + re.split(",", m.group(2))
 
 
-def get_hpxregion_dir(region, coordsys):
+def get_hpxregion_dir(region, frame):
     """Get the reference direction for a HEALPIX region string.
 
     Parameters
     ----------
     region : str
         A string describing a HEALPIX region
-    coordsys : {'CEL', 'GAL'}
+    frame : {'icrs', 'galactic'}
         Coordinate system
     """
     import healpy as hp
 
-    frame = coordsys_to_frame(coordsys)
-
     if region is None:
         return SkyCoord(0.0, 0.0, frame=frame, unit="deg")
 
@@ -404,18 +346,6 @@ def nside_to_order(nside):
     return order
 
 
-def upix_to_pix(upix):
-    """Get the pixel index and nside from a unique pixel number."""
-    nside = np.power(2, np.floor(np.log2(upix / 4)) / 2).astype(int)
-    pix = upix - 4 * np.power(nside, 2)
-    return pix, nside
-
-
-def pix_to_upix(pix, nside):
-    """Compute the unique pixel number from the pixel number and nside."""
-    return pix + 4 * np.power(nside, 2)
-
-
 def get_superpixels(idx, nside_subpix, nside_superpix, nest=True):
     """Compute the indices of superpixels that contain a subpixel.
 
@@ -547,8 +477,8 @@ class HpxGeom(Geom):
         non-spatial axes.
     nest : bool
         True -> 'NESTED', False -> 'RING' indexing scheme
-    coordsys : str
-        Coordinate system, 'CEL' | 'GAL'
+    frame : str
+        Coordinate system, "icrs" | "galactic"
     region : str or tuple
         Spatial geometry for partial-sky maps.  If none the map will
         encompass the whole sky.  String input will be parsed
@@ -566,7 +496,7 @@ class HpxGeom(Geom):
     is_hpx = True
 
     def __init__(
-        self, nside, nest=True, coordsys="CEL", region=None, axes=None, sparse=False
+        self, nside, nest=True, frame="icrs", region=None, axes=None, sparse=False
     ):
 
         # FIXME: Figure out what to do when sparse=True
@@ -583,7 +513,7 @@ class HpxGeom(Geom):
 
         self._order = nside_to_order(self._nside)
         self._nest = nest
-        self._coordsys = coordsys
+        self._frame = frame
         self._maxpix = 12 * self._nside * self._nside
         self._maxpix = self._maxpix * np.ones(self.shape_axes, dtype=int)
         self._sparse = sparse
@@ -763,7 +693,7 @@ class HpxGeom(Geom):
     def coord_to_pix(self, coords):
         import healpy as hp
 
-        coords = MapCoord.create(coords, coordsys=self.coordsys)
+        coords = MapCoord.create(coords, frame=self.frame)
         theta, phi = coords.theta, coords.phi
 
         c = self.coord_to_tuple(coords)
@@ -879,7 +809,7 @@ class HpxGeom(Geom):
         else:
             region = self.region
 
-        return self.__class__(nside, self.nest, self.coordsys, region, axes)
+        return self.__class__(nside, self.nest, self.frame, region, axes)
 
     @property
     def axes(self):
@@ -929,8 +859,8 @@ class HpxGeom(Geom):
         return self._npix
 
     @property
-    def coordsys(self):
-        return self._coordsys
+    def frame(self):
+        return self._frame
 
     @property
     def projection(self):
@@ -1002,7 +932,7 @@ class HpxGeom(Geom):
 
         axes = copy.deepcopy(self.axes)
         return self.__class__(
-            2 ** order, self.nest, coordsys=self.coordsys, region=self.region, axes=axes
+            2 ** order, self.nest, frame=self.frame, region=self.region, axes=axes
         )
 
     def to_swapped(self):
@@ -1015,16 +945,12 @@ class HpxGeom(Geom):
         """
         axes = copy.deepcopy(self.axes)
         return self.__class__(
-            self.nside,
-            not self.nest,
-            coordsys=self.coordsys,
-            region=self.region,
-            axes=axes,
+            self.nside, not self.nest, frame=self.frame, region=self.region, axes=axes,
         )
 
     def to_image(self):
         return self.__class__(
-            np.max(self.nside), self.nest, coordsys=self.coordsys, region=self.region
+            np.max(self.nside), self.nest, frame=self.frame, region=self.region
         )
 
     def to_cube(self, axes):
@@ -1032,7 +958,7 @@ class HpxGeom(Geom):
         return self.__class__(
             np.max(self.nside),
             self.nest,
-            coordsys=self.coordsys,
+            frame=self.frame,
             region=self.region,
             axes=axes,
         )
@@ -1070,7 +996,7 @@ class HpxGeom(Geom):
         return self.__class__(
             self.nside.copy(),
             self.nest,
-            coordsys=self.coordsys,
+            frame=self.frame,
             region=idx,
             axes=copy.deepcopy(self.axes),
         )
@@ -1097,7 +1023,7 @@ class HpxGeom(Geom):
         return self.__class__(
             self.nside.copy(),
             self.nest,
-            coordsys=self.coordsys,
+            frame=self.frame,
             region=idx,
             axes=copy.deepcopy(self.axes),
         )
@@ -1110,7 +1036,7 @@ class HpxGeom(Geom):
             return self.__class__(
                 self.nside * factor,
                 self.nest,
-                coordsys=self.coordsys,
+                frame=self.frame,
                 region=self.region,
                 axes=copy.deepcopy(self.axes),
             )
@@ -1126,7 +1052,7 @@ class HpxGeom(Geom):
         return self.__class__(
             self.nside * factor,
             self.nest,
-            coordsys=self.coordsys,
+            frame=self.frame,
             region=tuple(idx),
             axes=copy.deepcopy(self.axes),
         )
@@ -1139,7 +1065,7 @@ class HpxGeom(Geom):
             return self.__class__(
                 self.nside // factor,
                 self.nest,
-                coordsys=self.coordsys,
+                frame=self.frame,
                 region=self.region,
                 axes=copy.deepcopy(self.axes),
             )
@@ -1151,7 +1077,7 @@ class HpxGeom(Geom):
         return self.__class__(
             self.nside // factor,
             self.nest,
-            coordsys=self.coordsys,
+            frame=self.frame,
             region=tuple(idx),
             axes=copy.deepcopy(self.axes),
         )
@@ -1162,7 +1088,7 @@ class HpxGeom(Geom):
         nside=None,
         binsz=None,
         nest=True,
-        coordsys="CEL",
+        frame="icrs",
         region=None,
         axes=None,
         skydir=None,
@@ -1181,8 +1107,8 @@ class HpxGeom(Geom):
             value.  This option is superseded by nside.
         nest : bool
             True for HEALPIX "NESTED" indexing scheme, False for "RING" scheme
-        coordsys : {'CEL', 'GAL'}, optional
-            Coordinate system, either Galactic ('GAL') or Equatorial ('CEL').
+        frame : {"icrs", "galactic"}, optional
+            Coordinate system, either Galactic ("galactic") or Equatorial ("icrs").
         skydir : tuple or `~astropy.coordinates.SkyCoord`
             Sky position of map center.  Can be either a SkyCoord
             object or a tuple of longitude and latitude in deg in the
@@ -1221,14 +1147,14 @@ class HpxGeom(Geom):
         elif isinstance(skydir, tuple):
             lon, lat = skydir
         elif isinstance(skydir, SkyCoord):
-            lon, lat, frame = skycoord_to_lonlat(skydir, coordsys=coordsys)
+            lon, lat, frame = skycoord_to_lonlat(skydir, frame=frame)
         else:
             raise ValueError(f"Invalid type for skydir: {type(skydir)!r}")
 
         if region is None and width is not None:
             region = f"DISK({lon},{lat},{width/2})"
 
-        return cls(nside, nest=nest, coordsys=coordsys, region=region, axes=axes)
+        return cls(nside, nest=nest, frame=frame, region=region, axes=axes)
 
     @staticmethod
     def identify_hpx_convention(header):
@@ -1319,9 +1245,9 @@ class HpxGeom(Geom):
             raise ValueError("Failed to extract NSIDE or ORDER.")
 
         try:
-            coordsys = header[conv.coordsys]
+            frame = coordsys_to_frame(header[conv.frame])
         except KeyError:
-            coordsys = header.get("COORDSYS", "CEL")
+            frame = header.get("COORDSYS", "icrs")
 
         try:
             region = header["HPX_REG"]
@@ -1331,7 +1257,7 @@ class HpxGeom(Geom):
             except KeyError:
                 region = None
 
-        return cls(nside, nest, coordsys=coordsys, region=region, axes=axes)
+        return cls(nside, nest, frame=frame, region=region, axes=axes)
 
     @classmethod
     def from_hdu(cls, hdu, hdu_bands=None):
@@ -1381,7 +1307,7 @@ class HpxGeom(Geom):
             header["TELESCOP"] = "GLAST"
             header["INSTRUME"] = "LAT"
 
-        header[conv.coordsys] = self.coordsys
+        header[conv.frame] = frame_to_coordsys(self.frame)
         header["PIXTYPE"] = "HEALPIX"
         header["ORDERING"] = self.ordering
         header["INDXSCHM"] = indxschm
@@ -1391,7 +1317,7 @@ class HpxGeom(Geom):
         header["LASTPIX"] = np.max(self._maxpix) - 1
         header["HPX_CONV"] = conv.convname.upper()
 
-        if self.coordsys == "CEL":
+        if self.frame == "icrs":
             header["EQUINOX"] = (2000.0, "Equinox of RA & DEC specifications")
 
         if self.region:
@@ -1461,17 +1387,15 @@ class HpxGeom(Geom):
         """Compute the reference direction for this geometry."""
         import healpy as hp
 
-        frame = coordsys_to_frame(self.coordsys)
-
         if self.region == "explicit":
             idx = unravel_hpx_index(self._ipix, self._maxpix)
             nside = self._get_nside(idx)
             vec = hp.pix2vec(nside, idx[0], nest=self.nest)
             vec = np.array([np.mean(t) for t in vec])
             lonlat = hp.vec2ang(vec, lonlat=True)
-            return SkyCoord(lonlat[0], lonlat[1], frame=frame, unit="deg")
+            return SkyCoord(lonlat[0], lonlat[1], frame=self.frame, unit="deg")
 
-        return get_hpxregion_dir(self.region, self.coordsys)
+        return get_hpxregion_dir(self.region, self.frame)
 
     def _get_region_size(self):
         import healpy as hp
@@ -1482,8 +1406,7 @@ class HpxGeom(Geom):
             idx = unravel_hpx_index(self._ipix, self._maxpix)
             nside = self._get_nside(idx)
             ang = hp.pix2ang(nside, idx[0], nest=self.nest, lonlat=True)
-            frame = coordsys_to_frame(self.coordsys)
-            dirs = SkyCoord(ang[0], ang[1], unit="deg", frame=frame)
+            dirs = SkyCoord(ang[0], ang[1], unit="deg", frame=self.frame)
             return np.max(dirs.separation(self.center_skydir).deg)
 
         return get_hpxregion_size(self.region)
@@ -1539,7 +1462,7 @@ class HpxGeom(Geom):
         return WcsGeom.create(
             width=width,
             binsz=binsz,
-            coordsys=self.coordsys,
+            frame=self.frame,
             axes=axes,
             skydir=self.center_skydir,
             proj=proj,
@@ -1644,18 +1567,12 @@ class HpxGeom(Geom):
         for i, axis in enumerate(self.axes):
             cdict[axis.name] = coords[i + 2]
 
-        return MapCoord.create(cdict, coordsys=self.coordsys)
+        return MapCoord.create(cdict, frame=self.frame)
 
     def contains(self, coords):
         idx = self.coord_to_idx(coords)
         return np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
 
-    def get_skydirs(self):
-        """Get the sky coordinates of all the pixels in this geometry."""
-        coords = self.get_coord()
-        frame = "galactic" if self.coordsys == "GAL" else "icrs"
-        return SkyCoord(coords[0], coords[1], unit="deg", frame=frame)
-
     def solid_angle(self):
         """Solid angle array (`~astropy.units.Quantity` in ``sr``).
 
@@ -1677,7 +1594,7 @@ class HpxGeom(Geom):
             f"\tndim       : {self.ndim}\n"
             f"\tnside      : {self.nside[0]}\n"
             f"\tnested     : {self.nest}\n"
-            f"\tcoordsys   : {self.coordsys}\n"
+            f"\tframe   : {self.frame}\n"
             f"\tprojection : {self.projection}\n"
             f"\tcenter     : {lon:.1f} deg, {lat:.1f} deg\n"
         )
@@ -1701,7 +1618,7 @@ class HpxGeom(Geom):
 
         return (
             self.nside == other.nside
-            and self.coordsys == other.coordsys
+            and self.frame == other.frame
             and self.order == other.order
             and self.nest == other.nest
         )
@@ -1827,19 +1744,3 @@ class HpxToWcsMapping:
             wcs_data[~valid] = np.nan
 
         return wcs_data
-
-    def make_wcs_data_from_hpx_data(self, hpx_data, wcs, normalize=True):
-        """Create and fill a WCS map from the HEALPIX data using the pre-calculated mappings.
-
-        Parameters
-        ----------
-        hpx_data : TODO
-            The input HEALPIX data
-        wcs : TODO
-            The WCS object
-        normalize : bool
-            True -> preserve integral by splitting HEALPIX values between bins
-        """
-        wcs_data = np.zeros(wcs.npix)
-        self.fill_wcs_map_from_hpx_data(hpx_data, wcs_data, normalize)
-        return wcs_data
