@@ -3,26 +3,34 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 from astropy.io import fits
-from ..geom import MapAxis, MapCoord
-from ..hpx import HpxGeom, get_pix_size_from_nside, nside_to_order
-from ..hpx import make_hpx_to_wcs_mapping, unravel_hpx_index, ravel_hpx_index
-from ..hpx import get_hpxregion_dir, get_hpxregion_size, get_subpixels, get_superpixels
+from gammapy.maps import MapAxis, MapCoord
+from gammapy.maps.hpx import (
+    HpxGeom,
+    get_hpxregion_dir,
+    get_hpxregion_size,
+    get_pix_size_from_nside,
+    get_subpixels,
+    get_superpixels,
+    make_hpx_to_wcs_mapping,
+    nside_to_order,
+    ravel_hpx_index,
+    unravel_hpx_index,
+)
 
-pytest.importorskip("numpy", "1.13.0")
 pytest.importorskip("healpy")
 
 hpx_allsky_test_geoms = [
     # 2D All-sky
-    (8, False, "GAL", None, None),
+    (8, False, "galactic", None, None),
     # 3D All-sky
-    (8, False, "GAL", None, [MapAxis(np.logspace(0.0, 3.0, 4))]),
+    (8, False, "galactic", None, [MapAxis(np.logspace(0.0, 3.0, 4))]),
     # 3D All-sky w/ variable pixel size
-    ([2, 4, 8], False, "GAL", None, [MapAxis(np.logspace(0.0, 3.0, 4))]),
+    ([2, 4, 8], False, "galactic", None, [MapAxis(np.logspace(0.0, 3.0, 4))]),
     # 4D All-sky
     (
         8,
         False,
-        "GAL",
+        "galactic",
         None,
         [
             MapAxis(np.logspace(0.0, 3.0, 3), name="axis0"),
@@ -33,14 +41,14 @@ hpx_allsky_test_geoms = [
 
 hpx_partialsky_test_geoms = [
     # 2D Partial-sky
-    (8, False, "GAL", "DISK(110.,75.,10.)", None),
+    (8, False, "galactic", "DISK(110.,75.,10.)", None),
     # 3D Partial-sky
-    (8, False, "GAL", "DISK(110.,75.,10.)", [MapAxis(np.logspace(0.0, 3.0, 4))]),
+    (8, False, "galactic", "DISK(110.,75.,10.)", [MapAxis(np.logspace(0.0, 3.0, 4))]),
     # 3D Partial-sky w/ variable pixel size
     (
         [8, 16, 32],
         False,
-        "GAL",
+        "galactic",
         "DISK(110.,75.,10.)",
         [MapAxis(np.logspace(0.0, 3.0, 4))],
     ),
@@ -48,7 +56,7 @@ hpx_partialsky_test_geoms = [
     (
         [[8, 16, 32], [8, 8, 16]],
         False,
-        "GAL",
+        "galactic",
         "DISK(110.,75.,10.)",
         [
             MapAxis(np.logspace(0.0, 3.0, 3), name="axis0"),
@@ -158,24 +166,24 @@ def test_hpx_global_to_local():
     ax1 = np.linspace(0.0, 1.0, 3)
 
     # 2D All-sky
-    hpx = HpxGeom(16, False, "GAL")
+    hpx = HpxGeom(16, False, "galactic")
     assert_allclose(hpx[0], np.array([0]))
     assert_allclose(hpx[633], np.array([633]))
     assert_allclose(hpx[0, 633], np.array([0, 633]))
     assert_allclose(hpx[np.array([0, 633])], np.array([0, 633]))
 
     # 3D All-sky
-    hpx = HpxGeom(16, False, "GAL", axes=[ax0])
+    hpx = HpxGeom(16, False, "galactic", axes=[ax0])
     assert_allclose(
         hpx[(np.array([177, 177]), np.array([0, 1]))], np.array([177, 177 + 3072])
     )
 
     # 2D Partial-sky
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)")
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)")
     assert_allclose(hpx[0, 633, 706], np.array([-1, 0, 2]))
 
     # 3D Partial-sky
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     assert_allclose(hpx[633], np.array([0]))
     assert_allclose(hpx[49859], np.array([19]))
     assert_allclose(hpx[0, 633, 706, 49859, 49935], np.array([-1, 0, 2, 19, 21]))
@@ -188,7 +196,7 @@ def test_hpx_global_to_local():
     )
 
     # 3D Partial-sky w/ variable bin size
-    hpx = HpxGeom([32, 64], False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom([32, 64], False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
 
     assert_allclose(hpx[191], np.array([0]))
     assert_allclose(hpx[12995], np.array([6]))
@@ -200,7 +208,11 @@ def test_hpx_global_to_local():
 
     # 4D Partial-sky w/ variable bin size
     hpx = HpxGeom(
-        [[16, 32], [32, 64]], False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0, ax1]
+        [[16, 32], [32, 64]],
+        False,
+        "galactic",
+        region="DISK(110.,75.,2.)",
+        axes=[ax0, ax1],
     )
     assert_allclose(hpx[3263], np.array([1]))
     assert_allclose(hpx[28356], np.array([11]))
@@ -208,26 +220,24 @@ def test_hpx_global_to_local():
 
 
 @pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_allsky_test_geoms
+    ("nside", "nested", "frame", "region", "axes"), hpx_allsky_test_geoms
 )
-def test_hpxgeom_init_with_pix(nside, nested, coordsys, region, axes):
-    geom = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+def test_hpxgeom_init_with_pix(nside, nested, frame, region, axes):
+    geom = HpxGeom(nside, nested, frame, region=region, axes=axes)
 
     idx0 = geom.get_idx(flat=True)
     idx1 = tuple([t[::10] for t in idx0])
-    geom = HpxGeom(nside, nested, coordsys, region=idx0, axes=axes)
+    geom = HpxGeom(nside, nested, frame, region=idx0, axes=axes)
     assert_allclose(idx0, geom.get_idx(flat=True))
     assert_allclose(len(idx0[0]), np.sum(geom.npix))
-    geom = HpxGeom(nside, nested, coordsys, region=idx1, axes=axes)
+    geom = HpxGeom(nside, nested, frame, region=idx1, axes=axes)
     assert_allclose(idx1, geom.get_idx(flat=True))
     assert_allclose(len(idx1[0]), np.sum(geom.npix))
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_to_slice(nside, nested, coordsys, region, axes):
-    geom = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_to_slice(nside, nested, frame, region, axes):
+    geom = HpxGeom(nside, nested, frame, region=region, axes=axes)
     slices = tuple([slice(1, 2) for i in range(2, geom.ndim)])
     geom_slice = geom.to_slice(slices)
     assert_allclose(geom_slice.ndim, 2)
@@ -236,15 +246,13 @@ def test_hpxgeom_to_slice(nside, nested, coordsys, region, axes):
     idx = geom.get_idx(flat=True)
     idx_slice = geom_slice.get_idx(flat=True)
     if geom.ndim > 2:
-        m = np.all([np.in1d(t, [1]) for t in idx[1:]], axis=0)
+        m = np.all([np.isin(t, [1]) for t in idx[1:]], axis=0)
         assert_allclose(idx_slice, (idx[0][m],))
     else:
         assert_allclose(idx_slice, idx)
 
     # Test slicing with explicit geometry
-    geom = HpxGeom(
-        nside, nested, coordsys, region=tuple([t[::3] for t in idx]), axes=axes
-    )
+    geom = HpxGeom(nside, nested, frame, region=tuple([t[::3] for t in idx]), axes=axes)
     geom_slice = geom.to_slice(slices)
     assert_allclose(geom_slice.ndim, 2)
     assert_allclose(geom_slice.npix, np.squeeze(geom.npix[slices]))
@@ -252,17 +260,15 @@ def test_hpxgeom_to_slice(nside, nested, coordsys, region, axes):
     idx = geom.get_idx()
     idx_slice = geom_slice.get_idx()
     if geom.ndim > 2:
-        m = np.all([np.in1d(t, [1]) for t in idx[1:]], axis=0)
-        assert_allclose(idx_slice, (idx[0].flat[m],))
+        m = np.all([np.isin(t, [1]) for t in idx[1:]], axis=0)
+        assert_allclose(idx_slice, (idx[0][m],))
     else:
         assert_allclose(idx_slice, idx)
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_get_pix(nside, nested, coordsys, region, axes):
-    geom = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_get_pix(nside, nested, frame, region, axes):
+    geom = HpxGeom(nside, nested, frame, region=region, axes=axes)
     idx = geom.get_idx(local=False, flat=True)
     idx_local = geom.get_idx(local=True, flat=True)
     assert_allclose(idx, geom.local_to_global(idx_local))
@@ -273,13 +279,11 @@ def test_hpxgeom_get_pix(nside, nested, coordsys, region, axes):
         assert_allclose(idx_img, geom.local_to_global(idx_img_local))
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_coord_to_idx(nside, nested, coordsys, region, axes):
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_coord_to_idx(nside, nested, frame, region, axes):
     import healpy as hp
 
-    geom = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+    geom = HpxGeom(nside, nested, frame, region=region, axes=axes)
     lon = np.array([112.5, 135.0, 105.0])
     lat = np.array([75.3, 75.3, 74.6])
     coords = make_test_coords(geom, lon, lat)
@@ -322,24 +326,26 @@ def test_hpxgeom_coord_to_pix():
 
     # 2D all-sky
     coords = (lon, lat)
-    hpx = HpxGeom(64, False, "GAL")
+    hpx = HpxGeom(64, False, "galactic")
     assert_allclose(hpx.coord_to_pix(coords)[0], pix64)
 
     # 2D partial-sky
     coords = (lon, lat)
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)")
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)")
     assert_allclose(hpx.coord_to_pix(coords)[0], pix64)
 
     # 3D partial-sky
     coords = (lon, lat, z0)
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     assert_allclose(hpx.coord_to_pix(coords), (pix64, np.array([0, 1, 2])))
 
     # 3D partial-sky w/ variable bin size
     coords = (lon, lat, z0)
     nside = [16, 32, 64]
-    hpx_bins = [HpxGeom(n, False, "GAL", region="DISK(110.,75.,2.)") for n in nside]
-    hpx = HpxGeom(nside, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx_bins = [
+        HpxGeom(n, False, "galactic", region="DISK(110.,75.,2.)") for n in nside
+    ]
+    hpx = HpxGeom(nside, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     for i, (x, y, z) in enumerate(np.vstack(coords).T):
         pix0 = hpx.coord_to_pix((np.array([x]), np.array([y]), np.array([z])))
         pix1 = hpx_bins[i].coord_to_pix((np.array([x]), np.array([y])))
@@ -347,7 +353,7 @@ def test_hpxgeom_coord_to_pix():
 
     # 4D partial-sky
     coords = (lon, lat, z0, z1)
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0, ax1])
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0, ax1])
     assert_allclose(
         hpx.coord_to_pix(coords), (pix64, np.array([0, 1, 2]), np.array([0, 1, 2]))
     )
@@ -377,11 +383,11 @@ def test_hpx_get_hpxregion_size():
 
 
 def test_hpxgeom_get_hpxregion_dir():
-    refdir = get_hpxregion_dir("DISK(110.,75.,2.)", "GAL")
+    refdir = get_hpxregion_dir("DISK(110.,75.,2.)", "galactic")
     assert_allclose(refdir.l.deg, 110.0)
     assert_allclose(refdir.b.deg, 75.0)
 
-    refdir = get_hpxregion_dir(None, "GAL")
+    refdir = get_hpxregion_dir(None, "galactic")
     assert_allclose(refdir.l.deg, 0.0)
     assert_allclose(refdir.b.deg, 0.0)
 
@@ -389,11 +395,11 @@ def test_hpxgeom_get_hpxregion_dir():
 def test_hpxgeom_make_wcs():
     ax0 = np.linspace(0.0, 3.0, 4)
 
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)")
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)")
     wcs = hpx.make_wcs()
     assert_allclose(wcs.wcs.wcs.crval, np.array([110.0, 75.0]))
 
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     wcs = hpx.make_wcs()
     assert_allclose(wcs.wcs.wcs.crval, np.array([110.0, 75.0]))
 
@@ -402,44 +408,44 @@ def test_hpxgeom_get_coord():
     ax0 = np.linspace(0.0, 3.0, 4)
 
     # 2D all-sky
-    hpx = HpxGeom(16, False, "GAL")
+    hpx = HpxGeom(16, False, "galactic")
     c = hpx.get_coord()
     assert_allclose(c[0][:3], np.array([45.0, 135.0, 225.0]))
     assert_allclose(c[1][:3], np.array([87.075819, 87.075819, 87.075819]))
 
     # 3D all-sky
-    hpx = HpxGeom(16, False, "GAL", axes=[ax0])
+    hpx = HpxGeom(16, False, "galactic", axes=[ax0])
     c = hpx.get_coord()
     assert_allclose(c[0][0, :3], np.array([45.0, 135.0, 225.0]))
     assert_allclose(c[1][0, :3], np.array([87.075819, 87.075819, 87.075819]))
     assert_allclose(c[2][0, :3], np.array([0.5, 0.5, 0.5]))
 
     # 2D partial-sky
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)")
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)")
     c = hpx.get_coord()
     assert_allclose(c[0][:3], np.array([107.5, 112.5, 106.57894737]))
     assert_allclose(c[1][:3], np.array([76.813533, 76.813533, 76.07742]))
 
     # 3D partial-sky
-    hpx = HpxGeom(64, False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom(64, False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     c = hpx.get_coord()
     assert_allclose(c[0][0, :3], np.array([107.5, 112.5, 106.57894737]))
     assert_allclose(c[1][0, :3], np.array([76.813533, 76.813533, 76.07742]))
     assert_allclose(c[2][0, :3], np.array([0.5, 0.5, 0.5]))
 
     # 3D partial-sky w/ variable bin size
-    hpx = HpxGeom([16, 32, 64], False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom(
+        [16, 32, 64], False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0]
+    )
     c = hpx.get_coord(flat=True)
     assert_allclose(c[0][:3], np.array([117.0, 103.5, 112.5]))
     assert_allclose(c[1][:3], np.array([75.340734, 75.340734, 75.340734]))
     assert_allclose(c[2][:3], np.array([0.5, 1.5, 1.5]))
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_contains(nside, nested, coordsys, region, axes):
-    geom = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_contains(nside, nested, frame, region, axes):
+    geom = HpxGeom(nside, nested, frame, region=region, axes=axes)
     coords = geom.get_coord(flat=True)
     assert_allclose(geom.contains(coords), np.ones_like(coords[0], dtype=bool))
 
@@ -454,7 +460,7 @@ def test_hpxgeom_contains(nside, nested, coordsys, region, axes):
 
 def test_make_hpx_to_wcs_mapping():
     ax0 = np.linspace(0.0, 1.0, 3)
-    hpx = HpxGeom(16, False, "GAL", region="DISK(110.,75.,2.)")
+    hpx = HpxGeom(16, False, "galactic", region="DISK(110.,75.,2.)")
     # FIXME construct explicit WCS projection here
     wcs = hpx.make_wcs()
     hpx2wcs = make_hpx_to_wcs_mapping(hpx, wcs)
@@ -545,7 +551,7 @@ def test_make_hpx_to_wcs_mapping():
         ),
     )
 
-    hpx = HpxGeom([8, 16], False, "GAL", region="DISK(110.,75.,2.)", axes=[ax0])
+    hpx = HpxGeom([8, 16], False, "galactic", region="DISK(110.,75.,2.)", axes=[ax0])
     hpx2wcs = make_hpx_to_wcs_mapping(hpx, wcs)
     assert_allclose(
         hpx2wcs[0],
@@ -651,39 +657,34 @@ def test_hpxgeom_from_header():
     header.update(pars)
     hpx = HpxGeom.from_header(header)
 
-    assert hpx.coordsys == pars["COORDSYS"]
+    assert hpx.frame == "icrs"
     assert hpx.nest is False
     assert_allclose(hpx.nside, np.array([64]))
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_read_write(tmpdir, nside, nested, coordsys, region, axes):
-    geom0 = HpxGeom(nside, nested, coordsys, region=region, axes=axes)
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_read_write(tmp_path, nside, nested, frame, region, axes):
+    geom0 = HpxGeom(nside, nested, frame, region=region, axes=axes)
     hdu_bands = geom0.make_bands_hdu(hdu="BANDS")
     hdu_prim = fits.PrimaryHDU()
     hdu_prim.header.update(geom0.make_header())
 
-    filename = str(tmpdir / "hpxgeom.fits")
     hdulist = fits.HDUList([hdu_prim, hdu_bands])
-    hdulist.writeto(filename, overwrite=True)
+    hdulist.writeto(tmp_path / "tmp.fits")
 
-    hdulist = fits.open(filename)
-    geom1 = HpxGeom.from_header(hdulist[0].header, hdulist["BANDS"])
+    with fits.open(tmp_path / "tmp.fits", memmap=False) as hdulist:
+        geom1 = HpxGeom.from_header(hdulist[0].header, hdulist["BANDS"])
 
     assert_allclose(geom0.nside, geom1.nside)
     assert_allclose(geom0.npix, geom1.npix)
     assert_allclose(geom0.nest, geom1.nest)
-    assert geom0.coordsys == geom1.coordsys
+    assert geom0.frame == geom1.frame
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_upsample(nside, nested, coordsys, region, axes):
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_upsample(nside, nested, frame, region, axes):
     # NESTED
-    geom = HpxGeom(nside, True, coordsys, region=region, axes=axes)
+    geom = HpxGeom(nside, True, frame, region=region, axes=axes)
     geom_up = geom.upsample(2)
     assert_allclose(2 * geom.nside, geom_up.nside)
     assert_allclose(4 * geom.npix, geom_up.npix)
@@ -691,7 +692,7 @@ def test_hpxgeom_upsample(nside, nested, coordsys, region, axes):
     assert np.all(geom.contains(coords))
 
     # RING
-    geom = HpxGeom(nside, False, coordsys, region=region, axes=axes)
+    geom = HpxGeom(nside, False, frame, region=region, axes=axes)
     geom_up = geom.upsample(2)
     assert_allclose(2 * geom.nside, geom_up.nside)
     assert_allclose(4 * geom.npix, geom_up.npix)
@@ -699,19 +700,17 @@ def test_hpxgeom_upsample(nside, nested, coordsys, region, axes):
     assert np.all(geom.contains(coords))
 
 
-@pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "axes"), hpx_test_geoms
-)
-def test_hpxgeom_downsample(nside, nested, coordsys, region, axes):
+@pytest.mark.parametrize(("nside", "nested", "frame", "region", "axes"), hpx_test_geoms)
+def test_hpxgeom_downsample(nside, nested, frame, region, axes):
     # NESTED
-    geom = HpxGeom(nside, True, coordsys, region=region, axes=axes)
+    geom = HpxGeom(nside, True, frame, region=region, axes=axes)
     geom_down = geom.downsample(2)
     assert_allclose(geom.nside, 2 * geom_down.nside)
     coords = geom.get_coord(flat=True)
     assert np.all(geom_down.contains(coords))
 
     # RING
-    geom = HpxGeom(nside, False, coordsys, region=region, axes=axes)
+    geom = HpxGeom(nside, False, frame, region=region, axes=axes)
     geom_down = geom.downsample(2)
     assert_allclose(geom.nside, 2 * geom_down.nside)
     coords = geom.get_coord(flat=True)
@@ -719,7 +718,9 @@ def test_hpxgeom_downsample(nside, nested, coordsys, region, axes):
 
 
 def test_hpxgeom_solid_angle():
-    geom = HpxGeom.create(nside=8, coordsys="GAL", axes=[MapAxis.from_edges([0, 2, 3])])
+    geom = HpxGeom.create(
+        nside=8, frame="galactic", axes=[MapAxis.from_edges([0, 2, 3])]
+    )
 
     solid_angle = geom.solid_angle()
 
@@ -734,19 +735,19 @@ def test_geom_repr():
 
 
 hpx_equality_test_geoms = [
-    (16, False, "GAL", None, True),
-    (16, True, "GAL", None, False),
-    (8, False, "GAL", None, False),
-    (16, False, "CEL", None, False),
+    (16, False, "galactic", None, True),
+    (16, True, "galactic", None, False),
+    (8, False, "galactic", None, False),
+    (16, False, "icrs", None, False),
 ]
 
 
 @pytest.mark.parametrize(
-    ("nside", "nested", "coordsys", "region", "result"), hpx_equality_test_geoms
+    ("nside", "nested", "frame", "region", "result"), hpx_equality_test_geoms
 )
-def test_hpxgeom_equal(nside, nested, coordsys, region, result):
-    geom0 = HpxGeom(16, False, "GAL", region=None)
-    geom1 = HpxGeom(nside, nested, coordsys, region=region)
+def test_hpxgeom_equal(nside, nested, frame, region, result):
+    geom0 = HpxGeom(16, False, "galactic", region=None)
+    geom1 = HpxGeom(nside, nested, frame, region=region)
 
     assert (geom0 == geom1) is result
     assert (geom0 != geom1) is not result
