@@ -3,7 +3,7 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose, assert_equal
 import astropy.units as u
-from astropy.convolution import Gaussian2DKernel
+from astropy.convolution import Box2DKernel, Gaussian2DKernel
 from astropy.coordinates import SkyCoord
 from astropy.io import fits
 from astropy.table import Table
@@ -28,31 +28,29 @@ axes2 = [
 skydir = SkyCoord(110.0, 75.0, unit="deg", frame="icrs")
 
 wcs_allsky_test_geoms = [
-    (None, 10.0, "GAL", "AIT", skydir, None),
-    (None, 10.0, "GAL", "AIT", skydir, axes1),
-    (None, [10.0, 20.0], "GAL", "AIT", skydir, axes1),
-    (None, 10.0, "GAL", "AIT", skydir, axes2),
-    (None, [[10.0, 20.0, 30.0], [10.0, 20.0, 30.0]], "GAL", "AIT", skydir, axes2),
+    (None, 10.0, "galactic", "AIT", skydir, None),
+    (None, 10.0, "galactic", "AIT", skydir, axes1),
+    (None, [10.0, 20.0], "galactic", "AIT", skydir, axes1),
+    (None, 10.0, "galactic", "AIT", skydir, axes2),
+    (None, [[10.0, 20.0, 30.0], [10.0, 20.0, 30.0]], "galactic", "AIT", skydir, axes2),
 ]
 
 wcs_partialsky_test_geoms = [
-    (10, 1.0, "GAL", "AIT", skydir, None),
-    (10, 1.0, "GAL", "AIT", skydir, axes1),
-    (10, [1.0, 2.0], "GAL", "AIT", skydir, axes1),
-    (10, 1.0, "GAL", "AIT", skydir, axes2),
-    (10, [[1.0, 2.0, 3.0], [1.0, 2.0, 3.0]], "GAL", "AIT", skydir, axes2),
+    (10, 1.0, "galactic", "AIT", skydir, None),
+    (10, 1.0, "galactic", "AIT", skydir, axes1),
+    (10, [1.0, 2.0], "galactic", "AIT", skydir, axes1),
+    (10, 1.0, "galactic", "AIT", skydir, axes2),
+    (10, [[1.0, 2.0, 3.0], [1.0, 2.0, 3.0]], "galactic", "AIT", skydir, axes2),
 ]
 
 wcs_test_geoms = wcs_allsky_test_geoms + wcs_partialsky_test_geoms
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_init(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_init(npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m0 = WcsNDMap(geom)
     coords = m0.geom.get_coord()
     m0.set_by_coord(coords, coords[1])
@@ -61,12 +59,10 @@ def test_wcsndmap_init(npix, binsz, coordsys, proj, skydir, axes):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_read_write(tmp_path, npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_read_write(tmp_path, npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     path = tmp_path / "tmp.fits"
 
     m0 = WcsNDMap(geom)
@@ -98,7 +94,7 @@ def test_wcsndmap_read_write_fgst(tmp_path):
     path = tmp_path / "tmp.fits"
 
     axis = MapAxis.from_bounds(100.0, 1000.0, 4, name="energy", unit="MeV")
-    geom = WcsGeom.create(npix=10, binsz=1.0, proj="AIT", coordsys="GAL", axes=[axis])
+    geom = WcsGeom.create(npix=10, binsz=1.0, proj="AIT", frame="galactic", axes=[axis])
 
     # Test Counts Cube
     m = WcsNDMap(geom)
@@ -152,11 +148,11 @@ def test_wcs_nd_map_data_transpose_issue(tmp_path):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_set_get_by_pix(npix, binsz, coordsys, proj, skydir, axes):
+def test_wcsndmap_set_get_by_pix(npix, binsz, frame, proj, skydir, axes):
     geom = WcsGeom.create(
-        npix=npix, binsz=binsz, skydir=skydir, proj=proj, coordsys=coordsys, axes=axes
+        npix=npix, binsz=binsz, skydir=skydir, proj=proj, frame=frame, axes=axes
     )
     m = WcsNDMap(geom)
     coords = m.geom.get_coord()
@@ -178,11 +174,11 @@ def test_get_by_coord_bool_int():
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_set_get_by_coord(npix, binsz, coordsys, proj, skydir, axes):
+def test_wcsndmap_set_get_by_coord(npix, binsz, frame, proj, skydir, axes):
     geom = WcsGeom.create(
-        npix=npix, binsz=binsz, skydir=skydir, proj=proj, coordsys=coordsys, axes=axes
+        npix=npix, binsz=binsz, skydir=skydir, proj=proj, frame=frame, axes=axes
     )
     m = WcsNDMap(geom)
     coords = m.geom.get_coord()
@@ -210,7 +206,7 @@ def test_wcsndmap_set_get_by_coord(npix, binsz, coordsys, proj, skydir, axes):
     if axes:
         for i, ax in enumerate(axes):
             coords_dict[ax.name] = coords[i + 2]
-    map_coords = MapCoord.create(coords_dict, coordsys=coordsys)
+    map_coords = MapCoord.create(coords_dict, frame=frame)
     m.set_by_coord(map_coords, coords[0])
     assert_allclose(coords[0].value, m.get_by_coord(map_coords))
 
@@ -233,11 +229,11 @@ def qconcatenate(q_1, q_2):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_fill_by_coord(npix, binsz, coordsys, proj, skydir, axes):
+def test_wcsndmap_fill_by_coord(npix, binsz, frame, proj, skydir, axes):
     geom = WcsGeom.create(
-        npix=npix, binsz=binsz, skydir=skydir, proj=proj, coordsys=coordsys, axes=axes
+        npix=npix, binsz=binsz, skydir=skydir, proj=proj, frame=frame, axes=axes
     )
     m = WcsNDMap(geom)
     coords = m.geom.get_coord()
@@ -261,11 +257,11 @@ def test_wcsndmap_fill_by_coord(npix, binsz, coordsys, proj, skydir, axes):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_coadd(npix, binsz, coordsys, proj, skydir, axes):
+def test_wcsndmap_coadd(npix, binsz, frame, proj, skydir, axes):
     geom = WcsGeom.create(
-        npix=npix, binsz=binsz, skydir=skydir, proj=proj, coordsys=coordsys, axes=axes
+        npix=npix, binsz=binsz, skydir=skydir, proj=proj, frame=frame, axes=axes
     )
     m0 = WcsNDMap(geom)
     m1 = WcsNDMap(geom.upsample(2))
@@ -279,11 +275,11 @@ def test_wcsndmap_coadd(npix, binsz, coordsys, proj, skydir, axes):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_interp_by_coord(npix, binsz, coordsys, proj, skydir, axes):
+def test_wcsndmap_interp_by_coord(npix, binsz, frame, proj, skydir, axes):
     geom = WcsGeom.create(
-        npix=npix, binsz=binsz, skydir=skydir, proj=proj, coordsys=coordsys, axes=axes
+        npix=npix, binsz=binsz, skydir=skydir, proj=proj, frame=frame, axes=axes
     )
     m = WcsNDMap(geom)
     coords = m.geom.get_coord(flat=True)
@@ -326,13 +322,11 @@ def test_wcsndmap_interp_by_coord_fill_value():
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
 @pytest.mark.parametrize("keepdims", [True, False])
-def test_wcsndmap_sum_over_axes(npix, binsz, coordsys, proj, skydir, axes, keepdims):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_sum_over_axes(npix, binsz, frame, proj, skydir, axes, keepdims):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m = WcsNDMap(geom)
     coords = m.geom.get_coord()
     m.fill_by_coord(coords, coords[0].value)
@@ -343,12 +337,10 @@ def test_wcsndmap_sum_over_axes(npix, binsz, coordsys, proj, skydir, axes, keepd
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_pad(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_pad(npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m = WcsNDMap(geom)
     m2 = m.pad(1, mode="constant", cval=2.2)
     if not geom.is_allsky:
@@ -370,23 +362,19 @@ def test_wcsndmap_pad_cval():
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_crop(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_crop(npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m = WcsNDMap(geom)
     m.crop(1)
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_downsample(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_downsample(npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m = WcsNDMap(geom, unit="m2")
     # Check whether we can downsample
     if np.all(np.mod(geom.npix[0], 2) == 0) and np.all(np.mod(geom.npix[1], 2) == 0):
@@ -396,12 +384,10 @@ def test_wcsndmap_downsample(npix, binsz, coordsys, proj, skydir, axes):
 
 
 @pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
+    ("npix", "binsz", "frame", "proj", "skydir", "axes"), wcs_test_geoms
 )
-def test_wcsndmap_upsample(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
+def test_wcsndmap_upsample(npix, binsz, frame, proj, skydir, axes):
+    geom = WcsGeom.create(npix=npix, binsz=binsz, proj=proj, frame=frame, axes=axes)
     m = WcsNDMap(geom, unit="m2")
     m2 = m.upsample(2, preserve_counts=True)
     assert_allclose(np.nansum(m.data), np.nansum(m2.data))
@@ -430,7 +416,7 @@ def test_wcsndmap_downsample_axis():
 
 
 def test_coadd_unit():
-    geom = WcsGeom.create(npix=(10, 10), binsz=1, proj="CAR", coordsys="GAL")
+    geom = WcsGeom.create(npix=(10, 10), binsz=1, proj="CAR", frame="galactic")
     m1 = WcsNDMap(geom, data=np.ones((10, 10)), unit="m2")
     m2 = WcsNDMap(geom, data=np.ones((10, 10)), unit="cm2")
 
@@ -445,7 +431,9 @@ def test_smooth(kernel):
         MapAxis(np.logspace(0.0, 3.0, 3), interp="log"),
         MapAxis(np.logspace(1.0, 3.0, 4), interp="lin"),
     ]
-    geom = WcsGeom.create(npix=(10, 10), binsz=1, proj="CAR", coordsys="GAL", axes=axes)
+    geom = WcsGeom.create(
+        npix=(10, 10), binsz=1, proj="CAR", frame="galactic", axes=axes
+    )
     m = WcsNDMap(geom, data=np.ones(geom.data_shape), unit="m2")
 
     desired = m.data.sum()
@@ -459,7 +447,7 @@ def test_smooth(kernel):
 def test_make_cutout(mode):
     pos = SkyCoord(0, 0, unit="deg", frame="galactic")
     geom = WcsGeom.create(
-        npix=(10, 10), binsz=1, skydir=pos, proj="CAR", coordsys="GAL", axes=axes2
+        npix=(10, 10), binsz=1, skydir=pos, proj="CAR", frame="galactic", axes=axes2
     )
     m = WcsNDMap(geom, data=np.ones((3, 2, 10, 10)), unit="m2")
     cutout = m.cutout(position=pos, width=(2.0, 3.0) * u.deg, mode=mode)
@@ -506,9 +494,14 @@ def test_convolve_nd():
     assert psf_kernel.psf_kernel_map.data.shape == (3, 101, 101)
 
     mc = m.convolve(psf_kernel)
-
     assert_allclose(mc.data.sum(axis=(1, 2)), [0, 1, 1], atol=1e-5)
 
+    kernel_2d = Box2DKernel(3, mode="center")
+    kernel_2d.normalize("peak")
+    mc = m.convolve(kernel_2d.array)
+    assert_allclose(mc.data[0, :, :].sum(), 0, atol=1e-5)
+    assert_allclose(mc.data[1, :, :].sum(), 9, atol=1e-5)
+
 
 def test_convolve_pixel_scale_error():
     m = WcsNDMap.create(binsz=0.05 * u.deg, width=5 * u.deg)
@@ -538,7 +531,7 @@ def test_get_spectrum():
     axis = MapAxis.from_bounds(1, 10, nbin=3, unit="TeV", name="energy")
 
     geom = WcsGeom.create(
-        skydir=(0, 0), width=(2.5, 2.5), binsz=0.5, axes=[axis], coordsys="GAL"
+        skydir=(0, 0), width=(2.5, 2.5), binsz=0.5, axes=[axis], frame="galactic"
     )
 
     m = Map.from_geom(geom)
@@ -566,7 +559,7 @@ def get_npred_map():
         skydir=position,
         width="2 deg",
         axes=[energy_axis],
-        coordsys="GAL",
+        frame="galactic",
         unit="cm2 s",
     )
 
@@ -603,3 +596,50 @@ def test_map_sampling():
     assert coords["lon"].unit == "deg"
     assert coords["lat"].unit == "deg"
     assert coords["energy"].unit == "TeV"
+
+
+def test_map_interp_one_bin():
+    m = WcsNDMap.create(npix=(2, 1))
+    m.data = np.array([[1, 2]])
+
+    coords = {"lon": 0, "lat": [0, 0]}
+    data = m.interp_by_coord(coords)
+
+    assert data.shape == (2,)
+    assert_allclose(data, 1.5)
+
+
+def test_sum_over_axes():
+    # Check summing over a specific axis
+    ax1 = MapAxis.from_nodes([1, 2, 3, 4], name="ax1")
+    ax2 = MapAxis.from_nodes([5, 6, 7], name="ax2")
+    ax3 = MapAxis.from_nodes([8, 9], name="ax3")
+    geom = WcsGeom.create(npix=(5, 5), axes=[ax1, ax2, ax3])
+    m1 = Map.from_geom(geom=geom)
+    m1.data = np.ones(m1.data.shape)
+    m2 = m1.sum_over_axes(axes=["ax1", "ax3"], keepdims=True)
+
+    assert_allclose(m2.geom.data_shape, (1, 3, 1, 5, 5))
+    assert_allclose(m2.data[0][0][0][0][0], 8.0)
+
+    m3 = m1.sum_over_axes(axes=["ax3", "ax2"], keepdims=False)
+    assert_allclose(m3.geom.data_shape, (4, 5, 5))
+    assert_allclose(m3.data[0][0][0], 6.0)
+
+
+def test_reduce():
+    # Check summing over a specific axis
+    ax1 = MapAxis.from_nodes([1, 2, 3, 4], name="ax1")
+    ax2 = MapAxis.from_nodes([5, 6, 7], name="ax2")
+    ax3 = MapAxis.from_nodes([8, 9], name="ax3")
+    geom = WcsGeom.create(npix=(5, 5), axes=[ax1, ax2, ax3])
+    m1 = Map.from_geom(geom=geom)
+    m1.data = np.ones(m1.data.shape)
+    m2 = m1.reduce(axis="ax1", keepdims=True)
+
+    assert_allclose(m2.geom.data_shape, (2, 3, 1, 5, 5))
+    assert_allclose(m2.data[0][0][0][0][0], 4.0)
+
+    m3 = m1.reduce(axis="ax1", keepdims=False)
+    assert_allclose(m3.geom.data_shape, (2, 3, 5, 5))
+    assert_allclose(m3.data[0][0][0][0], 4.0)
