@@ -205,7 +205,7 @@ class WcsNDMap(WcsMap):
         idx = pix_tuple_to_idx(idx)
         self.data.T[idx] = vals
 
-    def sum_over_axes(self, keepdims=False):
+    def sum_over_axes(self, axes=None, keepdims=False):
         """To sum map values over all non-spatial axes.
 
         Parameters
@@ -213,39 +213,73 @@ class WcsNDMap(WcsMap):
         keepdims : bool, optional
             If this is set to true, the axes which are summed over are left in
             the map with a single bin
+        axes: list
+            Names of MapAxis to reduce over
+            If None, all will summed over
 
         Returns
         -------
-        map_out : WcsNDMap
+        map_out : `~WcsNDMap`
             Map with non-spatial axes summed over
         """
-        return self.reduce_over_axes(func=np.add, keepdims=keepdims)
+        return self.reduce_over_axes(func=np.add, axes=axes, keepdims=keepdims)
 
-    def reduce_over_axes(self, func, keepdims=False):
-        """Reduce map over all non spatial axes
+    def reduce_over_axes(self, func=np.add, keepdims=False, axes=None):
+        """Reduce map over non-spatial axes
 
         Parameters
         ----------
-        func : ~numpy.ufunc
+        func : `~numpy.ufunc`
+            Function to use for reducing the data.
+        keepdims : bool, optional
+            If this is set to true, the axes which are summed over are left in
+            the map with a single bin
+        axes: list
+            Names of MapAxis to reduce over
+            If None, all will reduced
+
+        Returns
+        -------
+        map_out : `~WcsNDMap`
+            Map with non-spatial axes reduced
+        """
+        if axes is None:
+            axes = [ax.name for ax in self.geom.axes]
+
+        map_out = self.copy()
+        for ax in axes:
+            map_out = map_out.reduce(ax, func=func, keepdims=keepdims)
+        return map_out
+
+    def reduce(self, axis, func=np.add, keepdims=False):
+        """Reduce map over a single non-spatial axis
+
+        Parameters
+        ----------
+        axis: str
+            The name of the axis to reduce over
+        func : `~numpy.ufunc`
             Function to use for reducing the data.
         keepdims : bool, optional
             If this is set to true, the axes which are summed over are left in
             the map with a single bin
 
+
         Returns
         -------
-        map_out : WcsNDMap
-            Map with non-spatial axes reduced
+        map_out : `~WcsNDMap`
+            Map with the given non-spatial axes reduced
         """
-        axis = tuple(range(self.data.ndim - 2))
-        geom = self.geom.to_image()
         if keepdims:
-            for ax in self.geom.axes:
-                geom = geom.to_cube([ax.squash()])
+            geom = self.geom.squash(axis=axis)
+        else:
+            geom = self.geom.drop(axis=axis)
+
+        names = [ax.name for ax in reversed(self.geom.axes)]
+        idx = names.index(axis)
         data = func.reduce(
-            self.data, axis=axis, keepdims=keepdims, where=~np.isnan(self.data)
+            self.data, axis=idx, keepdims=keepdims, where=~np.isnan(self.data)
         )
-        # TODO: summing over the axis can change the unit, handle this correctly
         return self._init_copy(geom=geom, data=data)
 
     def pad(self, pad_width, mode="constant", cval=0, order=1):
@@ -448,7 +482,7 @@ class WcsNDMap(WcsMap):
         ax.set_xlim(xmin, xmax)
         ax.set_ylim(ymin, ymax)
 
-        ax.text(0, ymax, self.geom.coordsys + " coords")
+        ax.text(0, ymax, self.geom.frame + " coords")
 
         # Grid and ticks
         glon_spacing, glat_spacing = 45, 15
@@ -545,7 +579,11 @@ class WcsNDMap(WcsMap):
 
         edges = energy_axis.edges
         return CountsSpectrum(
-            data=data, energy_lo=edges[:-1], energy_hi=edges[1:], unit=self.unit
+            data=data,
+            energy_lo=edges[:-1],
+            energy_hi=edges[1:],
+            unit=self.unit,
+            region=region,
         )
 
     def convolve(self, kernel, use_fft=True, **kwargs):
@@ -584,11 +622,13 @@ class WcsNDMap(WcsMap):
                 self.geom.pixel_scales.deg, kmap.geom.pixel_scales.deg, rtol=1e-5
             ):
                 raise ValueError("Pixel size of kernel and map not compatible.")
-            kernel = kmap.data
+            kernel = kmap.data.astype(np.float32)
 
         for img, idx in self.iter_by_image():
-            idx = Ellipsis if kernel.ndim == 2 else idx
-            convolved_data[idx] = conv_function(img, kernel[idx], **kwargs)
+            ikern = Ellipsis if kernel.ndim == 2 else idx
+            convolved_data[idx] = conv_function(
+                img.astype(np.float32), kernel[ikern], **kwargs
+            )
 
         return self._init_copy(data=convolved_data)
 
@@ -597,7 +637,7 @@ class WcsNDMap(WcsMap):
 
         Parameters
         ----------
-        edisp : `gammapy.irf.EnergyDispersion`
+        edisp : `gammapy.irf.EDispKernel`
             Energy dispersion matrix
 
         Returns
@@ -636,9 +676,13 @@ class WcsNDMap(WcsMap):
         geom_cutout = self.geom.cutout(position=position, width=width, mode=mode)
 
         slices = geom_cutout.cutout_info["parent-slices"]
+        parent_slices = Ellipsis, slices[0], slices[1]
+
+        slices = geom_cutout.cutout_info["cutout-slices"]
         cutout_slices = Ellipsis, slices[0], slices[1]
 
-        data = self.data[cutout_slices]
+        data = np.zeros(shape=geom_cutout.data_shape, dtype=self.data.dtype)
+        data[cutout_slices] = self.data[parent_slices]
 
         return self._init_copy(geom=geom_cutout, data=data)
 
@@ -650,7 +694,8 @@ class WcsNDMap(WcsMap):
         other : `WcsNDMap`
             Other map to stack
         weights : `WcsNDMap`
-            Array to be used as weights.
+            Array to be used as weights. The spatial geometry must be equivalent
+            to `other` and additional axes must be broadcastable.
         """
         if self.geom == other.geom:
             parent_slices, cutout_slices = None, None
@@ -668,7 +713,10 @@ class WcsNDMap(WcsMap):
         data = other.data[cutout_slices]
 
         if weights is not None:
-            data = data * weights.data
+            if not other.geom.to_image() == weights.geom.to_image():
+                raise ValueError("Incompatible spatial geoms between map and weights")
+
+            data = data * weights.data[cutout_slices]
 
         self.data[parent_slices] += data
 
@@ -699,4 +747,4 @@ class WcsNDMap(WcsMap):
         axes_names = ["lon", "lat"] + [ax.name for ax in self.geom.axes]
         cdict = OrderedDict(zip(axes_names, coords))
 
-        return MapCoord.create(cdict, coordsys=self.geom.coordsys)
+        return MapCoord.create(cdict, frame=self.geom.frame)
