@@ -7,10 +7,51 @@ import scipy.special
 import astropy.units as u
 from astropy.table import Table
 from gammapy.maps import MapAxis
-from gammapy.modeling import Model, Parameter, Parameters
-from gammapy.utils.integrate import integrate_spectrum
+from gammapy.maps.utils import edges_from_lo_hi
+from gammapy.modeling import Parameter, Parameters
+from gammapy.utils.integrate import evaluate_integral_pwl, trapz_loglog
 from gammapy.utils.interpolation import ScaledRegularGridInterpolator
 from gammapy.utils.scripts import make_path
+from .core import Model
+
+
+def integrate_spectrum(func, emin, emax, ndecade=100, intervals=False):
+    """Integrate 1d function using the log-log trapezoidal rule.
+
+    If scalar values for xmin and xmax are passed an oversampled grid is generated using the
+    ``ndecade`` keyword argument. If xmin and xmax arrays are passed, no
+    oversampling is performed and the integral is computed in the provided
+    grid.
+
+    Parameters
+    ----------
+    func : callable
+        Function to integrate.
+    emin : `~astropy.units.Quantity`
+        Integration range minimum
+    emax : `~astropy.units.Quantity`
+        Integration range minimum
+    ndecade : int, optional
+        Number of grid points per decade used for the integration.
+        Default : 100.
+    intervals : bool, optional
+        Return integrals in the grid not the sum, default: False
+    """
+    if emin.isscalar and emax.isscalar:
+        energies = MapAxis.from_energy_bounds(
+            emin=emin, emax=emax, nbin=ndecade, per_decade=True
+        ).edges
+    else:
+        energies = edges_from_lo_hi(emin, emax)
+
+    values = func(energies)
+
+    integral = trapz_loglog(values, energies)
+
+    if intervals:
+        return integral
+
+    return integral.sum()
 
 
 class SpectralModel(Model):
@@ -339,7 +380,7 @@ class SpectralModel(Model):
 class ConstantSpectralModel(SpectralModel):
     r"""Constant model.
 
-    .. math:: \phi(E) = k
+    For more information see :ref:`constant-spectral-model`.
 
     Parameters
     ----------
@@ -359,7 +400,7 @@ class ConstantSpectralModel(SpectralModel):
 class CompoundSpectralModel(SpectralModel):
     """Arithmetic combination of two spectral models.
 
-    Itself again a spectral model.
+    For more information see :ref:`compound-spectral-model`.
     """
 
     tag = "CompoundSpectralModel"
@@ -398,8 +439,7 @@ class CompoundSpectralModel(SpectralModel):
 class PowerLawSpectralModel(SpectralModel):
     r"""Spectral power-law model.
 
-    .. math::
-        \phi(E) = \phi_0 \cdot \left( \frac{E}{E_0} \right)^{-\Gamma}
+    For more information see :ref:`powerlaw-spectral-model`.
 
     Parameters
     ----------
@@ -415,29 +455,13 @@ class PowerLawSpectralModel(SpectralModel):
     index = Parameter("index", 2.0)
     amplitude = Parameter("amplitude", "1e-12 cm-2 s-1 TeV-1")
     reference = Parameter("reference", "1 TeV", frozen=True)
+    evaluate_integral = staticmethod(evaluate_integral_pwl)
 
     @staticmethod
     def evaluate(energy, index, amplitude, reference):
         """Evaluate the model (static function)."""
         return amplitude * np.power((energy / reference), -index)
 
-    @staticmethod
-    def evaluate_integral(emin, emax, index, amplitude, reference):
-        """Evaluate the model integral (static function)."""
-        val = -1 * index + 1
-
-        prefactor = amplitude * reference / val
-        upper = np.power((emax / reference), val)
-        lower = np.power((emin / reference), val)
-        integral = prefactor * (upper - lower)
-
-        mask = np.isclose(val, 0)
-
-        if mask.any():
-            integral[mask] = (amplitude * reference * np.log(emax / emin))[mask]
-
-        return integral
-
     @staticmethod
     def evaluate_energy_flux(emin, emax, index, amplitude, reference):
         """Evaluate the energy flux (static function)"""
@@ -523,11 +547,7 @@ class PowerLawSpectralModel(SpectralModel):
 class PowerLaw2SpectralModel(SpectralModel):
     r"""Spectral power-law model with integral as amplitude parameter.
 
-    See also: https://fermi.gsfc.nasa.gov/ssc/data/analysis/scitools/source_models.html
-
-    .. math::
-        \phi(E) = F_0 \cdot \frac{\Gamma + 1}{E_{0, max}^{-\Gamma + 1}
-         - E_{0, min}^{-\Gamma + 1}} \cdot E^{-\Gamma}
+    For more information see :ref:`powerlaw2-spectral-model`.
 
     Parameters
     ----------
@@ -605,11 +625,47 @@ class PowerLaw2SpectralModel(SpectralModel):
         return np.power(term.to_value(""), -1.0 / index) * emax
 
 
+class SmoothBrokenPowerLawSpectralModel(SpectralModel):
+    r"""Spectral smooth broken power-law model.
+
+    For more information see :ref:`smooth-broken-powerlaw-spectral-model`.
+
+    Parameters
+    ----------
+    index1 : `~astropy.units.Quantity`
+        :math:`\Gamma1`
+    index2 : `~astropy.units.Quantity`
+        :math:`\Gamma2`
+    amplitude : `~astropy.units.Quantity`
+        :math:`\phi_0`
+    reference : `~astropy.units.Quantity`
+        :math:`E_0`
+    ebreak : `~astropy.units.Quantity`
+        :math:`E_{break}`
+    beta : `~astropy.units.Quantity`
+        :math:`\beta`
+    """
+
+    tag = "SmoothBrokenPowerLawSpectralModel"
+    index1 = Parameter("index1", 2.0)
+    index2 = Parameter("index2", 2.0)
+    amplitude = Parameter("amplitude", "1e-12 cm-2 s-1 TeV-1")
+    ebreak = Parameter("ebreak", "1 TeV")
+    reference = Parameter("reference", "1 TeV", frozen=True)
+    beta = Parameter("beta", 1, frozen=True)
+
+    @staticmethod
+    def evaluate(energy, index1, index2, amplitude, ebreak, reference, beta):
+        """Evaluate the model (static function)."""
+        pwl = amplitude * (energy / reference) ** (-index1)
+        brk = (1 + (energy / ebreak) ** ((index2 - index1) / beta)) ** (-beta)
+        return pwl * brk
+
+
 class ExpCutoffPowerLawSpectralModel(SpectralModel):
     r"""Spectral exponential cutoff power-law model.
 
-    .. math::
-        \phi(E) = \phi_0 \cdot \left(\frac{E}{E_0}\right)^{-\Gamma} \exp(- {(\lambda E})^{\alpha})
+    For more information see :ref:`exp-cutoff-powerlaw-spectral-model`.
 
     Parameters
     ----------
@@ -664,11 +720,7 @@ class ExpCutoffPowerLawSpectralModel(SpectralModel):
 class ExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
     r"""Spectral exponential cutoff power-law model used for 3FGL.
 
-    Note that the parametrization is different from `ExpCutoffPowerLawSpectralModel`:
-
-    .. math::
-        \phi(E) = \phi_0 \cdot \left(\frac{E}{E_0}\right)^{-\Gamma}
-                  \exp \left( \frac{E_0 - E}{E_{C}} \right)
+    For more information see :ref:`exp-cutoff-powerlaw-3fgl-spectral-model`.
 
     Parameters
     ----------
@@ -699,6 +751,8 @@ class ExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
 class SuperExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
     r"""Spectral super exponential cutoff power-law model used for 3FGL.
 
+    For more information see :ref:`super-exp-cutoff-powerlaw-3fgl-spectral-model`.
+
     .. math::
         \phi(E) = \phi_0 \cdot \left(\frac{E}{E_0}\right)^{-\Gamma_1}
                   \exp \left( \left(\frac{E_0}{E_{C}} \right)^{\Gamma_2} -
@@ -737,16 +791,7 @@ class SuperExpCutoffPowerLaw3FGLSpectralModel(SpectralModel):
 class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
     r"""Spectral super exponential cutoff power-law model used for 4FGL.
 
-    This model parametrisation is very similar, but slightly different from
-    `SuperExpCutoffPowerLaw3FGLSpectralModel` or `ExpCutoffPowerLaw3FGLSpectralModel`.
-
-    See Equation (3) in https://arxiv.org/pdf/1902.10045.pdf
-
-    .. math::
-        \phi(E) = \phi_0 \cdot \left(\frac{E}{E_0}\right)^{-\Gamma_1}
-                  \exp \left(
-                      a \left( E_0 ^{\Gamma_2} - E^{\Gamma_2} \right)
-                  \right)
+    For more information see :ref:`super-exp-cutoff-powerlaw-4fgl-spectral-model`.
 
     Parameters
     ----------
@@ -785,20 +830,7 @@ class SuperExpCutoffPowerLaw4FGLSpectralModel(SpectralModel):
 class LogParabolaSpectralModel(SpectralModel):
     r"""Spectral log parabola model.
 
-    .. math::
-        \phi(E) = \phi_0 \left( \frac{E}{E_0} \right) ^ {
-          - \alpha - \beta \log{ \left( \frac{E}{E_0} \right) }
-        }
-
-    Note that :math:`log` refers to the natural logarithm. This is consistent
-    with the `Fermi Science Tools
-    <https://fermi.gsfc.nasa.gov/ssc/data/analysis/scitools/source_models.html>`_
-    and `ctools
-    <http://cta.irap.omp.eu/ctools-devel/users/user_manual/getting_started/models.html#log-parabola>`_.
-    The `Sherpa <http://cxc.harvard.edu/sherpa/ahelp/logparabola.html_
-    package>`_ package, however, uses :math:`log_{10}`. If you have
-    parametrization based on :math:`log_{10}` you can use the
-    :func:`~gammapy.modeling.models.LogParabolaSpectralModel.from_log10` method.
+    For more information see :ref:`logparabola-spectral-model`.
 
     Parameters
     ----------
@@ -850,13 +882,7 @@ class LogParabolaSpectralModel(SpectralModel):
 class TemplateSpectralModel(SpectralModel):
     """A model generated from a table of energy and value arrays.
 
-    the units returned will be the units of the values array provided at
-    initialization. The model will return values interpolated in
-    log-space, returning 0 for energies outside of the limits of the provided
-    energy array.
-
-    Class implementation follows closely what has been done in
-    `naima.models.TemplateSpectralModel`
+    For more information see :ref:`template-spectral-model`.
 
     Parameters
     ----------
@@ -892,7 +918,7 @@ class TemplateSpectralModel(SpectralModel):
         meta=None,
     ):
         self.energy = energy
-        self.values = values
+        self.values = u.Quantity(values, copy=False)
         self.meta = dict() if meta is None else meta
         interp_kwargs = interp_kwargs or {}
         interp_kwargs.setdefault("values_scale", "log")
@@ -1008,7 +1034,7 @@ class ScaleSpectralModel(SpectralModel):
 class Absorption:
     r"""Gamma-ray absorption models.
 
-    Usually used as part of `AbsorbedSpectralModel`.
+    For more information see :ref:`absorption-spectral-model`.
 
     Parameters
     ----------
@@ -1018,6 +1044,12 @@ class Absorption:
         Parameter node values
     data : `~astropy.units.Quantity`
         Model value
+    filename : str
+        Filename of the absorption model used for serialisation.
+    interp_kwargs : dict
+        Interpolation option passed to `ScaledRegularGridInterpolator`.
+        By default the models are extrapolated outside the range. To prevent
+        this and raise an error instead use interp_kwargs = {"extrapolate": False}
     """
 
     tag = "Absorption"
@@ -1031,6 +1063,7 @@ class Absorption:
 
         interp_kwargs = interp_kwargs or {}
         interp_kwargs.setdefault("points_scale", ("log", "lin"))
+        interp_kwargs.setdefault("extrapolate", True)
 
         self._evaluate = ScaledRegularGridInterpolator(
             points=(self.param, self.energy), values=data, **interp_kwargs
@@ -1068,7 +1101,7 @@ class Absorption:
             return cls(energy=energy, param=param, data=values)
 
     @classmethod
-    def read(cls, filename):
+    def read(cls, filename, interp_kwargs=None):
         """Build object from an XSPEC model.
 
         Todo: Format of XSPEC binary files should be referenced at https://gamma-astro-data-formats.readthedocs.io/en/latest/
@@ -1077,6 +1110,13 @@ class Absorption:
         ----------
         filename : str
             File containing the model.
+        interp_kwargs : dict
+            Interpolation option passed to `ScaledRegularGridInterpolator`.
+
+        Returns
+        -------
+        absorption : `Absorption`
+            Absorption model.
         """
         # Create EBL data array
         filename = make_path(filename)
@@ -1098,10 +1138,16 @@ class Absorption:
         # Get spectrum values
         table_spectra = Table.read(filename, hdu="SPECTRA")
         data = table_spectra["INTPSPEC"].data[idx, :]
-        return cls(energy=energy, param=param, data=data, filename=filename)
+        return cls(
+            energy=energy,
+            param=param,
+            data=data,
+            filename=filename,
+            interp_kwargs=interp_kwargs,
+        )
 
     @classmethod
-    def read_builtin(cls, name):
+    def read_builtin(cls, name, interp_kwargs=None):
         """Read one of the built-in absorption models.
 
         Parameters
@@ -1117,21 +1163,32 @@ class Absorption:
             `Link <https://ui.adsabs.harvard.edu/abs/2011MNRAS.410.2556D>`__
         .. [3] Finke et al., "Modeling the Extragalactic Background Light from Stars and Dust"
             `Link <https://ui.adsabs.harvard.edu/abs/2010ApJ...712..238F>`__
+
+        Returns
+        -------
+        absorption : `Absorption`
+            Absorption model.
+
         """
         models = dict()
         models["franceschini"] = "$GAMMAPY_DATA/ebl/ebl_franceschini.fits.gz"
         models["dominguez"] = "$GAMMAPY_DATA/ebl/ebl_dominguez11.fits.gz"
         models["finke"] = "$GAMMAPY_DATA/ebl/frd_abs.fits.gz"
 
-        return cls.read(models[name])
+        return cls.read(models[name], interp_kwargs=interp_kwargs)
 
     def table_model(self, parameter):
-        """Table model for a given parameter (`~gammapy.modeling.models.TemplateSpectralModel`).
+        """Table model for a given parameter value.
 
         Parameters
         ----------
         parameter : float
             Parameter value.
+
+        Returns
+        -------
+        template_model : `TemplateSpectralModel`
+            Template spectral model.
         """
         energy = self.energy
         values = self.evaluate(energy=energy, parameter=parameter)
@@ -1141,22 +1198,13 @@ class Absorption:
 
     def evaluate(self, energy, parameter):
         """Evaluate model for energy and parameter value."""
-        return self._evaluate((parameter, energy))
+        return np.clip(self._evaluate((parameter, energy)), 0, 1)
 
 
 class AbsorbedSpectralModel(SpectralModel):
     r"""Spectral model with EBL absorption.
 
-    The spectral model is evaluated, and then multiplied with an EBL
-    absorption factor given by
-
-    .. math::
-        \exp{ \left ( -\alpha \times \tau(E, z) \right )}
-
-    where :math:`\tau(E, z)` is the optical depth predicted by the model
-    (`Absorption`), which depends on the energy
-    of the gamma-rays and the redshift z of the source, and :math:`\alpha`
-    is a scale factor (default: 1) for the optical depth.
+    For more information see :ref:`absorbed-spectral-model`.
 
     Parameters
     ----------
@@ -1243,19 +1291,7 @@ class AbsorbedSpectralModel(SpectralModel):
 class NaimaSpectralModel(SpectralModel):
     r"""A wrapper for Naima models.
 
-    This class provides an interface with the models defined in the `~naima.models` module.
-    The model accepts as a positional argument a `Naima <https://naima.readthedocs.io/en/latest/>`_
-    radiative model instance, used to compute the non-thermal emission from populations of
-    relativistic electrons or protons due to interactions with the ISM or with radiation and magnetic fields.
-
-    One of the advantages provided by this class consists in the possibility of performing a maximum
-    likelihood spectral fit of the model's parameters directly on observations, as opposed to the MCMC
-    `fit to flux points <https://naima.readthedocs.io/en/latest/mcmc.html>`_ featured in
-    Naima. All the parameters defining the parent population of charged particles are stored as
-    `~gammapy.modeling.Parameter` and left free by default. In case that the radiative model is `
-    ~naima.radiative.Synchrotron`, the magnetic field strength may also be fitted. Parameters can be
-    freezed/unfreezed before the fit, and maximum/minimum values can be set to limit the parameters space to
-    the physically interesting region.
+    For more information see :ref:`naima-spectral-model`.
 
     Parameters
     ----------
@@ -1319,12 +1355,17 @@ class NaimaSpectralModel(SpectralModel):
         unit = 1 / (energy.unit * u.cm ** 2 * u.s)
         return dnde.to(unit)
 
+    @classmethod
+    def from_dict(cls, data):
+        raise NotImplementedError(
+            "Currently the NaimaSpectralModel cannot be read from YAML"
+        )
+
 
 class GaussianSpectralModel(SpectralModel):
     r"""Gaussian spectral model.
 
-    .. math::
-        \phi(E) = \frac{N_0}{\sigma \sqrt{2\pi}}  \exp{ \frac{- \left( E-\bar{E} \right)^2 }{2 \sigma^2} }
+    For more information see :ref:`gaussian-spectral-model`.
 
     Parameters
     ----------
