@@ -5,17 +5,17 @@ from numpy.testing import assert_allclose
 import astropy.units as u
 from gammapy.cube import PSFKernel
 from gammapy.cube.fit import MapEvaluator
-from gammapy.irf import EnergyDispersion
+from gammapy.irf import EDispKernel
 from gammapy.maps import Map, MapAxis, WcsGeom
 from gammapy.modeling.models import (
     BackgroundModel,
     ConstantSpectralModel,
     GaussianSpatialModel,
+    Models,
     PointSpatialModel,
     PowerLawSpectralModel,
     SkyDiffuseCube,
     SkyModel,
-    SkyModels,
     create_fermi_isotropic_diffuse_model,
 )
 from gammapy.utils.testing import requires_data
@@ -38,7 +38,7 @@ def sky_model():
 def diffuse_model():
     axis = MapAxis.from_nodes([0.1, 100], name="energy", unit="TeV", interp="log")
     m = Map.create(
-        npix=(4, 3), binsz=2, axes=[axis], unit="cm-2 s-1 MeV-1 sr-1", coordsys="GAL"
+        npix=(4, 3), binsz=2, axes=[axis], unit="cm-2 s-1 MeV-1 sr-1", frame="galactic"
     )
     m.data += 42
     return SkyDiffuseCube(m)
@@ -47,13 +47,13 @@ def diffuse_model():
 @pytest.fixture(scope="session")
 def geom():
     axis = MapAxis.from_edges(np.logspace(-1, 1, 3), unit=u.TeV, name="energy")
-    return WcsGeom.create(skydir=(0, 0), npix=(5, 4), coordsys="GAL", axes=[axis])
+    return WcsGeom.create(skydir=(0, 0), npix=(5, 4), frame="galactic", axes=[axis])
 
 
 @pytest.fixture(scope="session")
 def geom_true():
     axis = MapAxis.from_edges(np.logspace(-1, 1, 4), unit=u.TeV, name="energy")
-    return WcsGeom.create(skydir=(0, 0), npix=(5, 4), coordsys="GAL", axes=[axis])
+    return WcsGeom.create(skydir=(0, 0), npix=(5, 4), frame="galactic", axes=[axis])
 
 
 @pytest.fixture(scope="session")
@@ -75,7 +75,7 @@ def background(geom):
 def edisp(geom, geom_true):
     e_reco = geom.get_axis_by_name("energy").edges
     e_true = geom_true.get_axis_by_name("energy").edges
-    return EnergyDispersion.from_diagonal_response(e_true=e_true, e_reco=e_reco)
+    return EDispKernel.from_diagonal_response(e_true=e_true, e_reco=e_reco)
 
 
 @pytest.fixture(scope="session")
@@ -98,14 +98,14 @@ def diffuse_evaluator(diffuse_model, exposure, psf, edisp):
 def sky_models(sky_model):
     sky_model_2 = sky_model.copy(name="source-2")
     sky_model_3 = sky_model.copy(name="source-3")
-    return SkyModels([sky_model_2, sky_model_3])
+    return Models([sky_model_2, sky_model_3])
 
 
 @pytest.fixture(scope="session")
 def sky_models_2(sky_model):
     sky_model_4 = sky_model.copy(name="source-4")
     sky_model_5 = sky_model.copy(name="source-5")
-    return SkyModels([sky_model_4, sky_model_5])
+    return Models([sky_model_4, sky_model_5])
 
 
 def test_sky_model_init():
@@ -120,12 +120,12 @@ def test_sky_model_init():
 def test_sky_model_spatial_none_io(tmpdir):
     pwl = PowerLawSpectralModel()
     model = SkyModel(spectral_model=pwl, name="test")
-    models = SkyModels([model])
+    models = Models([model])
 
     filename = tmpdir / "test-models-none.yaml"
     models.write(filename)
 
-    models = SkyModels.read(filename)
+    models = Models.read(filename)
 
     assert models["test"].spatial_model is None
 
@@ -142,27 +142,27 @@ def test_sky_model_spatial_none_evaluate(geom):
 
 def test_skymodel_addition(sky_model, sky_models, sky_models_2, diffuse_model):
     models = sky_model + sky_model.copy()
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 2
 
     models = sky_model + sky_models
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 3
 
     models = sky_models + sky_model
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 3
 
     models = sky_models + diffuse_model
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 3
 
     models = sky_models + sky_models_2
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 4
 
     models = sky_model + sky_models
-    assert isinstance(models, SkyModels)
+    assert isinstance(models, Models)
     assert len(models) == 3
 
 
@@ -214,6 +214,38 @@ class TestSkyModels:
         with pytest.raises(IndexError):
             sky_models["spam"]
 
+    @staticmethod
+    def test_names(sky_models):
+        assert sky_models.names == ["source-2", "source-3"]
+
+
+@requires_data()
+def test_SkyModels_mutation(sky_model, sky_models, sky_models_2):
+    mods = sky_models
+
+    mods.insert(0, sky_model)
+    assert mods.names == ["source-1", "source-2", "source-3"]
+
+    mods.extend(sky_models_2)
+    assert mods.names == ["source-1", "source-2", "source-3", "source-4", "source-5"]
+
+    mod3 = mods[3]
+    mods.remove(mods[3])
+    assert mods.names == ["source-1", "source-2", "source-3", "source-5"]
+    mods.append(mod3)
+    assert mods.names == ["source-1", "source-2", "source-3", "source-5", "source-4"]
+    mods.pop(3)
+    assert mods.names == ["source-1", "source-2", "source-3", "source-4"]
+
+    with pytest.raises(ValueError, match="Model names must be unique"):
+        mods.append(sky_model)
+    with pytest.raises(ValueError, match="Model names must be unique"):
+        mods.insert(0, sky_model)
+    with pytest.raises(ValueError, match="Model names must be unique"):
+        mods.extend(sky_models_2)
+    with pytest.raises(ValueError, match="Model names must be unique"):
+        mods = sky_models + sky_models_2
+
 
 class TestSkyModel:
     @staticmethod
