@@ -17,18 +17,18 @@ def _get_parameters_str(parameters):
 
     for par in parameters:
         if par.name == "amplitude":
-            line = "\t{:12} {:11}: {:.2e} {} {}\n"
+            line = "\t{:12} {:11}: {:10.2e} {} {:<12s}\n"
         else:
-            line = "\t{:12} {:11}: {:.3f} {} {}\n"
+            line = "\t{:12} {:11}: {:7.3f} {} {:<12s}\n"
 
         frozen = "(frozen)" if par.frozen else ""
         try:
-            error = "+/- {:.2f}".format(parameters.get_error(par))
+            error = "+/- {:7.2f}".format(parameters.get_error(par))
         except AttributeError:
             error = ""
 
         str_ += line.format(par.name, frozen, par.value, error, par.unit)
-    return str_
+    return str_.expandtabs(tabsize=2)
 
 
 class Parameter:
@@ -70,6 +70,7 @@ class Parameter:
         self, name, factor, unit="", scale=1, min=np.nan, max=np.nan, frozen=False
     ):
         self.name = name
+        self._link_label_io = None
         self.scale = scale
 
         # TODO: move this to a setter method that can be called from `__set__` also!
@@ -217,7 +218,7 @@ class Parameter:
 
     def to_dict(self):
         """Convert to dict."""
-        return {
+        output = {
             "name": self.name,
             "value": self.value,
             "unit": self.unit.to_string("fits"),
@@ -225,6 +226,9 @@ class Parameter:
             "max": self.max,
             "frozen": self.frozen,
         }
+        if self._link_label_io is not None:
+            output["link"] = self._link_label_io
+        return output
 
     def autoscale(self, method="scale10"):
         """Autoscale the parameters.
@@ -461,19 +465,17 @@ class Parameters(collections.abc.Sequence):
 
     def update_from_dict(self, data):
         for par in data["parameters"]:
-            # TODO: not sure if we should allow this
-            # parameter names should be fixed on init
-            # To be rediscussed
-            parameter = self[par["name"].split("@")[0]]
-            parameter.name = par["name"]
+            parameter = self[par["name"]]
             parameter.value = float(par["value"])
             parameter.unit = u.Unit(par.get("unit", parameter.unit))
             parameter.min = float(par.get("min", parameter.min))
             parameter.max = float(par.get("max", parameter.max))
             parameter.frozen = par.get("frozen", parameter.frozen)
+            parameter._link_label_io = par.get("link", parameter._link_label_io)
 
-        if "covariance" in data:
-            self.covariance = np.array(data["covariance"])
+        covariance = data.get("covariance")
+        if covariance is not None:
+            self.covariance = np.array(covariance)
 
     def error(self, parname):
         """Get parameter error.
