@@ -1,10 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import warnings
 import logging
 import sys
+import warnings
 from pathlib import Path
 import click
-from .. import version
+from gammapy import __version__
 
 
 # We implement the --version following the example from here:
@@ -12,7 +12,7 @@ from .. import version
 def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
-    print("gammapy version {}".format(version.version))
+    print(f"gammapy version {__version__}")
     ctx.exit()
 
 
@@ -65,9 +65,21 @@ def cli(log_level, ignore_warnings):  # noqa: D301
         warnings.simplefilter("ignore")
 
 
-@cli.group("image")
-def cli_image():
-    """Analysis - 2D images"""
+@cli.group("analysis")
+def cli_analysis():
+    """Automation of configuration driven data reduction process.
+
+    \b
+    Examples
+    --------
+
+    \b
+    $ gammapy analysis config
+    $ gammapy analysis run
+    $ gammapy analysis config --overwrite
+    $ gammapy analysis config --filename myconfig.yaml
+    $ gammapy analysis run --filename myconfig.yaml
+    """
 
 
 @cli.group("download", short_help="Download datasets and notebooks")
@@ -102,7 +114,7 @@ def cli_download(ctx):  # noqa: D301
     $ gammapy download notebooks
     $ gammapy download datasets
     $ gammapy download tutorials --release 0.8
-    $ gammapy download notebooks --src first_steps
+    $ gammapy download notebooks --src overview
     $ gammapy download datasets --src fermi-3fhl-gc --out localfolder/
     """
 
@@ -130,7 +142,7 @@ def cli_jupyter(ctx, src):  # noqa: D301
 
     path = Path(src)
     if not path.exists():
-        log.error("File or folder {} not found.".format(src))
+        log.error(f"File or folder {src} not found.")
         sys.exit()
 
     if path.is_dir():
@@ -150,10 +162,6 @@ def add_subcommands():
 
     cli.add_command(cli_check)
 
-    from .image_bin import cli_image_bin
-
-    cli_image.add_command(cli_image_bin)
-
     from .download import cli_download_notebooks
 
     cli_download.add_command(cli_download_notebooks)
@@ -186,5 +194,13 @@ def add_subcommands():
 
     cli_jupyter.add_command(cli_jupyter_test)
 
+    from .analysis import cli_make_config
+
+    cli_analysis.add_command(cli_make_config)
+
+    from .analysis import cli_run_analysis
+
+    cli_analysis.add_command(cli_run_analysis)
+
 
 add_subcommands()
