@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from ...utils.testing import run_cli
-from ... import version
-from ..main import cli
+from gammapy import __version__
+from gammapy.scripts.main import cli
+from gammapy.utils.testing import run_cli
 
 
 def test_cli_no_args():
@@ -17,4 +17,4 @@ def test_cli_help():
 
 def test_cli_version():
     result = run_cli(cli, ["--version"])
-    assert "gammapy version {}".format(version.version) in result.output
+    assert f"gammapy version {__version__}" in result.output
