@@ -1,19 +1,19 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import logging
 import copy
+import logging
 import numpy as np
-from astropy.table import Table
-from astropy.io import fits
 import astropy.units as u
-from ..maps import MapAxis
-from ..maps.utils import edges_from_lo_hi
-from ..utils.scripts import make_path
-from ..utils.fits import energy_axis_to_ebounds, ebounds_to_energy_axis
-from ..data import EventList
+from astropy.io import fits
+from astropy.table import Table
+from gammapy.maps import MapAxis
+from gammapy.maps.utils import edges_from_lo_hi
+from gammapy.utils.fits import ebounds_to_energy_axis, energy_axis_to_ebounds
+from gammapy.utils.regions import compound_region_to_list
+from gammapy.utils.scripts import make_path
 
 __all__ = ["CountsSpectrum"]
 
-log = logging.getLogger("__name__")
+log = logging.getLogger(__name__)
 
 
 class CountsSpectrum:
@@ -29,6 +29,8 @@ class CountsSpectrum:
         Spectrum data.
     unit : str or `~astropy.units.Unit`
         Data unit
+    region : `~regions.SkyRegion`
+        Region the spectrum is defined for.
 
     Examples
     --------
@@ -49,7 +51,7 @@ class CountsSpectrum:
         spec.plot(show_poisson_errors=True)
     """
 
-    def __init__(self, energy_lo, energy_hi, data=None, unit=""):
+    def __init__(self, energy_lo, energy_hi, data=None, unit="", region=None):
         e_edges = edges_from_lo_hi(energy_lo, energy_hi)
         self.energy = MapAxis.from_edges(e_edges, interp="log", name="energy")
 
@@ -61,6 +63,7 @@ class CountsSpectrum:
             raise ValueError("Incompatible data and energy axis size.")
 
         self.unit = u.Unit(unit)
+        self.region = region
 
     @property
     def quantity(self):
@@ -74,16 +77,17 @@ class CountsSpectrum:
     @classmethod
     def from_hdulist(cls, hdulist, hdu1="COUNTS", hdu2="EBOUNDS"):
         """Read from HDU list in OGIP format."""
-        counts_table = Table.read(hdulist[hdu1])
-        counts = counts_table["COUNTS"].data
+        table = Table.read(hdulist[hdu1])
+        counts = table["COUNTS"].data
         ebounds = ebounds_to_energy_axis(hdulist[hdu2])
+
+        # TODO: add region serilisation
         return cls(data=counts, energy_lo=ebounds[:-1], energy_hi=ebounds[1:])
 
     @classmethod
     def read(cls, filename, hdu1="COUNTS", hdu2="EBOUNDS"):
         """Read from file."""
-        filename = make_path(filename)
-        with fits.open(str(filename), memmap=False) as hdulist:
+        with fits.open(make_path(filename), memmap=False) as hdulist:
             return cls.from_hdulist(hdulist, hdu1=hdu1, hdu2=hdu2)
 
     def to_table(self):
@@ -96,6 +100,7 @@ class CountsSpectrum:
 
         names = ["CHANNEL", "COUNTS"]
         meta = {"name": "COUNTS"}
+
         return Table([channel, counts], names=names, meta=meta)
 
     def to_hdulist(self, use_sherpa=False):
@@ -119,22 +124,17 @@ class CountsSpectrum:
     def write(self, filename, use_sherpa=False, **kwargs):
         """Write to file."""
         filename = make_path(filename)
-        self.to_hdulist(use_sherpa=use_sherpa).writeto(str(filename), **kwargs)
+        self.to_hdulist(use_sherpa=use_sherpa).writeto(filename, **kwargs)
 
-    def fill(self, events):
-        """Fill with list of events.
+    def fill_events(self, events):
+        """Fill events (`gammapy.data.EventList`)."""
+        self.fill_energy(events.energy)
 
-        Parameters
-        ----------
-        events : `~astropy.units.Quantity`, `gammapy.data.EventList`,
-            List of event energies
-        """
-        if isinstance(events, EventList):
-            events = events.energy
-
-        energy = events.to(self.energy.unit)
-        binned_val = np.histogram(energy.value, self.energy.edges)[0]
-        self.data = binned_val
+    def fill_energy(self, energy):
+        """Fill energy values (`~astropy.units.Quantity`)"""
+        energy = energy.to_value(self.energy.unit)
+        edges = self.energy.edges.to_value(self.energy.unit)
+        self.data = np.histogram(energy, edges)[0]
 
     @property
     def total_counts(self):
@@ -147,7 +147,7 @@ class CountsSpectrum:
         energy_unit="TeV",
         show_poisson_errors=False,
         show_energy=None,
-        **kwargs
+        **kwargs,
     ):
         """Plot as data points.
 
@@ -182,7 +182,7 @@ class CountsSpectrum:
         if show_energy is not None:
             ener_val = u.Quantity(show_energy).to_value(energy_unit)
             ax.vlines(ener_val, 0, 1.1 * max(self.data), linestyles="dashed")
-        ax.set_xlabel("Energy [{}]".format(energy_unit))
+        ax.set_xlabel(f"Energy [{energy_unit}]")
         ax.set_ylabel("Counts")
         ax.set_xscale("log")
         return ax
@@ -213,11 +213,32 @@ class CountsSpectrum:
         if show_energy is not None:
             ener_val = u.Quantity(show_energy).to_value(energy_unit)
             ax.vlines(ener_val, 0, 1.1 * max(self.data), linestyles="dashed")
-        ax.set_xlabel("Energy [{}]".format(energy_unit))
+        ax.set_xlabel(f"Energy [{energy_unit}]")
         ax.set_ylabel("Counts")
         ax.set_xscale("log")
         return ax
 
+    def plot_region(self, ax=None, **kwargs):
+        """Plot region
+
+        Parameters
+        ----------
+        ax : `~astropy.vizualisation.WCSAxes`
+            Axes to plot on.
+        **kwargs : dict
+            Keyword arguments forwarded to `~regions.PixelRegion.as_artist`
+        """
+        import matplotlib.pyplot as plt
+        from matplotlib.collections import PatchCollection
+
+        ax = plt.gca() or ax
+        regions = compound_region_to_list(self.region)
+        artists = [region.to_pixel(wcs=ax.wcs).as_artist() for region in regions]
+
+        patches = PatchCollection(artists, **kwargs)
+        ax.add_collection(patches)
+        return ax
+
     def peek(self, figsize=(5, 10)):
         """Quick-look summary plots."""
         import matplotlib.pyplot as plt
@@ -243,7 +264,7 @@ class CountsSpectrum:
         spectrum : `~gammapy.spectrum.CountsSpectrum`
             Downsampled spectrum.
         """
-        from ..extern.skimage import block_reduce
+        from gammapy.extern.skimage import block_reduce
 
         data = block_reduce(self.data, block_size=(factor,))
         energy = self.energy.downsample(factor).edges
@@ -302,3 +323,89 @@ class CountsSpectrum:
 
     def __array__(self):
         return self.data
+
+
+class SpectrumEvaluator:
+    """Calculate number of predicted counts (``npred``).
+
+    The true and reconstructed energy binning are inferred from the provided IRFs.
+
+    Parameters
+    ----------
+    model : `~gammapy.modeling.models.SkyModel`
+        Spectral model
+    aeff : `~gammapy.irf.EffectiveAreaTable`
+        EffectiveArea
+    edisp : `~gammapy.irf.EDispKernel`, optional
+        Energy dispersion kernel.
+    livetime : `~astropy.units.Quantity`
+        Observation duration (may be contained in aeff)
+    e_true : `~astropy.units.Quantity`, optional
+        Desired energy axis of the prediced counts vector if no IRFs are given
+
+    Examples
+    --------
+    Calculate predicted counts in a desired reconstruced energy binning
+
+    .. plot::
+        :include-source:
+
+        import numpy as np
+        import astropy.units as u
+        import matplotlib.pyplot as plt
+        from gammapy.irf import EffectiveAreaTable, EDispKernel
+        from gammapy.modeling.models import PowerLawSpectralModel, SkyModel
+        from gammapy.spectrum import SpectrumEvaluator
+
+        e_true = np.logspace(-2, 2.5, 109) * u.TeV
+        e_reco = np.logspace(-2, 2, 73) * u.TeV
+
+        aeff = EffectiveAreaTable.from_parametrization(energy=e_true)
+        edisp = EDispKernel.from_gauss(e_true=e_true, e_reco=e_reco, sigma=0.3, bias=0)
+
+        pwl = PowerLawSpectralModel(index=2.3, amplitude="2.5e-12 cm-2 s-1 TeV-1", reference="1 TeV")
+        model = SkyModel(spectral_model=pwl)
+
+        predictor = SpectrumEvaluator(model=model, aeff=aeff, edisp=edisp, livetime="1 hour")
+        predictor.compute_npred().plot_hist()
+        plt.show()
+    """
+
+    def __init__(self, model, aeff=None, edisp=None, livetime=None):
+        self.model = model
+        self.aeff = aeff
+        self.edisp = edisp
+        self.livetime = livetime
+
+    def compute_npred(self):
+        e_true = self.aeff.energy.edges
+        integral_flux = self.model.spectral_model.integral(
+            emin=e_true[:-1], emax=e_true[1:], intervals=True
+        )
+
+        true_counts = self.apply_aeff(integral_flux)
+        return self.apply_edisp(true_counts)
+
+    def apply_aeff(self, integral_flux):
+        if self.aeff is not None:
+            cts = integral_flux * self.aeff.data.data
+        else:
+            cts = integral_flux
+
+        # Multiply with livetime if not already contained in aeff or model
+        if cts.unit.is_equivalent("s-1"):
+            cts *= self.livetime
+
+        return cts.to("")
+
+    def apply_edisp(self, true_counts):
+        from . import CountsSpectrum
+
+        if self.edisp is not None:
+            cts = self.edisp.apply(true_counts)
+            e_reco = self.edisp.e_reco.edges
+        else:
+            cts = true_counts
+            e_reco = self.aeff.energy.edges
+
+        return CountsSpectrum(data=cts, energy_lo=e_reco[:-1], energy_hi=e_reco[1:])
