@@ -5,13 +5,13 @@ from astropy import units as u
 from astropy.io import fits
 from astropy.table import Table
 from gammapy.data import GTI
-from gammapy.irf import EffectiveAreaTable, EnergyDispersion, IRFStacker
+from gammapy.irf import EDispKernel, EffectiveAreaTable, IRFStacker
 from gammapy.modeling import Dataset, Parameters
-from gammapy.modeling.models import SkyModel, SkyModels
-from gammapy.stats import cash, significance_on_off, wstat
+from gammapy.modeling.models import Models
+from gammapy.stats import cash, significance, significance_on_off, wstat
 from gammapy.utils.fits import energy_axis_to_ebounds
 from gammapy.utils.random import get_random_state
-from gammapy.utils.scripts import make_path
+from gammapy.utils.scripts import make_name, make_path
 from .core import CountsSpectrum, SpectrumEvaluator
 
 __all__ = [
@@ -30,7 +30,7 @@ class SpectrumDataset(Dataset):
 
     Parameters
     ----------
-    models : `~gammapy.modeling.models.SkyModels`
+    models : `~gammapy.modeling.models.Models`
         Fit model
     counts : `~gammapy.spectrum.CountsSpectrum`
         Counts spectrum
@@ -38,7 +38,7 @@ class SpectrumDataset(Dataset):
         Livetime
     aeff : `~gammapy.irf.EffectiveAreaTable`
         Effective area
-    edisp : `~gammapy.irf.EnergyDispersion`
+    edisp : `~gammapy.irf.EDispKernel`
         Energy dispersion
     background : `~gammapy.spectrum.CountsSpectrum`
         Background to use for the fit.
@@ -56,7 +56,7 @@ class SpectrumDataset(Dataset):
     SpectrumDatasetOnOff, FluxPointsDataset, gammapy.cube.MapDataset
     """
 
-    likelihood_type = "cash"
+    stat_type = "cash"
     tag = "SpectrumDataset"
 
     def __init__(
@@ -69,7 +69,7 @@ class SpectrumDataset(Dataset):
         background=None,
         mask_safe=None,
         mask_fit=None,
-        name="",
+        name=None,
         gti=None,
     ):
 
@@ -88,12 +88,18 @@ class SpectrumDataset(Dataset):
         self.background = background
         self.models = models
         self.mask_safe = mask_safe
-        self.name = name
         self.gti = gti
 
+        self._name = make_name(name)
+
+    @property
+    def name(self):
+        return self._name
+
     def __str__(self):
-        str_ = self.__class__.__name__
-        str_ += "\n\n"
+        str_ = self.__class__.__name__ + "\n"
+        str_ += "-" * len(self.__class__.__name__) + "\n"
+        str_ += "\n"
 
         str_ += "\t{:32}: {} \n\n".format("Name", self.name)
 
@@ -145,7 +151,7 @@ class SpectrumDataset(Dataset):
         str_ += "\t{:32}: {} \n\n".format("Number of fit bins", n_fit_bins)
 
         # likelihood section
-        str_ += "\t{:32}: {}\n".format("Fit statistic type", self.likelihood_type)
+        str_ += "\t{:32}: {}\n".format("Fit statistic type", self.stat_type)
 
         stat = np.nan
         if self.models is not None and self.counts is not None:
@@ -161,45 +167,32 @@ class SpectrumDataset(Dataset):
         str_ += "\t{:32}: {}\n\n".format("Number of free parameters", n_free_pars)
 
         if self.models is not None:
-            str_ += "\t{:32}: {}\n".format("Model type", self.models.__class__.__name__)
-            info = str(self.models.parameters)
-            lines = info.split("\n")
-            for line in lines[2:-1]:
-                str_ += "\t" + line.replace(":", "\t:") + "\n"
+            str_ += "\t" + "\n\t".join(str(self.models).split("\n")[2:])
 
-        return str_.expandtabs(tabsize=4)
+        return str_.expandtabs(tabsize=2)
 
     @property
     def models(self):
-        """Models (`gammapy.modeling.models.SkyModels`)."""
+        """Models (`gammapy.modeling.models.Models`)."""
         return self._models
 
     @models.setter
     def models(self, value):
-        if value is None or isinstance(value, SkyModels):
-            models = value
-        elif isinstance(value, list):
-            models = SkyModels(value)
-        elif isinstance(value, SkyModel):
-            models = SkyModels([value])
+        if value is not None:
+            self._models = Models(value)
         else:
-            raise TypeError(f"Invalid: {value!r}")
-
-        self._models = models
-
-        self._make_evaluators()
-
-    def _make_evaluators(self):
-        if self.models is None:
-            self._evaluators = []
-            return
+            self._models = None
 
         evaluators = []
-        for model in self.models:
-            evaluator = SpectrumEvaluator(
-                model=model, livetime=self.livetime, aeff=self.aeff, edisp=self.edisp
-            )
-            evaluators.append(evaluator)
+        if self.models is not None:
+            for model in self.models:
+                evaluator = SpectrumEvaluator(
+                    model=model,
+                    livetime=self.livetime,
+                    aeff=self.aeff,
+                    edisp=self.edisp,
+                )
+                evaluators.append(evaluator)
 
         self._evaluators = evaluators
 
@@ -240,14 +233,20 @@ class SpectrumDataset(Dataset):
         """Shape of the counts data"""
         return (self._energy_axis.nbin,)
 
-    def npred(self):
-        """Return npred map (model + background)"""
+    def npred_sig(self):
+        """Predicted counts from source model (`CountsSpectrum`)."""
         data = np.zeros(self.data_shape)
         npred = self._as_counts_spectrum(data)
 
         for evaluator in self._evaluators:
             npred += evaluator.compute_npred()
 
+        return npred
+
+    def npred(self):
+        """Return npred map (model + background)"""
+        npred = self.npred_sig()
+
         if self.background:
             npred += self.background
 
@@ -267,7 +266,7 @@ class SpectrumDataset(Dataset):
         excess = self.counts.data - self.background.data
         return self._as_counts_spectrum(excess)
 
-    def fake(self, random_state="random-seed"):
+    def fake(self, random_state="random-seed", name=None):
         """Simulate fake counts for the current model and reduced irfs.
 
         This method overwrites the counts defined on the dataset object.
@@ -278,6 +277,7 @@ class SpectrumDataset(Dataset):
             Defines random number generator initialisation.
             Passed to `~gammapy.utils.random.get_random_state`.
         """
+        self._name = make_name(name)
         random_state = get_random_state(random_state)
         npred = self.npred()
         npred.data = random_state.poisson(npred.data)
@@ -338,7 +338,7 @@ class SpectrumDataset(Dataset):
 
         ax = plt.gca() if ax is None else ax
 
-        self.npred().plot(ax=ax, label="mu_src", energy_unit=self._e_unit)
+        self.npred_sig().plot(ax=ax, label="mu_src", energy_unit=self._e_unit)
         self.excess.plot(ax=ax, label="Excess", fmt=".", energy_unit=self._e_unit)
 
         e_min, e_max = self.energy_range
@@ -406,7 +406,9 @@ class SpectrumDataset(Dataset):
         return ax
 
     @classmethod
-    def create(cls, e_reco, e_true=None, region=None, reference_time="2000-01-01"):
+    def create(
+        cls, e_reco, e_true=None, region=None, reference_time="2000-01-01", name=None
+    ):
         """Creates empty spectrum dataset.
 
         Empty containers are created with the correct geometry.
@@ -433,7 +435,7 @@ class SpectrumDataset(Dataset):
         aeff = EffectiveAreaTable(
             e_true[:-1], e_true[1:], np.zeros(e_true[:-1].shape) * u.m ** 2
         )
-        edisp = EnergyDispersion.from_diagonal_response(e_true, e_reco)
+        edisp = EDispKernel.from_diagonal_response(e_true, e_reco)
         mask_safe = np.zeros_like(counts.data, "bool")
         gti = GTI.create(u.Quantity([], "s"), u.Quantity([], "s"), reference_time)
         livetime = gti.time_sum
@@ -446,6 +448,7 @@ class SpectrumDataset(Dataset):
             background=background,
             livetime=livetime,
             gti=gti,
+            name=name,
         )
 
     def stack(self, other):
@@ -527,6 +530,82 @@ class SpectrumDataset(Dataset):
         if self.livetime is not None:
             self.livetime += other.livetime
 
+    def peek(self, figsize=(16, 4)):
+        """Quick-look summary plots."""
+        import matplotlib.pyplot as plt
+
+        e_min, e_max = self.energy_range
+
+        _, (ax1, ax2, ax3) = plt.subplots(nrows=1, ncols=3, figsize=figsize)
+
+        ax1.set_title("Counts")
+        energy_unit = "TeV"
+
+        if isinstance(self, SpectrumDatasetOnOff) and self.counts_off is not None:
+            self.background.plot_hist(
+                ax=ax1, label="alpha * N_off", color="darkblue", energy_unit=energy_unit
+            )
+        elif self.background is not None:
+            self.background.plot_hist(
+                ax=ax1, label="background", color="darkblue", energy_unit=energy_unit
+            )
+
+        self.counts.plot_hist(
+            ax=ax1,
+            label="n_on",
+            color="darkred",
+            energy_unit=energy_unit,
+            show_energy=(e_min, e_max),
+        )
+
+        ax1.set_xlim(
+            0.7 * e_min.to_value(energy_unit), 1.3 * e_max.to_value(energy_unit)
+        )
+        ax1.legend(numpoints=1)
+
+        ax2.set_title("Effective Area")
+        e_unit = self.aeff.energy.unit
+        self.aeff.plot(ax=ax2, show_energy=(e_min, e_max))
+        ax2.set_xlim(0.7 * e_min.to_value(e_unit), 1.3 * e_max.to_value(e_unit))
+
+        ax3.set_title("Energy Dispersion")
+        if self.edisp is not None:
+            self.edisp.plot_matrix(ax=ax3)
+
+        # TODO: optimize layout
+        plt.subplots_adjust(wspace=0.3)
+
+    def info_dict(self, in_safe_energy_range=True):
+        """Info dict with summary statistics, summed over energy
+
+        Parameters
+        ----------
+        in_safe_energy_range : bool
+            Whether to sum only in the safe energy range
+
+        Returns
+        -------
+        info_dict : dict
+            Dictionary with summary info.
+        """
+        info = dict()
+        mask = self.mask_safe if in_safe_energy_range else slice(None)
+
+        info["name"] = self.name
+        info["livetime"] = self.livetime.copy()
+
+        info["n_on"] = self.counts.data[mask].sum()
+
+        info["background"] = self.background.data[mask].sum()
+        info["excess"] = self.excess.data[mask].sum()
+        info["significance"] = significance(
+            self.counts.data[mask].sum(), self.background.data[mask].sum(),
+        )
+
+        info["background_rate"] = info["background"] / info["livetime"]
+        info["gamma_rate"] = info["excess"] / info["livetime"]
+        return info
+
 
 class SpectrumDatasetOnOff(SpectrumDataset):
     """Spectrum dataset for on-off likelihood fitting.
@@ -538,7 +617,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
 
     Parameters
     ----------
-    models : `~gammapy.modeling.models.SkyModels`
+    models : `~gammapy.modeling.models.Models`
         Fit model
     counts : `~gammapy.spectrum.CountsSpectrum`
         ON Counts spectrum
@@ -548,7 +627,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         Livetime
     aeff : `~gammapy.irf.EffectiveAreaTable`
         Effective area
-    edisp : `~gammapy.irf.EnergyDispersion`
+    edisp : `~gammapy.irf.EDispKernel`
         Energy dispersion
     mask_safe : `~numpy.array`
         Mask defining the safe data range.
@@ -568,7 +647,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
     SpectrumDataset, FluxPointsDataset, MapDataset
     """
 
-    likelihood_type = "wstat"
+    stat_type = "wstat"
     tag = "SpectrumDatasetOnOff"
 
     def __init__(
@@ -583,7 +662,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         mask_fit=None,
         acceptance=None,
         acceptance_off=None,
-        name="",
+        name=None,
         gti=None,
     ):
 
@@ -608,18 +687,22 @@ class SpectrumDatasetOnOff(SpectrumDataset):
 
         self.acceptance = acceptance
         self.acceptance_off = acceptance_off
-        self.name = name
+        self._name = make_name(name)
         self.gti = gti
 
     def __str__(self):
         str_ = super().__str__()
 
+        str_list = str_.split("\n")
+
         acceptance = np.nan
         if self.acceptance is not None:
             acceptance = np.mean(self.acceptance)
 
-        str_ += "\t{:32}: {}\n".format("Acceptance mean:", acceptance)
-        return str_.expandtabs(tabsize=4)
+        str_acc = "\t{:32}: {}\n".format("Acceptance mean:", acceptance)
+        str_list.insert(16, str_acc)
+        str_ = "\n".join(str_list)
+        return str_.expandtabs(tabsize=2)
 
     @property
     def background(self):
@@ -632,16 +715,6 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         """Exposure ratio between signal and background regions"""
         return self.acceptance / self.acceptance_off
 
-    def npred_sig(self):
-        """Predicted counts from source model (`CountsSpectrum`)."""
-        data = np.zeros(self.data_shape)
-        npred = self._as_counts_spectrum(data)
-
-        for evaluator in self._evaluators:
-            npred += evaluator.compute_npred()
-
-        return npred
-
     def stat_array(self):
         """Likelihood per bin given the current model parameters"""
         mu_sig = self.npred_sig().data
@@ -653,7 +726,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         )
         return np.nan_to_num(on_stat_)
 
-    def fake(self, background_model, random_state="random-seed"):
+    def fake(self, background_model, random_state="random-seed", name=None):
         """Simulate fake counts for the current model and reduced irfs.
 
         This method overwrites the counts and off counts defined on the dataset object.
@@ -667,6 +740,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
             Defines random number generator initialisation.
             Passed to `~gammapy.utils.random.get_random_state`.
         """
+        self._name = make_name(name)
         random_state = get_random_state(random_state)
 
         npred_sig = self.npred_sig()
@@ -682,7 +756,9 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         self.counts_off = npred_off
 
     @classmethod
-    def create(cls, e_reco, e_true=None, region=None, reference_time="2000-01-01"):
+    def create(
+        cls, e_reco, e_true=None, region=None, reference_time="2000-01-01", name=None
+    ):
         """Create empty SpectrumDatasetOnOff.
 
         Empty containers are created with the correct geometry.
@@ -709,7 +785,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         aeff = EffectiveAreaTable(
             e_true[:-1], e_true[1:], np.zeros(e_true[:-1].shape) * u.m ** 2
         )
-        edisp = EnergyDispersion.from_diagonal_response(e_true, e_reco)
+        edisp = EDispKernel.from_diagonal_response(e_true, e_reco)
         mask_safe = np.zeros_like(counts.data, "bool")
         gti = GTI.create(u.Quantity([], "s"), u.Quantity([], "s"), reference_time)
         livetime = gti.time_sum
@@ -726,6 +802,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
             acceptance_off=acceptance_off,
             livetime=livetime,
             gti=gti,
+            name=name,
         )
 
     @classmethod
@@ -856,47 +933,6 @@ class SpectrumDatasetOnOff(SpectrumDataset):
 
         super().stack(other)
 
-    def peek(self, figsize=(16, 4)):
-        """Quick-look summary plots."""
-        import matplotlib.pyplot as plt
-
-        e_min, e_max = self.energy_range
-
-        _, (ax1, ax2, ax3) = plt.subplots(nrows=1, ncols=3, figsize=figsize)
-
-        ax1.set_title("Counts")
-        energy_unit = "TeV"
-
-        if self.counts_off is not None:
-            self.background.plot_hist(
-                ax=ax1, label="alpha * n_off", color="darkblue", energy_unit=energy_unit
-            )
-
-        self.counts.plot_hist(
-            ax=ax1,
-            label="n_on",
-            color="darkred",
-            energy_unit=energy_unit,
-            show_energy=(e_min, e_max),
-        )
-
-        ax1.set_xlim(
-            0.7 * e_min.to_value(energy_unit), 1.3 * e_max.to_value(energy_unit)
-        )
-        ax1.legend(numpoints=1)
-
-        ax2.set_title("Effective Area")
-        e_unit = self.aeff.energy.unit
-        self.aeff.plot(ax=ax2, show_energy=(e_min, e_max))
-        ax2.set_xlim(0.7 * e_min.to_value(e_unit), 1.3 * e_max.to_value(e_unit))
-
-        ax3.set_title("Energy Dispersion")
-        if self.edisp is not None:
-            self.edisp.plot_matrix(ax=ax3)
-
-        # TODO: optimize layout
-        plt.subplots_adjust(wspace=0.3)
-
     def to_ogip_files(self, outdir=None, use_sherpa=False, overwrite=False):
         """Write OGIP files.
 
@@ -1037,7 +1073,7 @@ class SpectrumDatasetOnOff(SpectrumDataset):
 
         try:
             rmffile = phafile.replace("pha", "rmf")
-            energy_dispersion = EnergyDispersion.read(dirname / rmffile)
+            energy_dispersion = EDispKernel.read(dirname / rmffile)
         except OSError:
             # TODO : Add logger and echo warning
             energy_dispersion = None
@@ -1088,15 +1124,11 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         info_dict : dict
             Dictionary with summary info.
         """
-        info = dict()
+        info = super().info_dict(in_safe_energy_range)
         mask = self.mask_safe if in_safe_energy_range else slice(None)
 
-        info["name"] = self.name
-        info["livetime"] = self.livetime.copy()
-
         # TODO: handle energy dependent a_on / a_off
         info["a_on"] = self.acceptance[0].copy()
-        info["n_on"] = self.counts.data[mask].sum()
 
         if self.counts_off is not None:
             info["n_off"] = self.counts_off.data[mask].sum()
@@ -1106,16 +1138,12 @@ class SpectrumDatasetOnOff(SpectrumDataset):
             info["a_off"] = 1
 
         info["alpha"] = self.alpha[0].copy()
-        info["background"] = self.background.data[mask].sum()
-        info["excess"] = self.excess.data[mask].sum()
         info["significance"] = significance_on_off(
             self.counts.data[mask].sum(),
             self.counts_off.data[mask].sum(),
             self.alpha[0],
         )
 
-        info["background_rate"] = info["background"] / info["livetime"]
-        info["gamma_rate"] = info["excess"] / info["livetime"]
         return info
 
     def to_dict(self, filename, *args, **kwargs):
@@ -1132,7 +1160,6 @@ class SpectrumDatasetOnOff(SpectrumDataset):
             "name": self.name,
             "type": self.tag,
             "models": models,
-            "likelihood": self.likelihood_type,
             "filename": filename,
         }
 
@@ -1181,6 +1208,49 @@ class SpectrumDatasetOnOff(SpectrumDataset):
         dataset.models = models
         return dataset
 
+    @classmethod
+    def from_spectrum_dataset(
+        cls, dataset, acceptance, acceptance_off, counts_off=None
+    ):
+        """Create spectrum dataseton off from another dataset.
+
+        Parameters
+        ----------
+        dataset : `SpectrumDataset`
+            Spectrum dataset defining counts, edisp, aeff, livetime etc.
+        acceptance : `~numpy.array` or float
+            Relative background efficiency in the on region.
+        acceptance_off : `~numpy.array` or float
+            Relative background efficiency in the off region.
+        counts_off : `~gammapy.spectrum.CountsSpectrum`
+            Off counts spectrum . If the dataset provides a background model,
+            and no off counts are defined. The off counts are deferred from
+            counts_off / alpha.
+
+        Returns
+        -------
+        dataset : `SpectrumDatasetOnOff`
+            Spectrum dataset on off.
+
+        """
+        if counts_off is None and dataset.background is not None:
+            alpha = acceptance / acceptance_off
+            counts_off = dataset.background / alpha
+
+        return cls(
+            counts=dataset.counts,
+            aeff=dataset.aeff,
+            counts_off=counts_off,
+            edisp=dataset.edisp,
+            livetime=dataset.livetime,
+            mask_safe=dataset.mask_safe,
+            mask_fit=dataset.mask_fit,
+            acceptance=acceptance,
+            acceptance_off=acceptance_off,
+            gti=dataset.gti,
+            name=dataset.name,
+        )
+
 
 def _read_ogip_hdulist(hdulist, hdu1="SPECTRUM", hdu2="EBOUNDS", hdu3="GTI"):
     """Create from `~astropy.io.fits.HDUList`."""
