@@ -5,14 +5,9 @@ from astropy import units as u
 from astropy.io.registry import IORegistryError
 from astropy.table import Table, vstack
 from gammapy.modeling import Dataset, Datasets, Fit, Parameters
-from gammapy.modeling.models import (
-    PowerLawSpectralModel,
-    ScaleSpectralModel,
-    SkyModel,
-    SkyModels,
-)
+from gammapy.modeling.models import Models, PowerLawSpectralModel, ScaleSpectralModel
 from gammapy.utils.interpolation import interpolate_profile
-from gammapy.utils.scripts import make_path
+from gammapy.utils.scripts import make_name, make_path
 from gammapy.utils.table import table_from_row_data, table_standardise_units_copy
 from .dataset import SpectrumDatasetOnOff
 
@@ -80,7 +75,7 @@ class FluxPoints:
     flux points given in one of the formats documented above::
 
         from gammapy.spectrum import FluxPoints
-        filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/flux_points.fits'
+        filename = '$GAMMAPY_DATA/hawc_crab/HAWC19_flux_points.fits'
         flux_points = FluxPoints.read(filename)
         flux_points.plot()
 
@@ -130,6 +125,9 @@ class FluxPoints:
         flux_points = FluxPoints(table)
         flux_points.plot()
 
+    Note: In order to reproduce the example you need the tests datasets folder.
+    You may download it with the command
+    ``gammapy download datasets --tests --out $GAMMAPY_DATA``
     """
 
     def __init__(self, table):
@@ -262,6 +260,10 @@ class FluxPoints:
         FluxPoints(sed_type="flux", n_points=24)
         >>> print(flux_points.drop_ul())
         FluxPoints(sed_type="flux", n_points=19)
+
+        Note: In order to reproduce the example you need the tests datasets folder.
+        You may download it with the command
+        ``gammapy download datasets --tests --out $GAMMAPY_DATA``
         """
         table_drop_ul = self.table[~self.is_ul]
         return self.__class__(table_drop_ul)
@@ -357,6 +359,10 @@ class FluxPoints:
         >>> flux_points = FluxPoints.read(filename)
         >>> model = PowerLawSpectralModel(index=2.2)
         >>> flux_points_dnde = flux_points.to_sed_type('dnde', model=model)
+
+        Note: In order to reproduce the example you need the tests datasets folder.
+        You may download it with the command
+        ``gammapy download datasets --tests --out $GAMMAPY_DATA``
         """
         # TODO: implement other directions.
         table = self.table.copy()
@@ -1149,7 +1155,7 @@ class FluxPointsDataset(Dataset):
 
     Parameters
     ----------
-    models : `~gammapy.modeling.models.SkyModels`
+    models : `~gammapy.modeling.models.Models`
         Models (only spectral part needs to be set)
     data : `~gammapy.spectrum.FluxPoints`
         Flux points.
@@ -1176,16 +1182,22 @@ class FluxPointsDataset(Dataset):
         result = fit.run()
         print(result)
         print(result.parameters.to_table())
+
+    Note: In order to reproduce the example you need the tests datasets folder.
+    You may download it with the command
+    ``gammapy download datasets --tests --out $GAMMAPY_DATA``
     """
 
-    likelihood_type = "chi2"
+    stat_type = "chi2"
     tag = "FluxPointsDataset"
 
-    def __init__(self, models, data, mask_fit=None, mask_safe=None, name=""):
+    def __init__(self, models, data, mask_fit=None, mask_safe=None, name=None):
         self.data = data
         self.mask_fit = mask_fit
-        self.name = name
         self.models = models
+
+        self._name = make_name(name)
+
         if data.sed_type != "dnde":
             raise ValueError("Currently only flux points of type 'dnde' are supported.")
 
@@ -1194,22 +1206,20 @@ class FluxPointsDataset(Dataset):
 
         self.mask_safe = mask_safe
 
+    @property
+    def name(self):
+        return self._name
+
     @property
     def models(self):
         return self._models
 
     @models.setter
     def models(self, value):
-        if isinstance(value, SkyModels):
-            models = value
-        elif isinstance(value, list):
-            models = SkyModels(value)
-        elif isinstance(value, SkyModel):
-            models = SkyModels([value])
+        if value is not None:
+            self._models = Models(value)
         else:
-            raise TypeError(f"Invalid: {value!r}")
-
-        self._models = models
+            self._models = None
 
     @property
     def parameters(self):
@@ -1291,53 +1301,47 @@ class FluxPointsDataset(Dataset):
         }
 
     def __str__(self):
-        str_ = f"{self.__class__.__name__}: \n"
+        str_ = f"{self.__class__.__name__}\n"
+        str_ += "-" * len(self.__class__.__name__) + "\n"
         str_ += "\n"
-        if self.models is None:
-            str_ += "\t{:32}:   {} \n".format("Model Name", "No Model")
-        else:
-            str_ += "\t{:32}:   {} \n".format("Total flux points", len(self.data.table))
-            str_ += "\t{:32}:   {} \n".format(
-                "Points used for the fit", self.mask.sum()
-            )
-            str_ += "\t{:32}:   {} \n".format(
-                "Excluded for safe energy range", (~self.mask_safe).sum()
-            )
-            if self.mask_fit is None:
-                str_ += "\t{:32}:   {} \n".format("Excluded by user", "0")
-            else:
-                str_ += "\t{:32}:   {} \n".format(
-                    "Excluded by user", (~self.mask_fit).sum()
-                )
-            str_ += "\t{:32}:   {}\n".format(
-                "Model Name", self.models.__class__.__name__
-            )
-            str_ += "\t{:32}:   {}\n".format("N parameters", len(self.parameters))
-            str_ += "\t{:32}:   {}\n".format(
-                "N free parameters", len(self.parameters.free_parameters)
-            )
-            str_ += "\tList of parameters\n"
-            for par in self.parameters:
-                if par.frozen:
-                    if par.name == "amplitude":
-                        str_ += "\t \t {:14} (Frozen):   {:.2e} {} \n".format(
-                            par.name, par.value, par.unit
-                        )
-                    else:
-                        str_ += "\t \t {:14} (Frozen):   {:.2f} {} \n".format(
-                            par.name, par.value, par.unit
-                        )
-                else:
-                    if par.name == "amplitude":
-                        str_ += "\t \t {:23}:   {:.2e} {} \n".format(
-                            par.name, par.value, par.unit
-                        )
-                    else:
-                        str_ += "\t \t {:23}:   {:.2f} {} \n".format(
-                            par.name, par.value, par.unit
-                        )
-            str_ += "\t{:32}:   {:.2f}\n".format("Likelihood value", self.stat_sum())
-        return str_
+
+        str_ += "\t{:32}: {} \n\n".format("Name", self.name)
+
+        # data section
+        n_bins = 0
+        if self.data is not None:
+            n_bins = len(self.data.table)
+        str_ += "\t{:32}: {} \n".format("Number of total flux points", n_bins)
+
+        n_fit_bins = 0
+        if self.mask is not None:
+            n_fit_bins = np.sum(self.mask.data)
+        str_ += "\t{:32}: {} \n\n".format("Number of fit bins", n_fit_bins)
+
+        # likelihood section
+        str_ += "\t{:32}: {}\n".format("Fit statistic type", self.stat_type)
+
+        stat = np.nan
+        if self.data is not None and self.models is not None:
+            stat = self.stat_sum()
+        str_ += "\t{:32}: {:.2f}\n\n".format("Fit statistic value (-2 log(L))", stat)
+
+        # model section
+        n_models = 0
+        if self.models is not None:
+            n_models = len(self.models)
+
+        str_ += "\t{:32}: {} \n".format("Number of models", n_models)
+
+        str_ += "\t{:32}: {}\n".format("Number of parameters", len(self.parameters))
+        str_ += "\t{:32}: {}\n\n".format(
+            "Number of free parameters", len(self.parameters.free_parameters)
+        )
+
+        if self.models is not None:
+            str_ += "\t" + "\n\t".join(str(self.models).split("\n")[2:])
+
+        return str_.expandtabs(tabsize=2)
 
     def data_shape(self):
         """Shape of the flux points data (tuple)."""
