@@ -6,15 +6,15 @@ import astropy.units as u
 from astropy.table import Table
 from astropy.time import Time
 from gammapy.data import GTI
-from gammapy.irf import EffectiveAreaTable, EnergyDispersion
+from gammapy.irf import EDispKernel, EffectiveAreaTable
 from gammapy.maps import MapAxis
 from gammapy.modeling import Datasets, Fit
 from gammapy.modeling.models import (
     ConstantSpectralModel,
     ExpCutoffPowerLawSpectralModel,
+    Models,
     PowerLawSpectralModel,
     SkyModel,
-    SkyModels,
 )
 from gammapy.spectrum import CountsSpectrum, SpectrumDataset, SpectrumDatasetOnOff
 from gammapy.utils.random import get_random_state
@@ -68,6 +68,7 @@ class TestSpectrumDataset:
             aeff=aeff,
             livetime=self.livetime,
             background=self.bkg,
+            name="test",
         )
 
     def test_data_shape(self):
@@ -119,7 +120,7 @@ class TestSpectrumDataset:
 
     def test_set_model(self):
         aeff = EffectiveAreaTable.from_parametrization(self.src.energy.edges, "HESS")
-        edisp = EnergyDispersion.from_diagonal_response(
+        edisp = EDispKernel.from_diagonal_response(
             self.src.energy.edges, self.src.energy.edges
         )
         dataset = SpectrumDataset(
@@ -131,7 +132,7 @@ class TestSpectrumDataset:
         dataset.models = model
         assert dataset.models["test"] is model
 
-        models = SkyModels([model])
+        models = Models([model])
         dataset.models = models
         assert dataset.models["test"] is model
 
@@ -146,7 +147,7 @@ class TestSpectrumDataset:
         model_1 = SkyModel(spectral_model=pwl_1)
         model_2 = SkyModel(spectral_model=pwl_2)
 
-        dataset.models = SkyModels([model_1, model_2])
+        dataset.models = Models([model_1, model_2])
 
         npred = dataset.npred()
 
@@ -158,8 +159,9 @@ class TestSpectrumDataset:
     def test_spectrumdataset_create(self):
         e_reco = u.Quantity([0.1, 1, 10.0], "TeV")
         e_true = u.Quantity([0.05, 0.5, 5, 20.0], "TeV")
-        empty_dataset = SpectrumDataset.create(e_reco, e_true)
+        empty_dataset = SpectrumDataset.create(e_reco, e_true, name="test")
 
+        assert empty_dataset.name == "test"
         assert empty_dataset.counts.total_counts == 0
         assert empty_dataset.data_shape[0] == 2
         assert empty_dataset.background.total_counts == 0
@@ -173,7 +175,7 @@ class TestSpectrumDataset:
 
     def test_spectrum_dataset_stack_diagonal_safe_mask(self):
         aeff = EffectiveAreaTable.from_parametrization(self.src.energy.edges, "HESS")
-        edisp = EnergyDispersion.from_diagonal_response(
+        edisp = EDispKernel.from_diagonal_response(
             self.src.energy.edges, self.src.energy.edges
         )
         livetime = self.livetime
@@ -220,7 +222,7 @@ class TestSpectrumDataset:
 
     def test_spectrum_dataset_stack_nondiagonal_no_bkg(self):
         aeff = EffectiveAreaTable.from_parametrization(self.src.energy.edges, "HESS")
-        edisp1 = EnergyDispersion.from_gauss(
+        edisp1 = EDispKernel.from_gauss(
             self.src.energy.edges, self.src.energy.edges, 0.1, 0.0
         )
         livetime = self.livetime
@@ -232,7 +234,7 @@ class TestSpectrumDataset:
         aeff2 = EffectiveAreaTable(
             self.src.energy.edges[:-1], self.src.energy.edges[1:], aeff.data.data
         )
-        edisp2 = EnergyDispersion.from_gauss(
+        edisp2 = EDispKernel.from_gauss(
             self.src.energy.edges, self.src.energy.edges, 0.2, 0.0
         )
         dataset2 = SpectrumDataset(
@@ -250,9 +252,34 @@ class TestSpectrumDataset:
         assert_allclose(
             dataset1.aeff.data.data.to_value("m2"), aeff.data.data.to_value("m2")
         )
-        assert_allclose(dataset1.edisp.get_bias(1 * u.TeV), 0.0, atol=1e-3)
+        assert_allclose(dataset1.edisp.get_bias(1 * u.TeV), 0.0, atol=1.2e-3)
         assert_allclose(dataset1.edisp.get_resolution(1 * u.TeV), 0.1581, atol=1e-2)
 
+    def test_info_dict(self):
+        info_dict = self.dataset.info_dict()
+
+        assert_allclose(info_dict["n_on"], 907010)
+        assert_allclose(info_dict["background"], 3000.0)
+
+        assert_allclose(info_dict["significance"], 2924.522174)
+        assert_allclose(info_dict["excess"], 904010)
+        assert_allclose(info_dict["livetime"].value, 1e2)
+
+        assert info_dict["name"] == "test"
+
+    @requires_dependency("matplotlib")
+    def test_peek(self):
+        with mpl_plot_check():
+            self.dataset.peek()
+        self.dataset.edisp = None
+        with mpl_plot_check():
+            self.dataset.peek()
+
+    @requires_dependency("matplotlib")
+    def test_plot_fit(self):
+        with mpl_plot_check():
+            self.dataset.plot_fit()
+
 
 class TestSpectrumOnOff:
     """ Test ON OFF SpectrumDataset"""
@@ -265,7 +292,7 @@ class TestSpectrumOnOff:
         ehi = ereco[1:]
         self.e_reco = ereco
         self.aeff = EffectiveAreaTable(etrue[:-1], etrue[1:], np.ones(9) * u.cm ** 2)
-        self.edisp = EnergyDispersion.from_diagonal_response(etrue, ereco)
+        self.edisp = EDispKernel.from_diagonal_response(etrue, ereco)
 
         data = np.ones(elo.shape)
         data[-1] = 0  # to test stats calculation with empty bins
@@ -454,7 +481,7 @@ class TestSpectrumOnOff:
         ehi = self.on_counts.energy.edges[1:]
         data = np.ones(self.on_counts.data.shape)
         background_model = CountsSpectrum(elo, ehi, data)
-        dataset.fake(background_model=background_model, random_state=314)
+        dataset.fake(background_model=background_model, random_state=314, name="fake")
 
         assert real_dataset.counts.data.shape == dataset.counts.data.shape
         assert real_dataset.counts_off.data.shape == dataset.counts_off.data.shape
@@ -466,6 +493,7 @@ class TestSpectrumOnOff:
         assert real_dataset.acceptance_off.mean() == dataset.acceptance_off.mean()
         assert dataset.counts_off.data.sum() == 39
         assert dataset.counts.data.sum() == 5
+        assert dataset.name == "fake"
 
     def test_info_dict(self):
         info_dict = self.dataset.info_dict()
@@ -598,7 +626,7 @@ def make_observation_list():
         energy_lo=energy[:-1], energy_hi=energy[1:], data=dataoff_2
     )
     aeff = EffectiveAreaTable.from_constant(energy, "1 cm2")
-    edisp = EnergyDispersion.from_gauss(e_true=energy, e_reco=energy, sigma=0.2, bias=0)
+    edisp = EDispKernel.from_gauss(e_true=energy, e_reco=energy, sigma=0.2, bias=0)
 
     time_ref = Time("2010-01-01")
     gti1 = make_gti({"START": [5, 6, 1, 2], "STOP": [8, 7, 3, 4]}, time_ref=time_ref)
@@ -720,7 +748,7 @@ def test_datasets_stack_reduce():
         ds = SpectrumDatasetOnOff.from_ogip_files(filename.format(obs))
         dataset_list.append(ds)
     datasets = Datasets(dataset_list)
-    stacked = datasets.stack_reduce()
+    stacked = datasets.stack_reduce(name="stacked")
     assert_allclose(stacked.livetime.to_value("s"), 6313.8116406202325)
 
     info_table = datasets.info_table()
@@ -728,6 +756,7 @@ def test_datasets_stack_reduce():
 
     info_table_cum = datasets.info_table(cumulative=True)
     assert_allclose(info_table_cum["n_on"], [124, 250, 369, 459])
+    assert stacked.name == "stacked"
 
 
 def test_spectrum_dataset_on_off_to_yaml(tmpdir):
