@@ -1,45 +1,50 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-import astropy.units as u
+import pytest
 import numpy as np
 from numpy.testing import assert_allclose
-from ...utils.testing import requires_data, requires_dependency
-from ...utils.random import get_random_state
-from ...utils.fitting import Fit
-from ...irf import EffectiveAreaTable
-from ...spectrum import (
-    CountsSpectrum,
-    models,
-    SpectrumDatasetOnOff,
-    SpectrumDataset,
-    SpectrumDatasetOnOffStacker,
+import astropy.units as u
+from gammapy.irf import EffectiveAreaTable
+from gammapy.modeling import Fit
+from gammapy.modeling.models import (
+    ExpCutoffPowerLawSpectralModel,
+    PowerLawSpectralModel,
+    SkyModel,
 )
+from gammapy.spectrum import CountsSpectrum, SpectrumDataset, SpectrumDatasetOnOff
+from gammapy.utils.random import get_random_state
+from gammapy.utils.testing import requires_data, requires_dependency
 
 
-@requires_dependency("sherpa")
+@requires_dependency("iminuit")
 class TestFit:
     """Test fit on counts spectra without any IRFs"""
 
     def setup(self):
         self.nbins = 30
         binning = np.logspace(-1, 1, self.nbins + 1) * u.TeV
-        self.source_model = models.PowerLaw(
-            index=2, amplitude=1e5 / u.TeV, reference=0.1 * u.TeV
+        self.source_model = SkyModel(
+            spectral_model=PowerLawSpectralModel(
+                index=2, amplitude=1e5 * u.Unit("cm-2 s-1 TeV-1"), reference=0.1 * u.TeV
+            )
         )
-        self.bkg_model = models.PowerLaw(
-            index=3, amplitude=1e4 / u.TeV, reference=0.1 * u.TeV
+        bkg_model = PowerLawSpectralModel(
+            index=3, amplitude=1e4 * u.Unit("cm-2 s-1 TeV-1"), reference=0.1 * u.TeV
         )
 
         self.alpha = 0.1
         random_state = get_random_state(23)
-        npred = self.source_model.integral(binning[:-1], binning[1:])
+        npred = self.source_model.spectral_model.integral(
+            binning[:-1], binning[1:]
+        ).value
         source_counts = random_state.poisson(npred)
         self.src = CountsSpectrum(
             energy_lo=binning[:-1], energy_hi=binning[1:], data=source_counts
         )
-        # Currently it's necessary to specify a lifetime
-        self.src.livetime = 1 * u.s
 
-        npred_bkg = self.bkg_model.integral(binning[:-1], binning[1:])
+        self.src.livetime = 1 * u.s
+        self.aeff = EffectiveAreaTable.from_constant(binning, "1 cm2")
+
+        npred_bkg = bkg_model.integral(binning[:-1], binning[1:]).value
 
         bkg_counts = random_state.poisson(npred_bkg)
         off_counts = random_state.poisson(npred_bkg * 1.0 / self.alpha)
@@ -52,12 +57,17 @@ class TestFit:
 
     def test_cash(self):
         """Simple CASH fit to the on vector"""
-        dataset = SpectrumDataset(model=self.source_model, counts=self.src)
+        dataset = SpectrumDataset(
+            models=self.source_model,
+            counts=self.src,
+            aeff=self.aeff,
+            livetime=self.src.livetime,
+        )
 
         npred = dataset.npred().data
         assert_allclose(npred[5], 660.5171, rtol=1e-5)
 
-        stat_val = dataset.likelihood()
+        stat_val = dataset.stat_sum()
         assert_allclose(stat_val, -107346.5291, rtol=1e-5)
 
         self.source_model.parameters["index"].value = 1.12
@@ -70,12 +80,36 @@ class TestFit:
         assert_allclose(pars["index"].value, 1.995525, rtol=1e-3)
         assert_allclose(pars["amplitude"].value, 100245.9, rtol=1e-3)
 
+    def test_wstat(self):
+        """WStat with on source and background spectrum"""
+        on_vector = self.src.copy()
+        on_vector.data += self.bkg.data
+        dataset = SpectrumDatasetOnOff(
+            counts=on_vector,
+            counts_off=self.off,
+            aeff=self.aeff,
+            livetime=self.src.livetime,
+            acceptance=1,
+            acceptance_off=1 / self.alpha,
+        )
+        dataset.models = self.source_model
+
+        self.source_model.parameters.index = 1.12
+
+        fit = Fit([dataset])
+        result = fit.run()
+        pars = self.source_model.parameters
+
+        assert_allclose(pars["index"].value, 1.997342, rtol=1e-3)
+        assert_allclose(pars["amplitude"].value, 100245.187067, rtol=1e-3)
+        assert_allclose(result.total_stat, 30.022316, rtol=1e-3)
+
     def test_fit_range(self):
         """Test fit range without complication of thresholds"""
         dataset = SpectrumDatasetOnOff(
             counts=self.src, mask_safe=np.ones(self.src.energy.nbin, dtype=bool)
         )
-        dataset.model = self.source_model
+        dataset.models = self.source_model
 
         assert np.sum(dataset.mask_safe) == self.nbins
         e_min, e_max = dataset.energy_range
@@ -83,9 +117,11 @@ class TestFit:
         assert_allclose(e_max.value, 10)
         assert_allclose(e_min.value, 0.1)
 
-    def test_likelihood_profile(self):
+    def test_stat_profile(self):
         dataset = SpectrumDataset(
-            model=self.source_model,
+            models=self.source_model,
+            aeff=self.aeff,
+            livetime=self.src.livetime,
             counts=self.src,
             mask_safe=np.ones(self.src.energy.nbin, dtype=bool),
         )
@@ -93,8 +129,8 @@ class TestFit:
         result = fit.run()
         true_idx = result.parameters["index"].value
         values = np.linspace(0.95 * true_idx, 1.05 * true_idx, 100)
-        profile = fit.likelihood_profile("index", values=values)
-        actual = values[np.argmin(profile["likelihood"])]
+        profile = fit.stat_profile("index", values=values)
+        actual = values[np.argmin(profile["stat"])]
         assert_allclose(actual, true_idx, rtol=0.01)
 
 
@@ -109,25 +145,29 @@ class TestSpectralFit:
         obs2 = SpectrumDatasetOnOff.from_ogip_files(path + "pha_obs23592.fits")
         self.obs_list = [obs1, obs2]
 
-        self.pwl = models.PowerLaw(
-            index=2, amplitude=1e-12 * u.Unit("cm-2 s-1 TeV-1"), reference=1 * u.TeV
+        self.pwl = SkyModel(
+            spectral_model=PowerLawSpectralModel(
+                index=2, amplitude=1e-12 * u.Unit("cm-2 s-1 TeV-1"), reference=1 * u.TeV
+            )
         )
 
-        self.ecpl = models.ExponentialCutoffPowerLaw(
-            index=2,
-            amplitude=1e-12 * u.Unit("cm-2 s-1 TeV-1"),
-            reference=1 * u.TeV,
-            lambda_=0.1 / u.TeV,
+        self.ecpl = SkyModel(
+            spectral_model=ExpCutoffPowerLawSpectralModel(
+                index=2,
+                amplitude=1e-12 * u.Unit("cm-2 s-1 TeV-1"),
+                reference=1 * u.TeV,
+                lambda_=0.1 / u.TeV,
+            )
         )
 
     def test_stats(self):
         dataset = self.obs_list[0]
-        dataset.model = self.pwl
+        dataset.models = self.pwl
 
         fit = Fit([dataset])
         result = fit.run()
 
-        stats = dataset.likelihood_per_bin()
+        stats = dataset.stat_array()
         actual = np.sum(stats[dataset.mask_safe])
 
         desired = result.total_stat
@@ -153,18 +193,16 @@ class TestSpectralFit:
             data=data, energy_lo=e_edges[:-1], energy_hi=e_edges[1:]
         )
         dataset.edisp = None
-        dataset.model = self.pwl
+        dataset.models = self.pwl
 
         fit = Fit([dataset])
         result = fit.run()
         assert_allclose(result.parameters["index"].value, 2.7961, atol=0.02)
 
     def test_stacked_fit(self):
-        obs_stacker = SpectrumDatasetOnOffStacker(self.obs_list)
-        obs_stacker.run()
-
-        dataset = obs_stacker.stacked_obs
-        dataset.model = self.pwl
+        dataset = self.obs_list[0].copy()
+        dataset.stack(self.obs_list[1])
+        dataset.models = self.pwl
 
         fit = Fit([dataset])
         result = fit.run()
@@ -175,7 +213,7 @@ class TestSpectralFit:
         assert_allclose(pars["amplitude"].value, 5.191e-11, rtol=1e-3)
 
     @requires_dependency("sherpa")
-    def test_sherpa_fit(self, tmpdir):
+    def test_sherpa_fit(self, tmp_path):
         # this is to make sure that the written PHA files work with sherpa
         import sherpa.astro.ui as sau
         from sherpa.models import PowLaw1D
@@ -187,10 +225,9 @@ class TestSpectralFit:
         logging.getLogger("sherpa").setLevel("ERROR")
 
         for obs in self.obs_list:
-            obs.to_ogip_files(str(tmpdir), use_sherpa=True)
+            obs.to_ogip_files(tmp_path, use_sherpa=True)
 
-        filename = tmpdir / "pha_obs23523.fits"
-        sau.load_pha(str(filename))
+        sau.load_pha(str(tmp_path / "pha_obs23523.fits"))
         sau.set_stat("wstat")
         model = PowLaw1D("powlaw1d.default")
         model.ref = 1e9
@@ -200,3 +237,13 @@ class TestSpectralFit:
         sau.fit()
         assert_allclose(model.pars[0].val, 2.732, rtol=1e-3)
         assert_allclose(model.pars[2].val, 4.647, rtol=1e-3)
+
+
+def test_stack_no_livetime():
+    e_reco = np.logspace(0, 1, 3) * u.TeV
+    dataset_1 = SpectrumDataset.create(e_reco=e_reco)
+    dataset_1.livetime = None
+    dataset_2 = dataset_1.copy()
+
+    with pytest.raises(ValueError):
+        dataset_1.stack(dataset_2)
