@@ -2,18 +2,18 @@
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
-from astropy.table import Table
 import astropy.units as u
-from ...catalog.fermi import SourceCatalog3FGL
-from ...utils.testing import (
-    requires_dependency,
-    requires_data,
+from astropy.table import Table
+from gammapy.catalog.fermi import SourceCatalog3FGL
+from gammapy.modeling import Datasets, Fit
+from gammapy.modeling.models import PowerLawSpectralModel, SkyModel, SpectralModel
+from gammapy.spectrum import FluxPoints, FluxPointsDataset
+from gammapy.utils.testing import (
     assert_quantity_allclose,
     mpl_plot_check,
+    requires_data,
+    requires_dependency,
 )
-from ...utils.fitting import Fit
-from ..models import PowerLaw, SpectralModel
-from ..flux_point import FluxPoints, FluxPointsDataset
 
 FLUX_POINTS_FILES = [
     "diff_flux_points.ecsv",
@@ -182,16 +182,14 @@ class TestFluxPoints:
             desired = 399430.975 * u.MeV
             assert_quantity_allclose(actual.sum(), desired)
 
-    def test_write_fits(self, tmpdir, flux_points):
-        filename = tmpdir / "flux_points.fits"
-        flux_points.write(filename)
-        actual = FluxPoints.read(filename)
+    def test_write_fits(self, tmp_path, flux_points):
+        flux_points.write(tmp_path / "tmp.fits")
+        actual = FluxPoints.read(tmp_path / "tmp.fits")
         assert str(flux_points) == str(actual)
 
-    def test_write_ecsv(self, tmpdir, flux_points):
-        filename = tmpdir / "flux_points.ecsv"
-        flux_points.write(filename)
-        actual = FluxPoints.read(filename)
+    def test_write_ecsv(self, tmp_path, flux_points):
+        flux_points.write(tmp_path / "flux_points.ecsv")
+        actual = FluxPoints.read(tmp_path / "flux_points.ecsv")
         assert str(flux_points) == str(actual)
 
     def test_drop_ul(self, flux_points):
@@ -211,7 +209,7 @@ class TestFluxPoints:
     @requires_dependency("matplotlib")
     def test_plot_likelihood(self, flux_points_likelihood):
         with mpl_plot_check():
-            flux_points_likelihood.plot_likelihood()
+            flux_points_likelihood.plot_ts_profiles()
 
 
 @requires_data()
@@ -222,7 +220,7 @@ def test_compute_flux_points_dnde_fermi():
     fermi_3fgl = SourceCatalog3FGL()
     source = fermi_3fgl["3FGL J0835.3-4510"]
     flux_points = source.flux_points.to_sed_type(
-        "dnde", model=source.spectral_model, method="log_center", pwl_approx=True
+        "dnde", model=source.spectral_model(), method="log_center", pwl_approx=True
     )
     for column in ["dnde", "dnde_errn", "dnde_errp", "dnde_ul"]:
         actual = flux_points.table["e2" + column].quantity
@@ -232,7 +230,7 @@ def test_compute_flux_points_dnde_fermi():
 
 @pytest.fixture()
 def fit(dataset):
-    return Fit(dataset)
+    return Fit([dataset])
 
 
 @pytest.fixture()
@@ -240,11 +238,38 @@ def dataset():
     path = "$GAMMAPY_DATA/tests/spectrum/flux_points/diff_flux_points.fits"
     data = FluxPoints.read(path)
     data.table["e_ref"] = data.e_ref.to("TeV")
-    model = PowerLaw(index=2.3, amplitude="2e-13 cm-2 s-1 TeV-1", reference="1 TeV")
+    model = SkyModel(
+        spectral_model=PowerLawSpectralModel(
+            index=2.3, amplitude="2e-13 cm-2 s-1 TeV-1", reference="1 TeV"
+        )
+    )
     dataset = FluxPointsDataset(model, data)
     return dataset
 
 
+@requires_data()
+def test_flux_point_dataset_serialization(tmp_path):
+    path = "$GAMMAPY_DATA/tests/spectrum/flux_points/diff_flux_points.fits"
+    data = FluxPoints.read(path)
+    data.table["e_ref"] = data.e_ref.to("TeV")
+    spectral_model = PowerLawSpectralModel(
+        index=2.3, amplitude="2e-13 cm-2 s-1 TeV-1", reference="1 TeV"
+    )
+    model = SkyModel(spectral_model=spectral_model, name="test_model")
+    dataset = FluxPointsDataset(model, data, name="test_dataset")
+
+    Datasets([dataset]).write(tmp_path, prefix="tmp")
+    datasets = Datasets.read(
+        tmp_path / "tmp_datasets.yaml", tmp_path / "tmp_models.yaml"
+    )
+    new_dataset = datasets[0]
+    assert_allclose(new_dataset.data.table["dnde"], dataset.data.table["dnde"], 1e-4)
+    if dataset.mask_fit is None:
+        assert np.all(new_dataset.mask_fit == dataset.mask_safe)
+    assert np.all(new_dataset.mask_safe == dataset.mask_safe)
+    assert new_dataset.name == "test_dataset"
+
+
 @requires_data()
 def test_flux_point_dataset_str(dataset):
     assert "FluxPointsDataset" in str(dataset)
@@ -279,29 +304,29 @@ class TestFluxPointFit:
 
     @staticmethod
     @requires_dependency("iminuit")
-    def test_likelihood_profile(fit):
+    def test_stat_profile(fit):
         optimize_opts = {"backend": "minuit"}
 
         result = fit.run(optimize_opts=optimize_opts)
 
-        profile = fit.likelihood_profile("amplitude", nvalues=3, bounds=1)
+        profile = fit.stat_profile("amplitude", nvalues=3, bounds=1)
 
-        ts_diff = profile["likelihood"] - result.total_stat
+        ts_diff = profile["stat"] - result.total_stat
         assert_allclose(ts_diff, [110.1, 0, 110.1], rtol=1e-2, atol=1e-7)
 
         value = result.parameters["amplitude"].value
         err = result.parameters.error("amplitude")
         values = np.array([value - err, value, value + err])
 
-        profile = fit.likelihood_profile("amplitude", values=values)
+        profile = fit.stat_profile("amplitude", values=values)
 
-        ts_diff = profile["likelihood"] - result.total_stat
+        ts_diff = profile["stat"] - result.total_stat
         assert_allclose(ts_diff, [110.1, 0, 110.1], rtol=1e-2, atol=1e-7)
 
     @staticmethod
     @requires_dependency("matplotlib")
     def test_fp_dataset_peek(fit):
-        fp_dataset = fit.datasets.datasets[0]
+        fp_dataset = fit.datasets[0]
 
         with mpl_plot_check():
-            fp_dataset.peek()
+            fp_dataset.peek(method="diff/model")
