@@ -2,15 +2,15 @@
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
-from astropy.table import Table
 import astropy.units as u
-from ..models import PowerLaw
-from ..flux_point import FluxPoints
+from astropy.table import Table
+from gammapy.modeling.models import PowerLawSpectralModel
+from gammapy.spectrum import FluxPoints
 
 
 @pytest.fixture(scope="session")
 def model():
-    return PowerLaw()
+    return PowerLawSpectralModel()
 
 
 @pytest.fixture(scope="session")
