@@ -2,8 +2,7 @@
 """Feldman Cousins algorithm to compute parameter confidence limits."""
 import logging
 import numpy as np
-from scipy.stats import norm, poisson, rankdata
-
+import scipy.stats
 
 __all__ = [
     "fc_find_acceptance_interval_gauss",
@@ -44,7 +43,7 @@ def fc_find_acceptance_interval_gauss(mu, sigma, x_bins, alpha):
         Acceptance interval
     """
 
-    dist = norm(loc=mu, scale=sigma)
+    dist = scipy.stats.norm(loc=mu, scale=sigma)
 
     x_bin_width = x_bins[1] - x_bins[0]
 
@@ -63,7 +62,7 @@ def fc_find_acceptance_interval_gauss(mu, sigma, x_bins, alpha):
         else:
             # Implementing the boundary condition at zero
             mu_best = max(0, x)
-            prob_mu_best = norm.pdf(x, loc=mu_best, scale=sigma)
+            prob_mu_best = scipy.stats.norm.pdf(x, loc=mu_best, scale=sigma)
             # probMuBest should never be zero. Check it just in case.
             if prob_mu_best == 0.0:
                 r.append(0.0)
@@ -79,7 +78,7 @@ def fc_find_acceptance_interval_gauss(mu, sigma, x_bins, alpha):
             "desired confidence level for this mu!"
         )
 
-    rank = rankdata(-r, method="dense")
+    rank = scipy.stats.rankdata(-r, method="dense")
 
     index_array = np.arange(x_bins.size)
 
@@ -125,7 +124,7 @@ def fc_find_acceptance_interval_poisson(mu, background, x_bins, alpha):
     (x_min, x_max) : tuple of floats
         Acceptance interval
     """
-    dist = poisson(mu=mu + background)
+    dist = scipy.stats.poisson(mu=mu + background)
 
     x_bin_width = x_bins[1] - x_bins[0]
 
@@ -136,7 +135,7 @@ def fc_find_acceptance_interval_poisson(mu, background, x_bins, alpha):
         p.append(dist.pmf(x))
         # Implementing the boundary condition at zero
         muBest = max(0, x - background)
-        probMuBest = poisson.pmf(x, mu=muBest + background)
+        probMuBest = scipy.stats.poisson.pmf(x, mu=muBest + background)
         # probMuBest should never be zero. Check it just in case.
         if probMuBest == 0.0:
             r.append(0.0)
@@ -152,7 +151,7 @@ def fc_find_acceptance_interval_poisson(mu, background, x_bins, alpha):
             "desired confidence level for this mu!"
         )
 
-    rank = rankdata(-r, method="dense")
+    rank = scipy.stats.rankdata(-r, method="dense")
 
     index_array = np.arange(x_bins.size)
 
