@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Time analysis."""
-from .simulate import *
 from .lightcurve import *
 from .lightcurve_estimator import *
-from .events import *
 from .period import *
+from .simulate import *
+from .variability import *
