@@ -3,7 +3,7 @@ import numpy as np
 import astropy.units as u
 from astropy.table import Table
 from astropy.time import Time
-from ..utils.scripts import make_path
+from gammapy.utils.scripts import make_path
 
 __all__ = ["LightCurve"]
 
@@ -18,7 +18,7 @@ class LightCurve:
     TODO: specification of format is work in progress
     See https://github.com/open-gamma-ray-astro/gamma-astro-data-formats/pull/61
 
-    Usage: :ref:`time-lc`
+    Usage: :ref:`time`
 
     Parameters
     ----------
@@ -30,7 +30,7 @@ class LightCurve:
         self.table = table
 
     def __repr__(self):
-        return "{}(len={})".format(self.__class__.__name__, len(self.table))
+        return f"{self.__class__.__name__}(len={len(self.table)})"
 
     @property
     def time_scale(self):
@@ -94,8 +94,7 @@ class LightCurve:
         kwargs : dict
             Keyword arguments passed to `astropy.table.Table.read`.
         """
-        filename = make_path(filename)
-        table = Table.read(str(filename), **kwargs)
+        table = Table.read(make_path(filename), **kwargs)
         return cls(table=table)
 
     def write(self, filename, **kwargs):
@@ -108,70 +107,7 @@ class LightCurve:
         kwargs : dict
             Keyword arguments passed to `astropy.table.Table.write`.
         """
-        filename = make_path(filename)
-        self.table.write(str(filename), **kwargs)
-
-    def compute_fvar(self):
-        r"""Calculate the fractional excess variance.
-
-        This method accesses the the ``FLUX`` and ``FLUX_ERR`` columns
-        from the lightcurve data.
-
-        The fractional excess variance :math:`F_{var}`, an intrinsic
-        variability estimator, is given by
-
-        .. math::
-            F_{var} = \sqrt{\frac{S^{2} - \bar{\sigma^{2}}}{\bar{x}^{2}}}.
-
-        It is the excess variance after accounting for the measurement errors
-        on the light curve :math:`\sigma`. :math:`S` is the variance.
-
-        Returns
-        -------
-        fvar, fvar_err : `~numpy.ndarray`
-            Fractional excess variance.
-
-        References
-        ----------
-        .. [Vaughan2003] "On characterizing the variability properties of X-ray light
-           curves from active galaxies", Vaughan et al. (2003)
-           https://ui.adsabs.harvard.edu/abs/2003MNRAS.345.1271V
-        """
-        flux = self.table["flux"].data.astype("float64")
-        flux_err = self.table["flux_err"].data.astype("float64")
-
-        flux_mean = np.mean(flux)
-        n_points = len(flux)
-
-        s_square = np.sum((flux - flux_mean) ** 2) / (n_points - 1)
-        sig_square = np.nansum(flux_err ** 2) / n_points
-        fvar = np.sqrt(np.abs(s_square - sig_square)) / flux_mean
-
-        sigxserr_a = np.sqrt(2 / n_points) * (sig_square / flux_mean) ** 2
-        sigxserr_b = np.sqrt(sig_square / n_points) * (2 * fvar / flux_mean)
-        sigxserr = np.sqrt(sigxserr_a ** 2 + sigxserr_b ** 2)
-        fvar_err = sigxserr / (2 * fvar)
-
-        return fvar, fvar_err
-
-    def compute_chisq(self):
-        """Calculate the chi-square test for `LightCurve`.
-
-        Chisquare test is a variability estimator. It computes
-        deviations from the expected value here mean value
-
-        Returns
-        -------
-        ChiSq, P-value : tuple of float or `~numpy.ndarray`
-            Tuple of Chi-square and P-value
-        """
-        import scipy.stats as stats
-
-        flux = self.table["flux"]
-        yexp = np.mean(flux)
-        yobs = flux.data
-        chi2, pval = stats.chisquare(yobs, yexp)
-        return chi2, pval
+        self.table.write(make_path(filename), **kwargs)
 
     def plot(self, ax=None, time_format="mjd", flux_unit="cm-2 s-1", **kwargs):
         """Plot flux points.
@@ -200,9 +136,9 @@ class LightCurve:
         if ax is None:
             ax = plt.gca()
 
+        x, xerr = self._get_times_and_errors(time_format)
         y, yerr = self._get_fluxes_and_errors(flux_unit)
         is_ul, yul = self._get_flux_uls(flux_unit)
-        x, xerr = self._get_times_and_errors(time_format)
 
         # length of the ul arrow
         ul_arr = (
@@ -312,8 +248,6 @@ class LightCurve:
             Tuple of time error values or `~datetime.timedelta` instances if
             'iso' is chosen as time format
         """
-        from matplotlib.dates import num2timedelta
-
         x = self.time
 
         try:
@@ -321,17 +255,15 @@ class LightCurve:
         except KeyError:
             xn, xp = x - x, x - x
 
-        # convert to given time format
         if time_format == "iso":
             x = x.datetime
-            # TODO: In astropy version >3.1 the TimeDelta.to_datetime() method
-            # should start working, for now i will use num2timedelta.
-            xn = np.asarray(num2timedelta(xn.to("d").value))
-            xp = np.asarray(num2timedelta(xp.to("d").value))
+            xn = xn.to_datetime()
+            xp = xp.to_datetime()
         elif time_format == "mjd":
             x = x.mjd
-            xn, xp = xn.to("d").value, xp.to("d").value
+            xn = xn.to("day").value
+            xp = xp.to("day").value
         else:
-            raise ValueError("Invalid time_format: {}".format(time_format))
+            raise ValueError(f"Invalid time_format: {time_format}")
 
         return x, (xn, xp)
