@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 from astropy.time import TimeDelta
-from ..utils.random import get_random_state
+from gammapy.utils.random import get_random_state
 
 __all__ = ["random_times"]
 
