@@ -1,9 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 from numpy.testing import assert_almost_equal
 from astropy.units import Quantity
-from ..simulate import random_times
+from gammapy.time import random_times
 
 
 def test_random_times():
