@@ -1,8 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Utility functions to deal with arrays and quantities."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
-from ..extern import six
 
 __all__ = [
     "array_stats_str",
@@ -31,7 +29,7 @@ def array_stats_str(x, label=""):
 
     ss = ""
     if label:
-        ss += "{0:15s}: ".format(label)
+        ss += f"{label:15s}: "
 
     min = x.min()
     max = x.max()
@@ -87,8 +85,9 @@ def shape_divisible_by(shape, factor):
 
 def symmetric_crop_pad_width(shape, new_shape):
     """
-    Compute symmetric crop or pad width to obtain a new shape from a given old
-    shape of an array.
+    Compute symmetric crop or pad width.
+
+    To obtain a new shape from a given old shape of an array.
 
     Parameters
     ----------
@@ -109,44 +108,3 @@ def symmetric_crop_pad_width(shape, new_shape):
     ywidth = (ydiff // 2, ydiff // 2)
     xwidth = (xdiff // 2, xdiff // 2)
     return ywidth, xwidth
-
-
-def check_type(val, category):
-    if category == "str":
-        return _check_str(val)
-    elif category == "number":
-        return _check_number(val)
-    elif category == "bool":
-        return _check_bool(val)
-    else:
-        raise ValueError("Invalid category: {}".format(category))
-
-
-def _check_str(val):
-    if isinstance(val, six.string_types):
-        return val
-    else:
-        raise TypeError("Expected a string. Got: {!r}".format(val))
-
-
-def _check_number(val):
-    if _is_float(val) or _is_int(val):
-        return val
-    raise TypeError("Expected a number. Got: {!r}".format(val))
-
-
-def _is_int(val):
-    int_types = six.integer_types + (np.integer,)
-    return isinstance(val, int_types)
-
-
-def _is_float(val):
-    float_types = (float, np.floating)
-    return isinstance(val, float_types)
-
-
-def _check_bool(val):
-    if isinstance(val, bool):
-        return val
-    else:
-        raise TypeError("Expected a bool. Got: {!r}".format(val))
