@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Other coordinate and distance-related functions"""
 import numpy as np
-from astropy.units import Unit, Quantity
+from astropy.units import Quantity, Unit
 
 __all__ = [
     "cartesian",
@@ -18,9 +18,7 @@ D_SUN_TO_GALACTIC_CENTER = Quantity(8.5, "kpc")
 
 
 def cartesian(r, theta):
-    """
-    Convert polar coordinates to cartesian coordinates.
-    """
+    """Convert polar coordinates to cartesian coordinates."""
     x = r * np.cos(theta)
     y = r * np.sin(theta)
     return x, y
@@ -34,8 +32,9 @@ def polar(x, y):
 
 
 def galactic(x, y, z, obs_pos=None):
-    """Compute galactic coordinates lon, lat (deg) and distance (kpc)
-    for given position in cartesian coordinates (kpc).
+    """Compute galactic coordinates lon, lat and distance.
+
+    For given position in cartesian coordinates (kpc).
     """
     obs_pos = obs_pos or [D_SUN_TO_GALACTIC_CENTER, 0, 0]
     y_prime = y + D_SUN_TO_GALACTIC_CENTER
@@ -68,7 +67,7 @@ def velocity_glon_glat(x, y, z, vx, vy, vz):
     v_glon = (-y_prime * vx + x * vy) / r ** 2
     v_glat = vz / (np.sqrt(1 - (z / d) ** 2) * d) - np.sqrt(
         vx ** 2 + vy ** 2 + vz ** 2
-    ) * z / ((np.sqrt(1 - (z / d) ** 2) * d ** 2))
+    ) * z / (np.sqrt(1 - (z / d) ** 2) * d ** 2)
     return v_glon * Unit("rad"), v_glat * Unit("rad")
 
 
