@@ -17,17 +17,17 @@ Here's some good resources with working examples:
 - https://github.com/bokeh/bokeh/tree/master/bokeh/sphinxext
 """
 import os
-import re
-from pathlib import Path
 from distutils.util import strtobool
-from docutils.parsers.rst.directives.images import Image
-from docutils.parsers.rst.directives import register_directive
-from docutils.parsers.rst import roles
-from docutils import nodes
-from sphinx.util import logging
-from nbformat.v4 import new_markdown_cell
+from pathlib import Path
 import nbformat
-from .. import version
+from docutils.parsers.rst.directives import register_directive
+from docutils.parsers.rst.directives.body import CodeBlock
+from docutils.parsers.rst.directives.images import Image
+from docutils.parsers.rst.directives.misc import Include
+from nbformat.v4 import new_markdown_cell
+from sphinx.util import logging
+from gammapy import __version__
+from gammapy.analysis import AnalysisConfig
 
 try:
     gammapy_data_path = Path(os.environ["GAMMAPY_DATA"])
@@ -35,7 +35,32 @@ try:
 except KeyError:
     HAS_GP_DATA = False
 
-log = logging.getLogger("__name__")
+log = logging.getLogger(__name__)
+
+
+class HowtoHLI(Include):
+    """Directive to insert how-to for high-level interface"""
+
+    def run(self):
+        raw = ""
+        section = self.arguments[0]
+        doc = AnalysisConfig._get_doc_sections()
+        for keyword in doc.keys():
+            if section == "" or section == keyword:
+                raw += doc[keyword]
+        include_lines = raw.splitlines()
+        codeblock = CodeBlock(
+            self.name,
+            [],
+            self.options,
+            include_lines,  # content
+            self.lineno,
+            self.content_offset,
+            self.block_text,
+            self.state,
+            self.state_machine,
+        )
+        return codeblock.run()
 
 
 class DocsImage(Image):
@@ -65,43 +90,9 @@ class DocsImage(Image):
         return super().run()
 
 
-def LinkNotebook(name, rawtext, notebook, lineno, inliner, options={}, content=[]):
-    """Link to a notebook"""
-    # check if file exists in local notebooks folder
-    nbfolder = Path("notebooks")
-    nbfilename = notebook + ".ipynb"
-    nbfile = nbfolder / nbfilename
-
-    if not nbfile.is_file():
-        msg = inliner.reporter.error(
-            "Unknown notebook {}".format(notebook), line=lineno
-        )
-        prb = inliner.problematic(rawtext, rawtext, msg)
-        return [prb], [msg]
-    else:
-        refuri = inliner.document.settings._source
-        app = inliner.document.settings.env.app
-        node = make_link_node(rawtext, app, refuri, notebook, options)
-        return [node], []
-
-
-def make_link_node(rawtext, app, refuri, notebook, options):
-    # base = 'https://github.com/gammapy/gammapy/tree/master/notebooks/'
-    # base = 'https://nbviewer.jupyter.org/github/gammapy/gammapy/blob/master/notebooks/'
-
-    relpath = refuri.split(str(Path("/docs")))[1]
-    foldersplit = relpath.split(os.sep)
-    base = ((".." + os.sep) * (len(foldersplit) - 2)) + "notebooks" + os.sep
-    full_name = notebook + ".html"
-    ref = base + full_name
-    roles.set_classes(options)
-    node = nodes.reference(rawtext, full_name, refuri=ref, **options)
-    return node
-
-
 def gammapy_sphinx_ext_activate():
     if HAS_GP_DATA:
-        log.info("*** Found GAMMAPY_DATA = {}".format(gammapy_data_path))
+        log.info(f"*** Found GAMMAPY_DATA = {gammapy_data_path}")
         log.info("*** Nice!")
     else:
         log.info("*** gammapy-data *not* found.")
@@ -110,20 +101,19 @@ def gammapy_sphinx_ext_activate():
 
     # Register our directives and roles with Sphinx
     register_directive("gp-image", DocsImage)
-    roles.register_local_role("gp-notebook", LinkNotebook)
+    register_directive("gp-howto-hli", HowtoHLI)
 
 
 def parse_notebooks(folder, url_docs):
-    """
+    """Parse Jupyter notebook.
+
     Modifies raw and html-fixed notebooks so they will not have broken links
     to other files in the documentation. Adds a box to the sphinx formatted
     notebooks with info and links to the *.ipynb and *.py files.
     """
-    if version.release:
-        release_number_docs = release_number_binder = version.version
-    else:
+    release_number_binder = __version__
+    if "dev" in __version__:
         release_number_binder = "master"
-        release_number_docs = "dev"
 
     DOWNLOAD_CELL = """
 <div class="alert alert-info">
@@ -168,22 +158,6 @@ def parse_notebooks(folder, url_docs):
                                     ].replace("$", "$$")
                 nbformat.write(rawnb, str(nbpath))
 
-        # modif links to rst /html doc files
-        txt = nbpath.read_text(encoding="utf-8")
-        if str(folder) == "notebooks":
-            repl = r"..\/\1rst\2"
-            txt = re.sub(
-                pattern=url_docs + r"(.*?)html(\)|#)",
-                repl=repl,
-                string=txt,
-                flags=re.M | re.I,
-            )
-        else:
-            url_docs_release = url_docs.replace("dev", release_number_docs)
-            txt = txt.replace(url_docs, url_docs_release)
-
-        nbpath.write_text(txt, encoding="utf-8")
-
 
 def gammapy_sphinx_notebooks(setup_cfg):
     """Manage creation of Sphinx-formatted notebooks."""
