@@ -13,10 +13,6 @@ def gauss_dist(x, mu, sigma):
     return stats.norm.pdf(x, mu, sigma)
 
 
-def po(x):
-    return x ** (-1.0 * 2)
-
-
 def test_uniform_dist_sampling():
     n_sampled = 1000
     x = np.linspace(-2, 2, n_sampled)
@@ -65,4 +61,4 @@ def test_axis_sampling():
     idx = sampler.sample_axis()
     x_sampled = np.interp(idx, np.arange(n_sampled), x)
 
-    assert_allclose(x_sampled, [0.01042147, 0.43061014], rtol=1e-5)
+    assert_allclose(x_sampled, [0.012266, 0.43081], rtol=1e-4)
