@@ -11,7 +11,6 @@ __all__ = [
     "sample_sphere_distance",
     "sample_powerlaw",
     "normalize",
-    "density",
     "draw",
     "pdf",
 ]
@@ -35,15 +34,6 @@ def pdf(func):
     return f
 
 
-def density(func):
-    """Radial surface density of a given one dimensional PDF."""
-
-    def f(x):
-        return func(x) / x
-
-    return f
-
-
 def draw(low, high, size, dist, random_state="random-seed", *args, **kwargs):
     """Allows drawing of random numbers from any distribution."""
     from .inverse_cdf import InverseCDFSampler
