@@ -1,11 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Test if Jupyter notebooks work."""
-import os
-import sys
 import logging
-from pathlib import Path
-from pkg_resources import working_set
+import os
 import subprocess
+import sys
+from pathlib import Path
+import pkg_resources
 import yaml
 
 log = logging.getLogger(__name__)
@@ -25,7 +25,7 @@ def requirement_missing(script):
             return False
         for package in script["requires"].split():
             try:
-                working_set.require(package)
+                pkg_resources.working_set.require(package)
             except Exception:
                 return True
     return False
@@ -33,7 +33,7 @@ def requirement_missing(script):
 
 def script_test(path):
     """Check if example Python script is broken."""
-    log.info("   ... EXECUTING {}".format(str(path)))
+    log.info(f"   ... EXECUTING {path}")
 
     cmd = [sys.executable, str(path)]
     cp = subprocess.run(cmd, stderr=subprocess.PIPE)
@@ -60,7 +60,7 @@ def main():
 
     for script in get_scripts():
         if requirement_missing(script):
-            log.info("Skipping script (missing requirement): {}".format(script["name"]))
+            log.info(f"Skipping script (missing requirement): {script['name']}")
             continue
 
         filename = script["name"] + ".py"
