@@ -12,7 +12,6 @@ __all__ = [
     "requires_data",
     "mpl_plot_check",
     "assert_quantity_allclose",
-    "assert_wcs_allclose",
     "assert_skycoord_allclose",
     "assert_time_allclose",
     "Checker",
@@ -127,12 +126,6 @@ def run_cli(cli, args, exit_code=0):
     return result
 
 
-def assert_wcs_allclose(wcs1, wcs2):
-    """Assert all-close for `astropy.wcs.WCS` objects."""
-    # TODO: implement properly
-    assert_allclose(wcs1.wcs.cdelt, wcs2.wcs.cdelt)
-
-
 def assert_skycoord_allclose(actual, desired):
     """Assert all-close for `astropy.coordinates.SkyCoord` objects.
 
@@ -140,8 +133,8 @@ def assert_skycoord_allclose(actual, desired):
     """
     assert isinstance(actual, SkyCoord)
     assert isinstance(desired, SkyCoord)
-    assert_allclose(actual.data.lon.value, desired.data.lon.value)
-    assert_allclose(actual.data.lat.value, desired.data.lat.value)
+    assert_allclose(actual.data.lon.deg, desired.data.lon.deg)
+    assert_allclose(actual.data.lat.deg, desired.data.lat.deg)
 
 
 def assert_time_allclose(actual, desired, atol=1e-3):
