@@ -1,11 +1,12 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Test if Jupyter notebooks work."""
-import os
-import sys
 import logging
-from pkg_resources import working_set
+import os
+import shutil
+import sys
+from pathlib import Path
 import yaml
-from ..extern.pathlib import Path
-from ..scripts.jupyter import notebook_test
+from gammapy.scripts.jupyter import notebook_test
 
 log = logging.getLogger(__name__)
 
@@ -17,19 +18,6 @@ def get_notebooks():
         return yaml.safe_load(fh)
 
 
-def requirement_missing(notebook):
-    """Check if one of the requirements is missing."""
-    if "requires" in notebook:
-        if notebook["requires"] is None:
-            return False
-        for package in notebook["requires"].split():
-            try:
-                working_set.require(package)
-            except Exception:
-                return True
-    return False
-
-
 def main():
     logging.basicConfig(level=logging.INFO)
 
@@ -41,22 +29,25 @@ def main():
 
     passed = True
 
+    # setup
+    path_temp = Path("temp")
+    path_empty_nbs = Path("tutorials")
+    shutil.rmtree(path_temp, ignore_errors=True)
+    shutil.copytree(path_empty_nbs, path_temp)
+
     for notebook in get_notebooks():
-        if requirement_missing(notebook):
-            log.info(
-                "Skipping notebook {} because requirement is missing.".format(
-                    notebook["name"]
-                )
-            )
-            continue
 
         filename = notebook["name"] + ".ipynb"
-        path = Path("tutorials") / filename
+        path = path_temp / filename
 
         if not notebook_test(path):
             passed = False
 
-    assert passed
+    # tear down
+    shutil.rmtree(path_temp, ignore_errors=True)
+
+    if not passed:
+        sys.exit("Some tests failed. Existing now.")
 
 
 if __name__ == "__main__":
